@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -37,29 +37,26 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
+#include <pthread.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <sys/un.h>
 #include <sys/types.h>
-#include <signal.h>
-#include <pthread.h>
+#include <unistd.h>
 
 #include "slurm/slurm.h"
 
+#include "src/common/eio.h"
+#include "src/common/fd.h"
+#include "src/common/forward.h"
+#include "src/common/net.h"
+#include "src/common/macros.h"
+#include "src/common/slurm_auth.h"
 #include "src/common/slurm_protocol_defs.h"
 #include "src/common/slurm_protocol_api.h"
 #include "src/common/slurm_protocol_common.h"
-#include "src/common/net.h"
-#include "src/common/fd.h"
-#include "src/common/forward.h"
 #include "src/common/xmalloc.h"
-#include "src/common/slurm_auth.h"
-#include "src/common/eio.h"
 #include "src/common/xsignal.h"
 
 struct allocation_msg_thread {
@@ -86,7 +83,7 @@ static void *_msg_thr_internal(void *arg)
 	debug("Entering _msg_thr_internal");
 	xsignal_block(signals);
 	slurm_mutex_lock(&msg_thr_start_lock);
-	pthread_cond_signal(&msg_thr_start_cond);
+	slurm_cond_signal(&msg_thr_start_cond);
 	slurm_mutex_unlock(&msg_thr_start_lock);
 	eio_handle_mainloop((eio_handle_t *)arg);
 	debug("Leaving _msg_thr_internal");
@@ -158,7 +155,7 @@ extern allocation_msg_thread_t *slurm_allocation_msg_thr_create(
 	slurm_attr_destroy(&attr);
 	/* Wait until the message thread has blocked signals
 	   before continuing. */
-	pthread_cond_wait(&msg_thr_start_cond, &msg_thr_start_lock);
+	slurm_cond_wait(&msg_thr_start_cond, &msg_thr_start_lock);
 	slurm_mutex_unlock(&msg_thr_start_lock);
 
 	return (allocation_msg_thread_t *)msg_thr;
