@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -37,10 +37,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -295,6 +291,14 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 	}
 	xstrfmtcat(out, " Dist=%s",
 		   slurm_step_layout_type_name(job_step_ptr->task_dist));
+	if (one_liner)
+		xstrcat(out, " ");
+	else
+		xstrcat(out, "\n   ");
+
+	/****** Line 7 ******/
+	xstrfmtcat(out, "SrunHost:Pid=%s:%u",
+		   job_step_ptr->srun_host, job_step_ptr->srun_pid);
 	xstrcat(out, "\n\n");
 
 	return out;
