@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -25,10 +25,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <pthread.h>
 #include <stdlib.h>
 
@@ -175,7 +171,7 @@ static void *_msg_thread(void *x)
 
 	slurm_mutex_lock(&agent_mutex);
 	agent_cnt--;
-	pthread_cond_signal(&agent_cond);
+	slurm_cond_signal(&agent_cond);
 	slurm_mutex_unlock(&agent_mutex);
 	xfree(x);
 	return NULL;
@@ -241,7 +237,7 @@ static void *_agent(void *x)
 
 		slurm_mutex_lock(&agent_mutex);
 		while (agent_cnt >= agent_max_cnt)
-			pthread_cond_wait(&agent_cond, &agent_mutex);
+			slurm_cond_wait(&agent_cond, &agent_mutex);
 		agent_cnt++;
 		slurm_mutex_unlock(&agent_mutex);
 
@@ -272,7 +268,7 @@ static void *_agent(void *x)
 	/* wait for completion of all outgoing message */
 	slurm_mutex_lock(&agent_mutex);
 	while (agent_cnt > 0)
-		pthread_cond_wait(&agent_cond, &agent_mutex);
+		slurm_cond_wait(&agent_cond, &agent_mutex);
 	slurm_mutex_unlock(&agent_mutex);
 	slurm_attr_destroy(&attr);
 
