@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -134,6 +134,9 @@ typedef struct gres_job_state {
 	 * gres_bit_step_alloc is a subset of gres_bit_alloc */
 	bitstr_t **gres_bit_step_alloc;
 	uint64_t  *gres_cnt_step_alloc;
+
+	/* key for searches with name and type */
+	uint32_t gres_name_type_id;
 } gres_job_state_t;
 
 /* Gres job step state as used by slurmctld daemon */
@@ -154,6 +157,12 @@ typedef struct gres_step_state {
 	bitstr_t **gres_bit_alloc;
 } gres_step_state_t;
 
+typedef enum {
+	GRES_STATE_TYPE_NODE = 0,
+	GRES_STATE_TYPE_JOB,
+	GRES_STATE_TYPE_STEP
+} gres_state_type_enum_t;
+
 /*
  * Initialize the gres plugin.
  *
@@ -414,7 +423,7 @@ extern int gres_plugin_job_count(List gres_list, int arr_len,
  * OUT gres_list - List of Gres records for this job to track usage
  * RET SLURM_SUCCESS or ESLURM_INVALID_GRES
  */
-extern int gres_plugin_job_state_validate(char *req_config, List *gres_list);
+extern int gres_plugin_job_state_validate(char **req_config, List *gres_list);
 
 /*
  * Create a (partial) copy of a job's gres state for job binding
@@ -553,8 +562,10 @@ extern void gres_plugin_job_merge(List from_job_gres_list,
  * Set environment variables as required for a batch job
  * IN/OUT job_env_ptr - environment variable array
  * IN gres_list - generated by gres_plugin_job_alloc()
-  */
-extern void gres_plugin_job_set_env(char ***job_env_ptr, List job_gres_list);
+ * IN node_inx - zero origin node index
+ */
+extern void gres_plugin_job_set_env(char ***job_env_ptr, List job_gres_list,
+				    int node_inx);
 
 
 /*
@@ -735,6 +746,15 @@ extern int gres_get_job_info(List job_gres_list, char *gres_name,
 			     uint32_t node_inx,
 			     enum gres_job_data_type data_type, void *data);
 
+/* Given a job's GRES data structure, return the indecies for selected elements
+ * IN job_gres_list  - job's GRES data structure
+ * OUT gres_detail_cnt - Number of elements (nodes) in gres_detail_str
+ * OUT gres_detail_str - Description of GRES on each node
+ */
+extern void gres_build_job_details(List job_gres_list,
+				   uint32_t *gres_detail_cnt,
+				   char ***gres_detail_str);
+
 enum gres_step_data_type {
 	GRES_STEP_DATA_COUNT,	/* data-> uint32_t  */
 	GRES_STEP_DATA_BITMAP,	/* data-> bitstr_t* */
@@ -768,7 +788,7 @@ extern gres_step_state_t *gres_get_step_state(List gres_list, char *name);
  */
 extern char *gres_2_tres_str(List gres_list, bool is_job, bool locked);
 
-/* Fill in the tres_cnt based off the gres_list and node_cnt
+/* Fill in the job allocated tres_cnt based off the gres_list and node_cnt
  * IN gres_list - filled in with gres_job_state_t's
  * IN node_cnt - number of nodes in the job
  * OUT tres_cnt - gres spots filled in with total number of TRES
@@ -780,4 +800,13 @@ extern void gres_set_job_tres_cnt(List gres_list,
 				  uint64_t *tres_cnt,
 				  bool locked);
 
+/* Fill in the node allocated tres_cnt based off the gres_list
+ * IN gres_list - filled in with gres_node_state_t's gres_alloc_cnt
+ * OUT tres_cnt - gres spots filled in with total number of TRES
+ *                allocated on node
+ * IN locked - if the assoc_mgr tres read locked is locked or not
+ */
+extern void gres_set_node_tres_cnt(List gres_list, uint64_t *tres_cnt,
+				   bool locked);
+
 #endif /* !_GRES_H */
