@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -39,16 +39,7 @@
 #ifndef _JOB_RESOURCES_H
 #define _JOB_RESOURCES_H
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#  if HAVE_INTTYPES_H
-#    include <inttypes.h>
-#  else
-#    if HAVE_STDINT_H
-#      include <stdint.h>
-#    endif
-#  endif			/* HAVE_INTTYPES_H */
-#endif
+#include <inttypes.h>
 
 #include "src/common/bitstring.h"
 #include "src/common/pack.h"
@@ -108,24 +99,24 @@
  * updated (e.g. cpus and mem_used on that node cleared).
  */
 struct job_resources {
-	bitstr_t *	core_bitmap;
-	bitstr_t *	core_bitmap_used;
-	uint32_t	cpu_array_cnt;
-	uint16_t *	cpu_array_value;
-	uint32_t *	cpu_array_reps;
-	uint16_t *	cpus;
-	uint16_t *	cpus_used;
-	uint16_t *	cores_per_socket;
-	uint32_t *	memory_allocated;
-	uint32_t *	memory_used;
-	uint32_t	nhosts;
-	bitstr_t *	node_bitmap;
-	uint32_t	node_req;
-	char *		nodes;
-	uint32_t	ncpus;
-	uint32_t *	sock_core_rep_count;
-	uint16_t *	sockets_per_node;
-	uint8_t		whole_node;
+	bitstr_t *core_bitmap;
+	bitstr_t *core_bitmap_used;
+	uint32_t  cpu_array_cnt;
+	uint16_t *cpu_array_value;
+	uint32_t *cpu_array_reps;
+	uint16_t *cpus;
+	uint16_t *cpus_used;
+	uint16_t *cores_per_socket;
+	uint64_t *memory_allocated;
+	uint64_t *memory_used;
+	uint32_t  nhosts;
+	bitstr_t *node_bitmap;
+	uint32_t  node_req;
+	char	 *nodes;
+	uint32_t  ncpus;
+	uint32_t *sock_core_rep_count;
+	uint16_t *sockets_per_node;
+	uint8_t   whole_node;
 };
 
 /*
