@@ -35,24 +35,19 @@
  *  Refer to "list.h" for documentation on public functions.
  *****************************************************************************/
 
-
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif /* HAVE_CONFIG_H */
-
-#ifdef WITH_PTHREADS
-#  include <pthread.h>
-#endif /* WITH_PTHREADS */
+#include "config.h"
 
 #include <assert.h>
 #include <errno.h>
+#include <pthread.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
 #include "list.h"
+#include "log.h"
 #include "macros.h"
 #include "xmalloc.h"
-#include "src/common/log.h"
 
 /*
 ** Define slurm-specific aliases for use by plugins, see slurm_xlator.h
@@ -85,41 +80,6 @@ strong_alias(list_find,		slurm_list_find);
 strong_alias(list_remove,	slurm_list_remove);
 strong_alias(list_delete_item,	slurm_list_delete_item);
 strong_alias(list_install_fork_handlers, slurm_list_install_fork_handlers);
-/*********************
- *  lsd_fatal_error  *
- *********************/
-
-#include <unistd.h>
-#ifdef WITH_LSD_FATAL_ERROR_FUNC
-#  undef lsd_fatal_error
-extern void lsd_fatal_error(char *file, int line, char *mesg);
-#else /* !WITH_LSD_FATAL_ERROR_FUNC */
-#  ifndef lsd_fatal_error
-static void lsd_fatal_error(char *file, int line, char *mesg)
-{
-	log_fatal(file, line, mesg, strerror(errno));
-}
-#  endif /* !lsd_fatal_error */
-#endif /* !WITH_LSD_FATAL_ERROR_FUNC */
-
-/*********************
- *  lsd_nomem_error  *
- *********************/
-
-#ifdef WITH_LSD_NOMEM_ERROR_FUNC
-#  undef lsd_nomem_error
-extern void * lsd_nomem_error(char *file, int line, char *mesg);
-#else /* !WITH_LSD_NOMEM_ERROR_FUNC */
-#  ifndef lsd_nomem_error
-static void * lsd_nomem_error(char *file, int line, char *mesg)
-{
-
-	log_oom(file, line, mesg);
-	abort();
-	return NULL;
-}
-#  endif /* !lsd_nomem_error */
-#endif /* !WITH_LSD_NOMEM_ERROR_FUNC */
 
 
 /***************
@@ -174,9 +134,7 @@ struct list {
 	struct listIterator  *iNext;        /* iterator chain for list_destroy() */
 	ListDelF              fDel;         /* function to delete node data      */
 	int                   count;        /* number of nodes in list           */
-#ifdef WITH_PTHREADS
 	pthread_mutex_t       mutex;        /* mutex to protect access to list   */
-#endif /* WITH_PTHREADS */
 #ifndef NDEBUG
 	unsigned int          magic;        /* sentinel for asserting validity   */
 #endif /* !NDEBUG */
@@ -202,6 +160,10 @@ static void list_free_aux (void *x, void *pfreelist);
 static void *_list_pop_locked(List l);
 static void *_list_append_locked(List l, void *x);
 
+#ifndef NDEBUG
+static int _list_mutex_is_locked (pthread_mutex_t *mutex);
+#endif
+
 /***************
  *  Variables  *
  ***************/
@@ -210,71 +172,7 @@ static List list_free_lists = NULL;
 static ListNode list_free_nodes = NULL;
 static ListIterator list_free_iterators = NULL;
 
-#ifdef WITH_PTHREADS
 static pthread_mutex_t list_free_lock = PTHREAD_MUTEX_INITIALIZER;
-#endif /* WITH_PTHREADS */
-
-
-/************
- *  Macros  *
- ************/
-
-#ifdef WITH_PTHREADS
-
-#  define list_mutex_init(mutex)	  \
-	do { \
-		int e = pthread_mutex_init(mutex, NULL); \
-		if (e != 0) { \
-			errno = e; \
-			lsd_fatal_error(__FILE__, __LINE__, "list mutex init"); \
-			abort(); \
-		} \
-	} while (0)
-
-#  define list_mutex_lock(mutex)	  \
-	do { \
-		int e = pthread_mutex_lock(mutex); \
-		if (e != 0) { \
-			errno = e; \
-			lsd_fatal_error(__FILE__, __LINE__, "list mutex lock"); \
-			abort(); \
-		} \
-	} while (0)
-
-#  define list_mutex_unlock(mutex)	  \
-	do { \
-		int e = pthread_mutex_unlock(mutex); \
-		if (e != 0) { \
-			errno = e; \
-			lsd_fatal_error(__FILE__, __LINE__, "list mutex unlock"); \
-			abort(); \
-		} \
-	} while (0)
-
-#  define list_mutex_destroy(mutex)	  \
-	do { \
-		int e = pthread_mutex_destroy(mutex); \
-		if (e != 0) { \
-			errno = e; \
-			lsd_fatal_error(__FILE__, __LINE__, "list mutex destroy"); \
-			abort(); \
-		} \
-	} while (0)
-
-#  ifndef NDEBUG
-static int list_mutex_is_locked (pthread_mutex_t *mutex);
-#  endif /* !NDEBUG */
-
-#else /* !WITH_PTHREADS */
-
-#  define list_mutex_init(mutex)
-#  define list_mutex_lock(mutex)
-#  define list_mutex_unlock(mutex)
-#  define list_mutex_destroy(mutex)
-#  define list_mutex_is_locked(mutex) (1)
-
-#endif /* !WITH_PTHREADS */
-
 
 /***************
  *  Functions  *
@@ -285,17 +183,14 @@ static int list_mutex_is_locked (pthread_mutex_t *mutex);
 List
 list_create (ListDelF f)
 {
-	List l;
-
-	if (!(l = list_alloc()))
-		return(lsd_nomem_error(__FILE__, __LINE__, "list create"));
+	List l = list_alloc();
 
 	l->head = NULL;
 	l->tail = &l->head;
 	l->iNext = NULL;
 	l->fDel = f;
 	l->count = 0;
-	list_mutex_init(&l->mutex);
+	slurm_mutex_init(&l->mutex);
 	assert(l->magic = LIST_MAGIC);      /* set magic via assert abuse */
 
 	return l;
@@ -310,7 +205,7 @@ list_destroy (List l)
 	ListNode p, pTmp;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	i = l->iNext;
@@ -330,8 +225,8 @@ list_destroy (List l)
 		p = pTmp;
 	}
 	assert(l->magic = ~LIST_MAGIC);     /* clear magic via assert abuse */
-	list_mutex_unlock(&l->mutex);
-	list_mutex_destroy(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
+	slurm_mutex_destroy(&l->mutex);
 	list_free(l);
 }
 
@@ -343,10 +238,10 @@ list_is_empty (List l)
 	int n;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 	n = l->count;
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return (n == 0);
 }
@@ -359,10 +254,10 @@ list_count (List l)
 	int n;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 	n = l->count;
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return n;
 }
@@ -376,10 +271,10 @@ list_append (List l, void *x)
 
 	assert(l != NULL);
 	assert(x != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 	v = _list_append_locked(l, x);
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -441,11 +336,11 @@ list_prepend (List l, void *x)
 
 	assert(l != NULL);
 	assert(x != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	v = list_node_create(l, &l->head, x);
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -461,7 +356,7 @@ list_find_first (List l, ListFindF f, void *key)
 	assert(l != NULL);
 	assert(f != NULL);
 	assert(key != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	for (p = l->head; p; p = p->next) {
@@ -470,7 +365,7 @@ list_find_first (List l, ListFindF f, void *key)
 			break;
 		}
 	}
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -486,7 +381,7 @@ list_delete_all (List l, ListFindF f, void *key)
 
 	assert(l != NULL);
 	assert(f != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	pp = &l->head;
@@ -502,7 +397,7 @@ list_delete_all (List l, ListFindF f, void *key)
 			pp = &(*pp)->next;
 		}
 	}
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return n;
 }
@@ -517,7 +412,7 @@ list_for_each (List l, ListForF f, void *arg)
 
 	assert(l != NULL);
 	assert(f != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	for (p = l->head; p; p = p->next) {
@@ -527,7 +422,7 @@ list_for_each (List l, ListForF f, void *arg)
 			break;
 		}
 	}
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return n;
 }
@@ -542,7 +437,7 @@ list_flush (List l)
 	int n = 0;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	pp = &l->head;
@@ -553,7 +448,7 @@ list_flush (List l)
 			n++;
 		}
 	}
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return n;
 }
@@ -567,11 +462,11 @@ list_push (List l, void *x)
 
 	assert(l != NULL);
 	assert(x != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	v = list_node_create(l, &l->head, x);
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -593,20 +488,15 @@ list_sort(List l, ListCmpF f)
 	assert(l != NULL);
 	assert(f != NULL);
 	assert(l->magic == LIST_MAGIC);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 
 	if (l->count <= 1) {
-		list_mutex_unlock(&l->mutex);
+		slurm_mutex_unlock(&l->mutex);
 		return;
 	}
 
 	lsize = l->count;
 	v = xmalloc(lsize * sizeof(char *));
-	if (v == NULL) {
-		list_mutex_unlock(&l->mutex);
-		lsd_nomem_error(__FILE__, __LINE__, "list_sort");
-		return;
-	}
 
 	n = 0;
 	while ((e = _list_pop_locked(l))) {
@@ -631,7 +521,7 @@ list_sort(List l, ListCmpF f)
 		i->prev = &i->list->head;
 	}
 
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 }
 
 /* list_pop()
@@ -642,11 +532,11 @@ list_pop (List l)
 	void *v;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	v = _list_pop_locked(l);
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -659,11 +549,11 @@ list_peek (List l)
 	void *v;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	v = (l->head) ? l->head->data : NULL;
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -677,11 +567,11 @@ list_enqueue (List l, void *x)
 
 	assert(l != NULL);
 	assert(x != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	v = list_node_create(l, l->tail, x);
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -694,11 +584,11 @@ list_dequeue (List l)
 	void *v;
 
 	assert(l != NULL);
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	v = list_node_destroy(l, &l->head);
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return v;
 }
@@ -711,11 +601,10 @@ list_iterator_create (List l)
 	ListIterator i;
 
 	assert(l != NULL);
-	if (!(i = list_iterator_alloc()))
-		return(lsd_nomem_error(__FILE__, __LINE__, "list iterator create"));
+	i = list_iterator_alloc();
 
 	i->list = l;
-	list_mutex_lock(&l->mutex);
+	slurm_mutex_lock(&l->mutex);
 	assert(l->magic == LIST_MAGIC);
 
 	i->pos = l->head;
@@ -724,7 +613,7 @@ list_iterator_create (List l)
 	l->iNext = i;
 	assert(i->magic = LIST_MAGIC);      /* set magic via assert abuse */
 
-	list_mutex_unlock(&l->mutex);
+	slurm_mutex_unlock(&l->mutex);
 
 	return i;
 }
@@ -736,13 +625,13 @@ list_iterator_reset (ListIterator i)
 {
 	assert(i != NULL);
 	assert(i->magic == LIST_MAGIC);
-	list_mutex_lock(&i->list->mutex);
+	slurm_mutex_lock(&i->list->mutex);
 	assert(i->list->magic == LIST_MAGIC);
 
 	i->pos = i->list->head;
 	i->prev = &i->list->head;
 
-	list_mutex_unlock(&i->list->mutex);
+	slurm_mutex_unlock(&i->list->mutex);
 }
 
 /* list_iterator_destroy()
@@ -754,7 +643,7 @@ list_iterator_destroy (ListIterator i)
 
 	assert(i != NULL);
 	assert(i->magic == LIST_MAGIC);
-	list_mutex_lock(&i->list->mutex);
+	slurm_mutex_lock(&i->list->mutex);
 	assert(i->list->magic == LIST_MAGIC);
 
 	for (pi = &i->list->iNext; *pi; pi = &(*pi)->iNext) {
@@ -764,7 +653,7 @@ list_iterator_destroy (ListIterator i)
 			break;
 		}
 	}
-	list_mutex_unlock(&i->list->mutex);
+	slurm_mutex_unlock(&i->list->mutex);
 
 	assert(i->magic = ~LIST_MAGIC);     /* clear magic via assert abuse */
 	list_iterator_free(i);
@@ -779,7 +668,7 @@ list_next (ListIterator i)
 
 	assert(i != NULL);
 	assert(i->magic == LIST_MAGIC);
-	list_mutex_lock(&i->list->mutex);
+	slurm_mutex_lock(&i->list->mutex);
 	assert(i->list->magic == LIST_MAGIC);
 
 	if ((p = i->pos))
@@ -787,7 +676,7 @@ list_next (ListIterator i)
 	if (*i->prev != p)
 		i->prev = &(*i->prev)->next;
 
-	list_mutex_unlock(&i->list->mutex);
+	slurm_mutex_unlock(&i->list->mutex);
 
 	return (p ? p->data : NULL);
 }
@@ -801,12 +690,12 @@ list_peek_next (ListIterator i)
 
 	assert(i != NULL);
 	assert(i->magic == LIST_MAGIC);
-	list_mutex_lock(&i->list->mutex);
+	slurm_mutex_lock(&i->list->mutex);
 	assert(i->list->magic == LIST_MAGIC);
 
 	p = i->pos;
 
-	list_mutex_unlock(&i->list->mutex);
+	slurm_mutex_unlock(&i->list->mutex);
 
 	return (p ? p->data : NULL);
 }
@@ -821,11 +710,11 @@ list_insert (ListIterator i, void *x)
 	assert(i != NULL);
 	assert(x != NULL);
 	assert(i->magic == LIST_MAGIC);
-	list_mutex_lock(&i->list->mutex);
+	slurm_mutex_lock(&i->list->mutex);
 	assert(i->list->magic == LIST_MAGIC);
 
 	v = list_node_create(i->list, i->prev, x);
-	list_mutex_unlock(&i->list->mutex);
+	slurm_mutex_unlock(&i->list->mutex);
 
 	return v;
 }
@@ -856,12 +745,12 @@ list_remove (ListIterator i)
 
 	assert(i != NULL);
 	assert(i->magic == LIST_MAGIC);
-	list_mutex_lock(&i->list->mutex);
+	slurm_mutex_lock(&i->list->mutex);
 	assert(i->list->magic == LIST_MAGIC);
 
 	if (*i->prev != i->pos)
 		v = list_node_destroy(i->list, i->prev);
-	list_mutex_unlock(&i->list->mutex);
+	slurm_mutex_unlock(&i->list->mutex);
 
 	return v;
 }
@@ -900,12 +789,11 @@ list_node_create (List l, ListNode *pp, void *x)
 
 	assert(l != NULL);
 	assert(l->magic == LIST_MAGIC);
-	assert(list_mutex_is_locked(&l->mutex));
+	assert(_list_mutex_is_locked(&l->mutex));
 	assert(pp != NULL);
 	assert(x != NULL);
 
-	if (!(p = list_node_alloc()))
-		return(lsd_nomem_error(__FILE__, __LINE__, "list node create"));
+	p = list_node_alloc();
 
 	p->data = x;
 	if (!(p->next = *pp))
@@ -943,7 +831,7 @@ list_node_destroy (List l, ListNode *pp)
 
 	assert(l != NULL);
 	assert(l->magic == LIST_MAGIC);
-	assert(list_mutex_is_locked(&l->mutex));
+	assert(_list_mutex_is_locked(&l->mutex));
 	assert(pp != NULL);
 
 	if (!(p = *pp))
@@ -1033,7 +921,7 @@ list_alloc_aux (int size, void *pfreelist)
 	assert(size >= sizeof(void *));
 	assert(pfreelist != NULL);
 	assert(LIST_ALLOC > 0);
-	list_mutex_lock(&list_free_lock);
+	slurm_mutex_lock(&list_free_lock);
 
 	if (!*pfree) {
 		if ((*pfree = xmalloc(LIST_ALLOC * size))) {
@@ -1048,7 +936,7 @@ list_alloc_aux (int size, void *pfreelist)
 		*pfree = *px;
 	else
 		errno = ENOMEM;
-	list_mutex_unlock(&list_free_lock);
+	slurm_mutex_unlock(&list_free_lock);
 
 	return px;
 }
@@ -1068,41 +956,30 @@ list_free_aux (void *x, void *pfreelist)
 
 	assert(x != NULL);
 	assert(pfreelist != NULL);
-	list_mutex_lock(&list_free_lock);
+	slurm_mutex_lock(&list_free_lock);
 
 	*px = *pfree;
 	*pfree = px;
 
-	list_mutex_unlock(&list_free_lock);
+	slurm_mutex_unlock(&list_free_lock);
 #endif
 }
 
-#ifdef WITH_PTHREADS
 static void
 list_reinit_mutexes (void)
 {
-	list_mutex_init(&list_free_lock);
+	slurm_mutex_init(&list_free_lock);
 }
 
 void list_install_fork_handlers (void)
 {
-	int err;
-	if ((err = pthread_atfork(NULL, NULL, &list_reinit_mutexes))) {
-		lsd_fatal_error(__FILE__, __LINE__, "list atfork install");
-		abort();
-	}
+	if (pthread_atfork(NULL, NULL, &list_reinit_mutexes))
+		fatal("cannot install list atfork handler");
 }
-#else
-void list_install_fork_handlers (void)
-{
-	return;
-}
-#endif
 
 #ifndef NDEBUG
-#ifdef WITH_PTHREADS
 static int
-list_mutex_is_locked (pthread_mutex_t *mutex)
+_list_mutex_is_locked (pthread_mutex_t *mutex)
 {
 /*  Returns true if the mutex is locked; o/w, returns false.
  */
@@ -1112,7 +989,6 @@ list_mutex_is_locked (pthread_mutex_t *mutex)
 	rc = pthread_mutex_trylock(mutex);
 	return(rc == EBUSY ? 1 : 0);
 }
-#endif /* WITH_PTHREADS */
 #endif /* !NDEBUG */
 
 /* _list_pop_locked
