@@ -6,7 +6,7 @@
  *  Written by Bull-HN-PHX/d.rusak,
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -113,7 +113,7 @@ static void *_watch_node(void *arg)
 		slurm_mutex_unlock(&g_context_lock);
 
 		slurm_mutex_lock(&acct_gather_profile_timer[type].notify_mutex);
-		pthread_cond_wait(
+		slurm_cond_wait(
 			&acct_gather_profile_timer[type].notify,
 			&acct_gather_profile_timer[type].notify_mutex);
 		slurm_mutex_unlock(&acct_gather_profile_timer[type].
@@ -198,7 +198,7 @@ extern void acct_gather_energy_destroy(acct_gather_energy_t *energy)
 extern void acct_gather_energy_pack(acct_gather_energy_t *energy, Buf buffer,
 				    uint16_t protocol_version)
 {
-	if (protocol_version >= SLURM_15_08_PROTOCOL_VERSION) {
+	if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
 		if (!energy) {
 			pack64(0, buffer);
 			pack32(0, buffer);
@@ -215,28 +215,12 @@ extern void acct_gather_energy_pack(acct_gather_energy_t *energy, Buf buffer,
 		pack32(energy->current_watts, buffer);
 		pack64(energy->previous_consumed_energy, buffer);
 		pack_time(energy->poll_time, buffer);
-	} else if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
-		if (!energy) {
-			int i;
-			for (i=0; i<5; i++)
-				pack32(0, buffer);
-			pack_time(0, buffer);
-			return;
-		}
-
-		pack32((uint32_t) energy->base_consumed_energy, buffer);
-		pack32(energy->base_watts, buffer);
-		pack32((uint32_t) energy->consumed_energy, buffer);
-		pack32(energy->current_watts, buffer);
-		pack32((uint32_t) energy->previous_consumed_energy, buffer);
-		pack_time(energy->poll_time, buffer);
 	}
 }
 
 extern int acct_gather_energy_unpack(acct_gather_energy_t **energy, Buf buffer,
 				     uint16_t protocol_version, bool need_alloc)
 {
-	uint32_t uint32_tmp;
 	acct_gather_energy_t *energy_ptr;
 
 	if (need_alloc) {
@@ -246,23 +230,13 @@ extern int acct_gather_energy_unpack(acct_gather_energy_t **energy, Buf buffer,
 		energy_ptr = *energy;
 	}
 
-	if (protocol_version >= SLURM_15_08_PROTOCOL_VERSION) {
+	if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
 		safe_unpack64(&energy_ptr->base_consumed_energy, buffer);
 		safe_unpack32(&energy_ptr->base_watts, buffer);
 		safe_unpack64(&energy_ptr->consumed_energy, buffer);
 		safe_unpack32(&energy_ptr->current_watts, buffer);
 		safe_unpack64(&energy_ptr->previous_consumed_energy, buffer);
 		safe_unpack_time(&energy_ptr->poll_time, buffer);
-	} else if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
-		safe_unpack32(&uint32_tmp, buffer);
-		energy_ptr->base_consumed_energy = (uint64_t) uint32_tmp;
-		safe_unpack32(&energy_ptr->base_watts, buffer);
-		safe_unpack32(&uint32_tmp, buffer);
-		energy_ptr->consumed_energy = (uint64_t) uint32_tmp;
-		safe_unpack32(&energy_ptr->current_watts, buffer);
-		safe_unpack32(&uint32_tmp, buffer);
-		energy_ptr->previous_consumed_energy = (uint64_t) uint32_tmp;
-		safe_unpack_time(&energy_ptr->poll_time, buffer);
 	}
 
 	return SLURM_SUCCESS;
