@@ -8,7 +8,7 @@
  *  Written by Rod Schultz <rod.schultz@bull.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com>.
+ *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -53,15 +53,14 @@
 #include "src/common/plugin.h"
 #include "src/common/plugrack.h"
 #include "src/common/read_config.h"
-#include "src/common/slurm_protocol_api.h"
-#include "src/common/xmalloc.h"
-#include "src/common/xstring.h"
+#include "src/common/slurm_acct_gather_infiniband.h"
 #include "src/common/slurm_acct_gather_profile.h"
 #include "src/common/slurm_acct_gather_energy.h"
 #include "src/common/slurm_jobacct_gather.h"
-#include "src/common/slurm_acct_gather_infiniband.h"
-#include "src/common/slurm_strcasestr.h"
+#include "src/common/slurm_protocol_api.h"
 #include "src/common/timers.h"
+#include "src/common/xmalloc.h"
+#include "src/common/xstring.h"
 
 /* These 2 should remain the same. */
 #define SLEEP_TIME 1
@@ -178,7 +177,7 @@ static void *_timer_thread(void *args)
 			/* signal poller to start */
 			slurm_mutex_lock(&acct_gather_profile_timer[i].
 					 notify_mutex);
-			pthread_cond_signal(
+			slurm_cond_signal(
 				&acct_gather_profile_timer[i].notify);
 			slurm_mutex_unlock(&acct_gather_profile_timer[i].
 					   notify_mutex);
@@ -312,20 +311,20 @@ extern uint32_t acct_gather_profile_from_string(char *profile_str)
 	uint32_t profile = ACCT_GATHER_PROFILE_NOT_SET;
 
         if (!profile_str) {
-	} else if (slurm_strcasestr(profile_str, "none"))
+	} else if (xstrcasestr(profile_str, "none"))
 		profile = ACCT_GATHER_PROFILE_NONE;
-	else if (slurm_strcasestr(profile_str, "all"))
+	else if (xstrcasestr(profile_str, "all"))
 		profile = ACCT_GATHER_PROFILE_ALL;
 	else {
-		if (slurm_strcasestr(profile_str, "energy"))
+		if (xstrcasestr(profile_str, "energy"))
 			profile |= ACCT_GATHER_PROFILE_ENERGY;
-		if (slurm_strcasestr(profile_str, "task"))
+		if (xstrcasestr(profile_str, "task"))
 			profile |= ACCT_GATHER_PROFILE_TASK;
 
-		if (slurm_strcasestr(profile_str, "lustre"))
+		if (xstrcasestr(profile_str, "lustre"))
 			profile |= ACCT_GATHER_PROFILE_LUSTRE;
 
-		if (slurm_strcasestr(profile_str, "network"))
+		if (xstrcasestr(profile_str, "network"))
 			profile |= ACCT_GATHER_PROFILE_NETWORK;
 	}
 
@@ -446,7 +445,7 @@ extern int acct_gather_profile_startpoll(char *freq, char *freq_def)
 	for (i=0; i < PROFILE_CNT; i++) {
 		memset(&acct_gather_profile_timer[i], 0,
 		       sizeof(acct_gather_profile_timer_t));
-		pthread_cond_init(&acct_gather_profile_timer[i].notify, NULL);
+		slurm_cond_init(&acct_gather_profile_timer[i].notify, NULL);
 		slurm_mutex_init(&acct_gather_profile_timer[i].notify_mutex);
 
 		switch (i) {
@@ -523,9 +522,8 @@ extern void acct_gather_profile_endpoll(void)
 	for (i=0; i < PROFILE_CNT; i++) {
 		/* end remote threads */
 		slurm_mutex_lock(&acct_gather_profile_timer[i].notify_mutex);
-		pthread_cond_signal(&acct_gather_profile_timer[i].notify);
+		slurm_cond_signal(&acct_gather_profile_timer[i].notify);
 		slurm_mutex_unlock(&acct_gather_profile_timer[i].notify_mutex);
-		pthread_cond_destroy(&acct_gather_profile_timer[i].notify);
 		acct_gather_profile_timer[i].freq = 0;
 		switch (i) {
 		case PROFILE_ENERGY:
