@@ -3,13 +3,13 @@
  *****************************************************************************
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
- *  Portions Copyright (C) 2015 SchedMD <http://www.schedmd.com>.
+ *  Portions Copyright (C) 2015 SchedMD <https://www.schedmd.com>.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -38,19 +38,14 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include "config.h"
 
 #include <fcntl.h>
+#include <pthread.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <sys/time.h>
 
-#if WITH_PTHREADS
-#  include <pthread.h>
-#endif /* WITH_PTHREADS */
-
 #include "slurm/slurm_errno.h"
 #include "src/common/bitstring.h"
 #include "src/common/gres.h"
@@ -141,9 +136,7 @@ struct slurm_cred_context {
 #  define CRED_CTX_MAGIC 0x0c0c0c
 	int magic;
 #endif
-#if WITH_PTHREADS
 	pthread_mutex_t mutex;
-#endif
 	enum ctx_type  type;       /* type of context (creator or verifier) */
 	void          *key;        /* private or public key                 */
 	List           job_list;   /* List of used jobids (for verifier)    */
@@ -164,17 +157,15 @@ struct slurm_job_credential {
 #  define CRED_MAGIC 0x0b0b0b
 	int      magic;
 #endif
-#ifdef  WITH_PTHREADS
 	pthread_mutex_t mutex;
-#endif
 	uint32_t  jobid;	/* Job ID associated with this cred	*/
 	uint32_t  stepid;	/* Job step ID for this credential	*/
 	uid_t     uid;		/* user for which this cred is valid	*/
 
-	uint32_t  job_mem_limit;/* MB of memory reserved per node OR
+	uint64_t  job_mem_limit;/* MB of memory reserved per node OR
 				 * real memory per CPU | MEM_PER_CPU,
 				 * default=0 (no limit) */
-	uint32_t  step_mem_limit;
+	uint64_t  step_mem_limit;
 
 	uint16_t  core_array_size;	/* core/socket array size */
 	uint16_t *cores_per_socket;
@@ -294,10 +285,6 @@ static void _cred_state_pack_one(cred_state_t *s, Buf buffer);
 static void _sbast_cache_add(sbcast_cred_t *sbcast_cred);
 static void _sbcast_cache_del(void *x);
 
-#ifndef DISABLE_LOCALTIME
-static char * timestr (const time_t *tp, char *buf, size_t n);
-#endif
-
 static int _slurm_crypto_init(void)
 {
 	char	*auth_info, *tok;
@@ -1130,7 +1117,7 @@ static char *_core_format(bitstr_t *core_bitmap)
  */
 void format_core_allocs(slurm_cred_t *cred, char *node_name, uint16_t cpus,
 			char **job_alloc_cores, char **step_alloc_cores,
-			uint32_t *job_mem_limit, uint32_t *step_mem_limit)
+			uint64_t *job_mem_limit, uint64_t *step_mem_limit)
 {
 #ifdef HAVE_BG
 	xassert(cred);
@@ -1267,12 +1254,12 @@ extern void get_cred_gres(slurm_cred_t *cred, char *node_name,
 #else
 	host_index = hostset_find(hset, node_name);
 #endif
+	hostset_destroy(hset);
 	if ((host_index < 0) || (host_index >= cred->job_nhosts)) {
 		error("Invalid host_index %d for job %u",
 		      host_index, cred->jobid);
 		error("Host %s not in credential hostlist %s",
 		      node_name, cred->job_hostlist);
-		hostset_destroy(hset);
 		return;
 	}
 
@@ -1305,7 +1292,6 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 {
 	uint32_t     cred_uid, len;
 	slurm_cred_t *cred = NULL;
-	char        *bit_fmt = NULL;
 	char       **sigp;
 	uint32_t     cluster_flags = slurmdb_setup_cluster_flags();
 
@@ -1313,7 +1299,7 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 
 	cred = _slurm_cred_alloc();
 	slurm_mutex_lock(&cred->mutex);
-	if (protocol_version >= SLURM_15_08_PROTOCOL_VERSION) {
+	if (protocol_version >= SLURM_17_02_PROTOCOL_VERSION) {
 		safe_unpack32(&cred->jobid, buffer);
 		safe_unpack32(&cred->stepid, buffer);
 		safe_unpack32(&cred_uid, buffer);
@@ -1330,8 +1316,8 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 			goto unpack_error;
 		}
 		safe_unpack16(&cred->job_core_spec, buffer);
-		safe_unpack32(&cred->job_mem_limit, buffer);
-		safe_unpack32(&cred->step_mem_limit, buffer);
+		safe_unpack64(&cred->job_mem_limit, buffer);
+		safe_unpack64(&cred->step_mem_limit, buffer);
 		safe_unpackstr_xmalloc(&cred->job_constraints, &len, buffer);
 		safe_unpackstr_xmalloc(&cred->step_hostlist, &len, buffer);
 		safe_unpack_time(&cred->ctime, buffer);
@@ -1339,18 +1325,8 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 		if (!(cluster_flags & CLUSTER_FLAG_BG)) {
 			uint32_t tot_core_cnt;
 			safe_unpack32(&tot_core_cnt, buffer);
-			safe_unpackstr_xmalloc(&bit_fmt, &len, buffer);
-			cred->job_core_bitmap =
-				bit_alloc((bitoff_t) tot_core_cnt);
-			if (bit_unfmt(cred->job_core_bitmap, bit_fmt))
-				goto unpack_error;
-			xfree(bit_fmt);
-			safe_unpackstr_xmalloc(&bit_fmt, &len, buffer);
-			cred->step_core_bitmap =
-				bit_alloc((bitoff_t) tot_core_cnt);
-			if (bit_unfmt(cred->step_core_bitmap, bit_fmt))
-				goto unpack_error;
-			xfree(bit_fmt);
+			unpack_bit_str_hex(&cred->job_core_bitmap, buffer);
+			unpack_bit_str_hex(&cred->step_core_bitmap, buffer);
 			safe_unpack16(&cred->core_array_size, buffer);
 			if (cred->core_array_size) {
 				safe_unpack16_array(&cred->cores_per_socket,
@@ -1378,7 +1354,8 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 		safe_unpackmem_xmalloc(sigp, &len, buffer);
 		cred->siglen = len;
 		xassert(len > 0);
-	} else if (protocol_version >= SLURM_14_11_PROTOCOL_VERSION) {
+	} else if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
+		uint32_t tmp_mem;
 		safe_unpack32(&cred->jobid, buffer);
 		safe_unpack32(&cred->stepid, buffer);
 		safe_unpack32(&cred_uid, buffer);
@@ -1395,13 +1372,17 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 			goto unpack_error;
 		}
 		safe_unpack16(&cred->job_core_spec, buffer);
-		safe_unpack32(&cred->job_mem_limit, buffer);
-		safe_unpack32(&cred->step_mem_limit, buffer);
+		safe_unpack32(&tmp_mem, buffer);
+		cred->job_mem_limit = xlate_mem_old2new(tmp_mem);
+		safe_unpack32(&tmp_mem, buffer);
+		cred->step_mem_limit = xlate_mem_old2new(tmp_mem);
+		safe_unpackstr_xmalloc(&cred->job_constraints, &len, buffer);
 		safe_unpackstr_xmalloc(&cred->step_hostlist, &len, buffer);
 		safe_unpack_time(&cred->ctime, buffer);
 
 		if (!(cluster_flags & CLUSTER_FLAG_BG)) {
 			uint32_t tot_core_cnt;
+			char *bit_fmt = NULL;
 			safe_unpack32(&tot_core_cnt, buffer);
 			safe_unpackstr_xmalloc(&bit_fmt, &len, buffer);
 			cred->job_core_bitmap =
@@ -1517,8 +1498,8 @@ slurm_cred_print(slurm_cred_t *cred)
 	info("Cred: UID               %u",  (uint32_t) cred->uid);
 	info("Cred: Job_constraints   %s",  cred->job_constraints );
 	info("Cred: Job_core_spec     %d %s", spec_count, spec_type );
-	info("Cred: Job_mem_limit     %u",  cred->job_mem_limit );
-	info("Cred: Step_mem_limit    %u",  cred->step_mem_limit );
+	info("Cred: Job_mem_limit     %"PRIu64"",  cred->job_mem_limit );
+	info("Cred: Step_mem_limit    %"PRIu64"",  cred->step_mem_limit );
 	info("Cred: Step hostlist     %s",  cred->step_hostlist );
 	info("Cred: ctime             %s",  slurm_ctime2(&cred->ctime) );
 	info("Cred: siglen            %u",  cred->siglen        );
@@ -1745,7 +1726,7 @@ _pack_cred(slurm_cred_t *cred, Buf buffer, uint16_t protocol_version)
 {
 	uint32_t cred_uid = (uint32_t) cred->uid;
 
-	if (protocol_version >= SLURM_15_08_PROTOCOL_VERSION) {
+	if (protocol_version >= SLURM_17_02_PROTOCOL_VERSION) {
 		pack32(cred->jobid,          buffer);
 		pack32(cred->stepid,         buffer);
 		pack32(cred_uid,             buffer);
@@ -1757,8 +1738,49 @@ _pack_cred(slurm_cred_t *cred, Buf buffer, uint16_t protocol_version)
 					    cred->jobid, cred->stepid,
 					    protocol_version);
 		pack16(cred->job_core_spec,  buffer);
-		pack32(cred->job_mem_limit,  buffer);
-		pack32(cred->step_mem_limit, buffer);
+		pack64(cred->job_mem_limit,  buffer);
+		pack64(cred->step_mem_limit, buffer);
+		packstr(cred->job_constraints, buffer);
+		packstr(cred->step_hostlist, buffer);
+		pack_time(cred->ctime,       buffer);
+#ifndef HAVE_BG
+		{
+			uint32_t tot_core_cnt = 0;
+			if (cred->job_core_bitmap)
+				tot_core_cnt = bit_size(cred->job_core_bitmap);
+			pack32(tot_core_cnt, buffer);
+			pack_bit_str_hex(cred->job_core_bitmap, buffer);
+			pack_bit_str_hex(cred->step_core_bitmap, buffer);
+			pack16(cred->core_array_size, buffer);
+			if (cred->core_array_size) {
+				pack16_array(cred->cores_per_socket,
+					     cred->core_array_size,
+					     buffer);
+				pack16_array(cred->sockets_per_node,
+					     cred->core_array_size,
+					     buffer);
+				pack32_array(cred->sock_core_rep_count,
+					     cred->core_array_size,
+					     buffer);
+			}
+			pack32(cred->job_nhosts,    buffer);
+			packstr(cred->job_hostlist, buffer);
+		}
+#endif
+	} else if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
+		pack32(cred->jobid,          buffer);
+		pack32(cred->stepid,         buffer);
+		pack32(cred_uid,             buffer);
+
+		(void) gres_plugin_job_state_pack(cred->job_gres_list, buffer,
+						  cred->jobid, false,
+						  protocol_version);
+		gres_plugin_step_state_pack(cred->step_gres_list, buffer,
+					    cred->jobid, cred->stepid,
+					    protocol_version);
+		pack16(cred->job_core_spec,  buffer);
+		pack32(xlate_mem_new2old(cred->job_mem_limit),  buffer);
+		pack32(xlate_mem_new2old(cred->step_mem_limit), buffer);
 		packstr(cred->job_constraints, buffer);
 		packstr(cred->step_hostlist, buffer);
 		pack_time(cred->ctime,       buffer);
@@ -1785,68 +1807,30 @@ _pack_cred(slurm_cred_t *cred, Buf buffer, uint16_t protocol_version)
 			pack32(cred->job_nhosts,    buffer);
 			packstr(cred->job_hostlist, buffer);
 		}
-#endif
-	} else {
-		pack32(cred->jobid,          buffer);
-		pack32(cred->stepid,         buffer);
-		pack32(cred_uid,             buffer);
-
-		(void) gres_plugin_job_state_pack(cred->job_gres_list, buffer,
-						  cred->jobid, false,
-						  protocol_version);
-		gres_plugin_step_state_pack(cred->step_gres_list, buffer,
-					    cred->jobid, cred->stepid,
-					    protocol_version);
-		pack16(cred->job_core_spec,  buffer);
-		pack32(cred->job_mem_limit,  buffer);
-		pack32(cred->step_mem_limit, buffer);
-		packstr(cred->step_hostlist, buffer);
-		pack_time(cred->ctime,       buffer);
-#ifndef HAVE_BG
-		{
-			uint32_t tot_core_cnt;
-			tot_core_cnt = bit_size(cred->job_core_bitmap);
-			pack32(tot_core_cnt, buffer);
-			pack_bit_fmt(cred->job_core_bitmap, buffer);
-			pack_bit_fmt(cred->step_core_bitmap, buffer);
-			pack16(cred->core_array_size, buffer);
-			if (cred->core_array_size) {
-				pack16_array(cred->cores_per_socket,
-					     cred->core_array_size,
-					     buffer);
-				pack16_array(cred->sockets_per_node,
-					     cred->core_array_size,
-					     buffer);
-				pack32_array(cred->sock_core_rep_count,
-					     cred->core_array_size,
-					     buffer);
-			}
-			pack32(cred->job_nhosts,    buffer);
-			packstr(cred->job_hostlist, buffer);
-		}
 #endif
 	}
 }
 
+static int _list_find_cred_state(void *x, void *key)
+{
+	cred_state_t *s = (cred_state_t *) x;
+	slurm_cred_t *cred = (slurm_cred_t *) key;
+	if ((s->jobid  == cred->jobid)  &&
+	    (s->stepid == cred->stepid) &&
+	    (s->ctime  == cred->ctime))
+		return 1;
+	return 0;
+}
+
 
 static bool
 _credential_replayed(slurm_cred_ctx_t ctx, slurm_cred_t *cred)
 {
-	ListIterator  i = NULL;
 	cred_state_t *s = NULL;
 
 	_clear_expired_credential_states(ctx);
 
-	i = list_iterator_create(ctx->state_list);
-
-	while ((s = list_next(i))) {
-		if ((s->jobid  == cred->jobid)  &&
-		    (s->stepid == cred->stepid) &&
-		    (s->ctime  == cred->ctime))
-			break;
-	}
-
-	list_iterator_destroy(i);
+	s = list_find_first(ctx->state_list, _list_find_cred_state, cred);
 
 	/*
 	 * If we found a match, this credential is being replayed.
@@ -1861,21 +1845,11 @@ _credential_replayed(slurm_cred_ctx_t ctx, slurm_cred_t *cred)
 	return false;
 }
 
-#ifdef DISABLE_LOCALTIME
-extern char * timestr (const time_t *tp, char *buf, size_t n)
-#else
-	static char * timestr (const time_t *tp, char *buf, size_t n)
-#endif
+static char * timestr (const time_t *tp, char *buf, size_t n)
 {
 	char fmt[] = "%y%m%d%H%M%S";
 	struct tm tmval;
-#ifdef DISABLE_LOCALTIME
-	static int disabled = 0;
-	if (buf == NULL)
-		disabled = 1;
-	if (disabled)
-		return NULL;
-#endif
+
 	if (!slurm_localtime_r (tp, &tmval))
 		error ("localtime_r: %m");
 	slurm_strftime (buf, n, fmt, &tmval);
@@ -1942,19 +1916,20 @@ _credential_revoked(slurm_cred_ctx_t ctx, slurm_cred_t *cred)
 	return false;
 }
 
+static int _list_find_job_state(void *x, void *key)
+{
+	job_state_t *j = (job_state_t *) x;
+	uint32_t jobid = *(uint32_t *) key;
+	if (j->jobid == jobid)
+		return 1;
+	return 0;
+}
 
 static job_state_t *
 _find_job_state(slurm_cred_ctx_t ctx, uint32_t jobid)
 {
-	ListIterator  i = NULL;
-	job_state_t  *j = NULL;
-
-	i = list_iterator_create(ctx->job_list);
-	while ((j = list_next(i))) {
-		if (j->jobid == jobid)
-			break;
-	}
-	list_iterator_destroy(i);
+	job_state_t *j =
+		list_find_first(ctx->job_list, _list_find_job_state, &jobid);
 	return j;
 }
 
@@ -2019,7 +1994,7 @@ _clear_expired_job_states(slurm_cred_ctx_t ctx)
 		}
 		if (j->expiration) {
 			strcpy(t3, " expires:");
-			timestr(&j->revoked, (t3+9), (64-9));
+			timestr(&j->expiration, (t3+9), (64-9));
 		} else {
 			t3[0] = '\0';
 		}
@@ -2039,25 +2014,27 @@ _clear_expired_job_states(slurm_cred_ctx_t ctx)
 	list_iterator_destroy(i);
 }
 
+static int _list_find_expired(void *x, void *key)
+{
+	cred_state_t *s = (cred_state_t *)x;
+	time_t curr_time = *(time_t *)key;
+
+	if (curr_time > s->expiration)
+		return 1;
+	return 0;
+}
 
 static void
 _clear_expired_credential_states(slurm_cred_ctx_t ctx)
 {
 	static time_t last_scan = 0;
 	time_t        now = time(NULL);
-	ListIterator  i   = NULL;
-	cred_state_t *s   = NULL;
 
 	if ((now - last_scan) < 2)	/* Reduces slurmd overhead */
 		return;
 	last_scan = now;
 
-	i = list_iterator_create(ctx->state_list);
-	while ((s = list_next(i))) {
-		if (now > s->expiration)
-			list_delete_item(i);
-	}
-	list_iterator_destroy(i);
+	list_delete_all(ctx->state_list, _list_find_expired, &now);
 }
 
 
