@@ -10,7 +10,7 @@
  *  Copyright (C) 2005 Hewlett-Packard Development Company, L.P.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -241,7 +241,7 @@ static void *_watch_tasks(void *arg)
 	       acct_gather_profile_test()) {
 		/* Do this until shutdown is requested */
 		slurm_mutex_lock(&acct_gather_profile_timer[type].notify_mutex);
-		pthread_cond_wait(
+		slurm_cond_wait(
 			&acct_gather_profile_timer[type].notify,
 			&acct_gather_profile_timer[type].notify_mutex);
 		slurm_mutex_unlock(&acct_gather_profile_timer[type].
@@ -551,28 +551,29 @@ extern int jobacct_gather_set_proctrack_container_id(uint64_t id)
 	return SLURM_SUCCESS;
 }
 
-extern int jobacct_gather_set_mem_limit(uint32_t job_id, uint32_t step_id,
-					uint32_t mem_limit)
+extern int jobacct_gather_set_mem_limit(uint32_t job_id,
+					uint32_t step_id,
+					uint64_t mem_limit)
 {
 	if (!plugin_polling)
 		return SLURM_SUCCESS;
 
 	if ((job_id == 0) || (mem_limit == 0)) {
-		error("jobacct_gather_set_mem_limit: jobid:%u mem_limit:%u",
-		      job_id, mem_limit);
+		error("jobacct_gather_set_mem_limit: jobid:%u "
+		      "mem_limit:%"PRIu64"", job_id, mem_limit);
 		return SLURM_ERROR;
 	}
 
 	jobacct_job_id      = job_id;
 	jobacct_step_id     = step_id;
-	jobacct_mem_limit   = (uint64_t) mem_limit * 1024; /* MB to KB */
+	jobacct_mem_limit   = mem_limit * 1024; /* MB to KB */
 	jobacct_vmem_limit  = jobacct_mem_limit;
 	jobacct_vmem_limit *= (slurm_get_vsize_factor() / 100.0);
 	return SLURM_SUCCESS;
 }
 
-extern void jobacct_gather_handle_mem_limit(
-	uint64_t total_job_mem, uint64_t total_job_vsize)
+extern void jobacct_gather_handle_mem_limit(uint64_t total_job_mem,
+					    uint64_t total_job_vsize)
 {
 	if (!plugin_polling)
 		return;
@@ -686,7 +687,7 @@ extern int jobacctinfo_setinfo(jobacctinfo_t *jobacct,
 	double *dub = (double *) data;
 	jobacct_id_t *jobacct_id = (jobacct_id_t *) data;
 	struct jobacctinfo *send = (struct jobacctinfo *) data;
-
+	Buf buffer = NULL;
 	if (!plugin_polling)
 		return SLURM_SUCCESS;
 
@@ -697,13 +698,13 @@ extern int jobacctinfo_setinfo(jobacctinfo_t *jobacct,
 	case JOBACCT_DATA_PIPE:
 		if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
 			int len;
-			Buf buffer = init_buf(0);
+			buffer = init_buf(0);
 			jobacctinfo_pack(jobacct, protocol_version,
 					 PROTOCOL_TYPE_SLURM, buffer);
 			len = get_buf_offset(buffer);
 			safe_write(*fd, &len, sizeof(int));
 			safe_write(*fd, get_buf_data(buffer), len);
-			free_buf(buffer);
+			FREE_NULL_BUFFER(buffer);
 		}
 
 		break;
@@ -780,7 +781,9 @@ extern int jobacctinfo_setinfo(jobacctinfo_t *jobacct,
 	}
 
 	return rc;
+
 rwfail:
+	FREE_NULL_BUFFER(buffer);
 	return SLURM_ERROR;
 }
 
@@ -796,6 +799,7 @@ extern int jobacctinfo_getinfo(
 	jobacct_id_t *jobacct_id = (jobacct_id_t *) data;
 	struct rusage *rusage = (struct rusage *)data;
 	struct jobacctinfo *send = (struct jobacctinfo *) data;
+	char *buf = NULL;
 
 	if (!plugin_polling)
 		return SLURM_SUCCESS;
@@ -809,7 +813,6 @@ extern int jobacctinfo_getinfo(
 		break;
 	case JOBACCT_DATA_PIPE:
 		if (protocol_version >= SLURM_MIN_PROTOCOL_VERSION) {
-			char* buf;
 			int len;
 			Buf buffer;
 
@@ -894,7 +897,9 @@ extern int jobacctinfo_getinfo(
 		debug("jobacct_g_set_getinfo data_type %d invalid", type);
 	}
 	return rc;
+
 rwfail:
+	xfree(buf);
 	return SLURM_ERROR;
 }
 
@@ -906,7 +911,7 @@ extern void jobacctinfo_pack(jobacctinfo_t *jobacct,
 
 	no_pack = (!plugin_polling && (protocol_type != PROTOCOL_TYPE_DBD));
 
-	if (rpc_version >= SLURM_15_08_PROTOCOL_VERSION) {
+	if (rpc_version >= SLURM_MIN_PROTOCOL_VERSION) {
 		if (!jobacct || no_pack) {
 			pack8((uint8_t) 0, buffer);
 			return;
@@ -933,41 +938,6 @@ extern void jobacctinfo_pack(jobacctinfo_t *jobacct,
 		packdouble((double)jobacct->max_disk_write, buffer);
 		packdouble((double)jobacct->tot_disk_write, buffer);
 
-		_pack_jobacct_id(&jobacct->max_vsize_id, rpc_version, buffer);
-		_pack_jobacct_id(&jobacct->max_rss_id, rpc_version, buffer);
-		_pack_jobacct_id(&jobacct->max_pages_id, rpc_version, buffer);
-		_pack_jobacct_id(&jobacct->min_cpu_id, rpc_version, buffer);
-		_pack_jobacct_id(&jobacct->max_disk_read_id, rpc_version,
-			buffer);
-		_pack_jobacct_id(&jobacct->max_disk_write_id, rpc_version,
-			buffer);
-	} else if (rpc_version >= SLURM_14_11_PROTOCOL_VERSION) {
-		if (!jobacct || no_pack) {
-			pack8((uint8_t) 0, buffer);
-			return;
-		}
-		pack8((uint8_t) 1, buffer);
-
-		pack32((uint32_t)jobacct->user_cpu_sec, buffer);
-		pack32((uint32_t)jobacct->user_cpu_usec, buffer);
-		pack32((uint32_t)jobacct->sys_cpu_sec, buffer);
-		pack32((uint32_t)jobacct->sys_cpu_usec, buffer);
-		pack64(jobacct->max_vsize, buffer);
-		pack64(jobacct->tot_vsize, buffer);
-		pack64(jobacct->max_rss, buffer);
-		pack64(jobacct->tot_rss, buffer);
-		pack64(jobacct->max_pages, buffer);
-		pack64(jobacct->tot_pages, buffer);
-		pack32((uint32_t)jobacct->min_cpu, buffer);
-		pack32((uint32_t)jobacct->tot_cpu, buffer);
-		pack32((uint32_t)jobacct->act_cpufreq, buffer);
-		pack32((uint32_t)jobacct->energy.consumed_energy, buffer);
-
-		packdouble((double)jobacct->max_disk_read, buffer);
-		packdouble((double)jobacct->tot_disk_read, buffer);
-		packdouble((double)jobacct->max_disk_write, buffer);
-		packdouble((double)jobacct->tot_disk_write, buffer);
-
 		_pack_jobacct_id(&jobacct->max_vsize_id, rpc_version, buffer);
 		_pack_jobacct_id(&jobacct->max_rss_id, rpc_version, buffer);
 		_pack_jobacct_id(&jobacct->max_pages_id, rpc_version, buffer);
@@ -991,7 +961,7 @@ extern int jobacctinfo_unpack(jobacctinfo_t **jobacct,
 
 	jobacct_gather_init();
 
-	if (rpc_version >= SLURM_15_08_PROTOCOL_VERSION) {
+	if (rpc_version >= SLURM_MIN_PROTOCOL_VERSION) {
 		safe_unpack8(&uint8_tmp, buffer);
 		if (uint8_tmp == (uint8_t) 0)
 			return SLURM_SUCCESS;
@@ -1021,56 +991,6 @@ extern int jobacctinfo_unpack(jobacctinfo_t **jobacct,
 		safe_unpackdouble(&(*jobacct)->max_disk_write, buffer);
 		safe_unpackdouble(&(*jobacct)->tot_disk_write, buffer);
 
-		if (_unpack_jobacct_id(&(*jobacct)->max_vsize_id, rpc_version,
-			buffer) != SLURM_SUCCESS)
-			goto unpack_error;
-		if (_unpack_jobacct_id(&(*jobacct)->max_rss_id, rpc_version,
-			buffer) != SLURM_SUCCESS)
-			goto unpack_error;
-		if (_unpack_jobacct_id(&(*jobacct)->max_pages_id, rpc_version,
-			buffer) != SLURM_SUCCESS)
-			goto unpack_error;
-		if (_unpack_jobacct_id(&(*jobacct)->min_cpu_id, rpc_version,
-			buffer) != SLURM_SUCCESS)
-			goto unpack_error;
-		if (_unpack_jobacct_id(&(*jobacct)->max_disk_read_id,
-			rpc_version, buffer) != SLURM_SUCCESS)
-			goto unpack_error;
-		if (_unpack_jobacct_id(&(*jobacct)->max_disk_write_id,
-			rpc_version, buffer) != SLURM_SUCCESS)
-			goto unpack_error;
-	} else if (rpc_version >= SLURM_14_11_PROTOCOL_VERSION) {
-		safe_unpack8(&uint8_tmp, buffer);
-		if (uint8_tmp == (uint8_t) 0)
-			return SLURM_SUCCESS;
-		if (alloc)
-			*jobacct = xmalloc(sizeof(struct jobacctinfo));
-		safe_unpack32(&uint32_tmp, buffer);
-		(*jobacct)->user_cpu_sec = uint32_tmp;
-		safe_unpack32(&uint32_tmp, buffer);
-		(*jobacct)->user_cpu_usec = uint32_tmp;
-		safe_unpack32(&uint32_tmp, buffer);
-		(*jobacct)->sys_cpu_sec = uint32_tmp;
-		safe_unpack32(&uint32_tmp, buffer);
-		(*jobacct)->sys_cpu_usec = uint32_tmp;
-		safe_unpack64(&(*jobacct)->max_vsize, buffer);
-		safe_unpack64(&(*jobacct)->tot_vsize, buffer);
-		safe_unpack64(&(*jobacct)->max_rss, buffer);
-		safe_unpack64(&(*jobacct)->tot_rss, buffer);
-		safe_unpack64(&(*jobacct)->max_pages, buffer);
-		safe_unpack64(&(*jobacct)->tot_pages, buffer);
-		safe_unpack32(&(*jobacct)->min_cpu, buffer);
-		safe_unpack32(&uint32_tmp, buffer);
-		(*jobacct)->tot_cpu = (double)uint32_tmp;
-		safe_unpack32(&(*jobacct)->act_cpufreq, buffer);
-		safe_unpack32(&uint32_tmp, buffer);
-		(*jobacct)->energy.consumed_energy = (uint64_t) uint32_tmp;
-
-		safe_unpackdouble(&(*jobacct)->max_disk_read, buffer);
-		safe_unpackdouble(&(*jobacct)->tot_disk_read, buffer);
-		safe_unpackdouble(&(*jobacct)->max_disk_write, buffer);
-		safe_unpackdouble(&(*jobacct)->tot_disk_write, buffer);
-
 		if (_unpack_jobacct_id(&(*jobacct)->max_vsize_id, rpc_version,
 			buffer) != SLURM_SUCCESS)
 			goto unpack_error;
