@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -40,18 +40,7 @@
 #ifndef _SLURM_PROTOCOL_PACK_H
 #define _SLURM_PROTOCOL_PACK_H
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#  if HAVE_INTTYPES_H
-#    include <inttypes.h>
-#  else
-#    if HAVE_STDINT_H
-#      include <stdint.h>
-#    endif
-#  endif  /* HAVE_INTTYPES_H */
-#else   /* !HAVE_CONFIG_H */
-#  include <inttypes.h>
-#endif  /*  HAVE_CONFIG_H */
+#include <inttypes.h>
 
 #include "src/common/pack.h"
 #include "src/common/slurm_protocol_defs.h"
@@ -167,10 +156,10 @@ extern int slurm_unpack_block_info_msg(
 	block_info_msg_t **block_info_msg_pptr, Buf buffer,
 	uint16_t protocol_version);
 
-/* Translate task_dist value from v15.08+ format to v14.11- format */
-extern uint16_t task_dist_new2old(uint32_t new_task_dist);
-/* Translate task_dist value from v14.11- format to v15.08+ format */
-extern uint32_t task_dist_old2new(uint16_t old_task_dist);
+/* Translate memory limits from old format to new */
+/* Remove when version 16.05 support is no longer required. */
+extern uint32_t xlate_mem_new2old(uint64_t new_mem);
+extern uint64_t xlate_mem_old2new(uint32_t old_mem);
 
 /* Translate 32-bit nice value to equivalent 16-bit value.
  * Remove when version 15.08 support is no longer required. */
