@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -105,6 +105,10 @@ extern slurmdb_step_rec_t *slurmdb_create_step_rec();
 extern slurmdb_assoc_usage_t *slurmdb_create_assoc_usage(int tres_cnt);
 extern slurmdb_qos_usage_t *slurmdb_create_qos_usage(int tres_cnt);
 
+extern char *slurmdb_cluster_fed_states_str(uint32_t states);
+extern uint32_t str_2_cluster_fed_states(char *states);
+extern char *slurmdb_federation_flags_str(uint32_t flags);
+extern uint32_t str_2_federation_flags(char *flags, int option);
 extern char *slurmdb_qos_str(List qos_list, uint32_t level);
 extern uint32_t str_2_slurmdb_qos(List qos_list, char *level);
 extern char *slurmdb_qos_flags_str(uint32_t flags);
@@ -168,6 +172,10 @@ extern char *slurmdb_get_selected_step_id(
  */
 extern void slurmdb_copy_assoc_rec_limits(slurmdb_assoc_rec_t *out,
 					  slurmdb_assoc_rec_t *in);
+extern void slurmdb_copy_cluster_rec(slurmdb_cluster_rec_t *out,
+				     slurmdb_cluster_rec_t *in);
+extern void slurmdb_copy_federation_rec(slurmdb_federation_rec_t *out,
+					slurmdb_federation_rec_t *in);
 extern void slurmdb_copy_qos_rec_limits(slurmdb_qos_rec_t *out,
 					slurmdb_qos_rec_t *in);
 extern slurmdb_tres_rec_t *slurmdb_copy_tres_rec(slurmdb_tres_rec_t *tres);
@@ -242,6 +250,7 @@ extern int slurmdb_find_update_object_in_list(void *x, void *key);
 extern int slurmdb_find_tres_in_list(void *x, void *key);
 extern int slurmdb_find_tres_in_list_by_count(void *x, void *key);
 extern int slurmdb_find_tres_in_list_by_type(void *x, void *key);
+extern int slurmdb_find_cluster_in_list(void *x, void *key);
 extern int slurmdb_find_cluster_accting_tres_in_list(void *x, void *key);
 extern int slurmdb_add_cluster_accounting_to_tres_list(
 	slurmdb_cluster_accounting_rec_t *accting,
