@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -45,172 +45,198 @@
 #include "xstring.h"
 
 extern void slurmdb_pack_user_rec(void *in,
-				  uint16_t rpc_version, Buf buffer);
+				  uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_user_rec(void **object,
-				   uint16_t rpc_version, Buf buffer);
+				   uint16_t protocol_version, Buf buffer);
 extern void slurmdb_pack_account_rec(void *in,
-				     uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_account_rec(void **object, uint16_t rpc_version,
+				     uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_account_rec(void **object, uint16_t protocol_version,
 				      Buf buffer);
 extern void slurmdb_pack_coord_rec(void *in,
-				   uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_coord_rec(void **object, uint16_t rpc_version,
+				   uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_coord_rec(void **object, uint16_t protocol_version,
 				    Buf buffer);
 extern void pack_cluster_accounting_rec(void *in,
-					uint16_t rpc_version, Buf buffer);
-extern int unpack_cluster_accounting_rec(void **object, uint16_t rpc_version,
+					uint16_t protocol_version, Buf buffer);
+extern int unpack_cluster_accounting_rec(void **object,
+					 uint16_t protocol_version,
 					 Buf buffer);
 extern void slurmdb_pack_clus_res_rec(void *in,
-				      uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_clus_res_rec(void **object, uint16_t rpc_version,
+				      uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_clus_res_rec(void **object, uint16_t protocol_version,
 				       Buf buffer);
 extern void slurmdb_pack_cluster_rec(void *in,
-				     uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_cluster_rec(void **object, uint16_t rpc_version,
+				     uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_cluster_rec(void **object, uint16_t protocol_version,
 				      Buf buffer);
-extern void slurmdb_pack_accounting_rec(void *in,
-					uint16_t rpc_version,
+extern void slurmdb_pack_federation_rec(void *in, uint16_t protocol_version,
 					Buf buffer);
-extern int slurmdb_unpack_accounting_rec(void **object, uint16_t rpc_version,
+extern int slurmdb_unpack_federation_rec(void **object,
+					 uint16_t protocol_version, Buf buffer);
+extern void slurmdb_pack_accounting_rec(void *in,
+					uint16_t protocol_version,
+					Buf buffer);
+extern int slurmdb_unpack_accounting_rec(void **object,
+					 uint16_t protocol_version,
 					 Buf buffer);
 extern void slurmdb_pack_assoc_rec(void *in,
-				   uint16_t rpc_version,
+				   uint16_t protocol_version,
 				   Buf buffer);
 extern int slurmdb_unpack_assoc_rec_members(slurmdb_assoc_rec_t *object_ptr,
-					    uint16_t rpc_version,
+					    uint16_t protocol_version,
 					    Buf buffer);
-extern int slurmdb_unpack_assoc_rec(void **object, uint16_t rpc_version,
+extern int slurmdb_unpack_assoc_rec(void **object, uint16_t protocol_version,
 				    Buf buffer);
-extern void slurmdb_pack_assoc_usage(void *in, uint16_t rpc_version,
+extern void slurmdb_pack_assoc_usage(void *in, uint16_t protocol_version,
 				     Buf buffer);
-extern int slurmdb_unpack_assoc_usage(void **object, uint16_t rpc_version,
+extern int slurmdb_unpack_assoc_usage(void **object, uint16_t protocol_version,
 				      Buf buffer);
-extern void slurmdb_pack_assoc_rec_with_usage(void *in, uint16_t rpc_version,
+extern void slurmdb_pack_assoc_rec_with_usage(void *in,
+					      uint16_t protocol_version,
 					      Buf buffer);
 extern int slurmdb_unpack_assoc_rec_with_usage(void **object,
-					       uint16_t rpc_version,
+					       uint16_t protocol_version,
 					       Buf buffer);
 extern void slurmdb_pack_event_rec(void *in,
-				   uint16_t rpc_version,
+				   uint16_t protocol_version,
 				   Buf buffer);
-extern int slurmdb_unpack_event_rec(void **object, uint16_t rpc_version,
+extern int slurmdb_unpack_event_rec(void **object, uint16_t protocol_version,
 				    Buf buffer);
 extern void slurmdb_pack_qos_rec(void *in,
-				 uint16_t rpc_version, Buf buffer);
+				 uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_qos_rec(void **object,
-				  uint16_t rpc_version, Buf buffer);
-extern void slurmdb_pack_qos_usage(void *in, uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_qos_usage(void **object, uint16_t rpc_version,
+				  uint16_t protocol_version, Buf buffer);
+extern void slurmdb_pack_qos_usage(void *in, uint16_t protocol_version,
+				   Buf buffer);
+extern int slurmdb_unpack_qos_usage(void **object, uint16_t protocol_version,
 				    Buf buffer);
-extern void slurmdb_pack_qos_rec_with_usage(void *in, uint16_t rpc_version,
+extern void slurmdb_pack_qos_rec_with_usage(void *in, uint16_t protocol_version,
 					    Buf buffer);
 extern int slurmdb_unpack_qos_rec_with_usage(void **object,
-					     uint16_t rpc_version,
+					     uint16_t protocol_version,
 					     Buf buffer);
 extern void slurmdb_pack_reservation_rec(void *in,
-					 uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_reservation_rec(void **object, uint16_t rpc_version,
+					 uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_reservation_rec(void **object,
+					  uint16_t protocol_version,
 					  Buf buffer);
-extern void slurmdb_pack_res_rec(void *in, uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_res_rec(void **object, uint16_t rpc_version,
+extern void slurmdb_pack_res_rec(void *in, uint16_t protocol_version,
+				 Buf buffer);
+extern int slurmdb_unpack_res_rec(void **object, uint16_t protocol_version,
 				  Buf buffer);
 extern void slurmdb_pack_txn_rec(void *in,
-				 uint16_t rpc_version, Buf buffer);
+				 uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_txn_rec(void **object,
-				  uint16_t rpc_version, Buf buffer);
+				  uint16_t protocol_version, Buf buffer);
 extern void slurmdb_pack_wckey_rec(void *in,
-				   uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_wckey_rec(void **object, uint16_t rpc_version,
+				   uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_wckey_rec(void **object, uint16_t protocol_version,
 				    Buf buffer);
 extern void slurmdb_pack_archive_rec(void *in,
-				     uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_archive_rec(void **object, uint16_t rpc_version,
+				     uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_archive_rec(void **object, uint16_t protocol_version,
 				      Buf buffer);
-extern void slurmdb_pack_tres_cond(void *in, uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_tres_cond(void **object, uint16_t rpc_version,
+extern void slurmdb_pack_tres_cond(void *in, uint16_t protocol_version,
+				   Buf buffer);
+extern int slurmdb_unpack_tres_cond(void **object, uint16_t protocol_version,
 				     Buf buffer);
-extern void slurmdb_pack_tres_rec(void *in, uint16_t rpc_version, Buf buffer);
+extern void slurmdb_pack_tres_rec(void *in, uint16_t protocol_version,
+				  Buf buffer);
 extern int slurmdb_unpack_tres_rec_noalloc(
-	slurmdb_tres_rec_t *object_ptr, uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_tres_rec(void **object, uint16_t rpc_version,
+	slurmdb_tres_rec_t *object_ptr, uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_tres_rec(void **object, uint16_t protocol_version,
 				    Buf buffer);
 
 extern void slurmdb_pack_user_cond(void *in,
-				   uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_user_cond(void **object, uint16_t rpc_version,
+				   uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_user_cond(void **object, uint16_t protocol_version,
 				    Buf buffer);
 extern void slurmdb_pack_account_cond(void *in,
-				      uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_account_cond(void **object, uint16_t rpc_version,
+				      uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_account_cond(void **object, uint16_t protocol_version,
 				       Buf buffer);
 extern void slurmdb_pack_cluster_cond(void *in,
-				      uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_cluster_cond(void **object, uint16_t rpc_version,
+				      uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_cluster_cond(void **object, uint16_t protocol_version,
 				       Buf buffer);
+extern void slurmdb_pack_federation_cond(void *in, uint16_t protocol_version,
+					 Buf buffer);
+extern int slurmdb_unpack_federation_cond(void **object,
+					  uint16_t protocol_version,
+					  Buf buffer);
 extern void slurmdb_pack_assoc_cond(void *in,
-				    uint16_t rpc_version,
+				    uint16_t protocol_version,
 				    Buf buffer);
-extern int slurmdb_unpack_assoc_cond(void **object, uint16_t rpc_version,
+extern int slurmdb_unpack_assoc_cond(void **object, uint16_t protocol_version,
 				     Buf buffer);
 extern void slurmdb_pack_event_cond(void *in,
-				    uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_event_cond(void **object, uint16_t rpc_version,
+				    uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_event_cond(void **object, uint16_t protocol_version,
 				     Buf buffer);
 extern void slurmdb_pack_job_cond(void *in,
-				  uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_job_cond(void **object, uint16_t rpc_version,
+				  uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_job_cond(void **object, uint16_t protocol_version,
 				   Buf buffer);
 extern void slurmdb_pack_job_modify_cond(void *in,
-					 uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_job_modify_cond(void **object, uint16_t rpc_version,
+					 uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_job_modify_cond(void **object,
+					  uint16_t protocol_version,
 					  Buf buffer);
 extern void slurmdb_pack_job_rec(void *object,
-				 uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_job_rec(void **job, uint16_t rpc_version, Buf buffer);
+				 uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_job_rec(void **job, uint16_t protocol_version,
+				  Buf buffer);
 extern void slurmdb_pack_qos_cond(void *in,
-				  uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_qos_cond(void **object, uint16_t rpc_version,
+				  uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_qos_cond(void **object, uint16_t protocol_version,
 				   Buf buffer);
 extern void slurmdb_pack_reservation_cond(void *in,
-					  uint16_t rpc_version,
+					  uint16_t protocol_version,
 					  Buf buffer);
-extern int slurmdb_unpack_reservation_cond(void **object, uint16_t rpc_version,
+extern int slurmdb_unpack_reservation_cond(void **object,
+					   uint16_t protocol_version,
 					   Buf buffer);
 extern void slurmdb_pack_selected_step(slurmdb_selected_step_t *step,
-				       uint16_t rpc_version, Buf buffer);
+				       uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_selected_step(slurmdb_selected_step_t **step,
-					uint16_t rpc_version, Buf buffer);
+					uint16_t protocol_version, Buf buffer);
 extern void slurmdb_pack_step_rec(slurmdb_step_rec_t *step,
-				  uint16_t rpc_version, Buf buffer);
+				  uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_step_rec(slurmdb_step_rec_t **step,
-				   uint16_t rpc_version, Buf buffer);
-extern void slurmdb_pack_res_cond(void *in, uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_res_cond(void **object, uint16_t rpc_version,
+				   uint16_t protocol_version, Buf buffer);
+extern void slurmdb_pack_res_cond(void *in, uint16_t protocol_version,
+				  Buf buffer);
+extern int slurmdb_unpack_res_cond(void **object, uint16_t protocol_version,
 				   Buf buffer);
 extern void slurmdb_pack_txn_cond(void *in,
-				  uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_txn_cond(void **object, uint16_t rpc_version,
+				  uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_txn_cond(void **object, uint16_t protocol_version,
 				   Buf buffer);
 extern void slurmdb_pack_wckey_cond(void *in,
-				    uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_wckey_cond(void **object, uint16_t rpc_version,
+				    uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_wckey_cond(void **object, uint16_t protocol_version,
 				     Buf buffer);
 extern void slurmdb_pack_archive_cond(void *in,
-				      uint16_t rpc_version, Buf buffer);
-extern int slurmdb_unpack_archive_cond(void **object, uint16_t rpc_version,
+				      uint16_t protocol_version, Buf buffer);
+extern int slurmdb_unpack_archive_cond(void **object, uint16_t protocol_version,
 				       Buf buffer);
 extern void slurmdb_pack_update_object(slurmdb_update_object_t *object,
-				       uint16_t rpc_version, Buf buffer);
+				       uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_update_object(slurmdb_update_object_t **object,
-					uint16_t rpc_version, Buf buffer);
+					uint16_t protocol_version, Buf buffer);
 extern void slurmdb_pack_used_limits(void *in, uint32_t tres_cnt,
-				     uint16_t rpc_version, Buf buffer);
+				     uint16_t protocol_version, Buf buffer);
 extern int slurmdb_unpack_used_limits(void **object, uint32_t tres_cnt,
-				      uint16_t rpc_version, Buf buffer);
+				      uint16_t protocol_version, Buf buffer);
 
 extern void pack_update_shares_used(void *in,
-				    uint16_t rpc_version, Buf buffer);
-extern int unpack_update_shares_used(void **object, uint16_t rpc_version,
+				    uint16_t protocol_version, Buf buffer);
+extern int unpack_update_shares_used(void **object, uint16_t protocol_version,
 				     Buf buffer);
 
+extern void slurmdb_pack_stats_msg(void *object, uint16_t protocol_version,
+				   Buf buffer);
+extern int slurmdb_unpack_stats_msg(void **object, uint16_t protocol_version,
+				    Buf buffer);
+
 #endif
