@@ -7,7 +7,7 @@
  *  Written by Danny Auble <da@llnl.gov>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -123,6 +123,12 @@ extern int acct_storage_p_add_clusters(void *db_conn, uint32_t uid,
 	return SLURM_SUCCESS;
 }
 
+extern int acct_storage_p_add_federations(void *db_conn, uint32_t uid,
+					  List federation_list)
+{
+	return SLURM_SUCCESS;
+}
+
 extern int acct_storage_p_add_tres(void *db_conn,
 				     uint32_t uid, List tres_list)
 {
@@ -187,6 +193,14 @@ extern List acct_storage_p_modify_assocs(void *db_conn, uint32_t uid,
 	return SLURM_SUCCESS;
 }
 
+extern List acct_storage_p_modify_federations(
+				void *db_conn, uint32_t uid,
+				slurmdb_federation_cond_t *fed_cond,
+				slurmdb_federation_rec_t *fed)
+{
+	return SLURM_SUCCESS;
+}
+
 extern List acct_storage_p_modify_job(void *db_conn, uint32_t uid,
 				      slurmdb_job_modify_cond_t *job_cond,
 				      slurmdb_job_rec_t *job)
@@ -252,6 +266,13 @@ extern List acct_storage_p_remove_assocs(void *db_conn, uint32_t uid,
 	return SLURM_SUCCESS;
 }
 
+extern List acct_storage_p_remove_federations(
+					void *db_conn, uint32_t uid,
+					slurmdb_federation_cond_t *fed_cond)
+{
+	return SLURM_SUCCESS;
+}
+
 extern List acct_storage_p_remove_qos(void *db_conn, uint32_t uid,
 				      slurmdb_qos_cond_t *qos_cond)
 {
@@ -294,6 +315,12 @@ extern List acct_storage_p_get_clusters(void *db_conn, uid_t uid,
 	return NULL;
 }
 
+extern List acct_storage_p_get_federations(void *db_conn, uid_t uid,
+					   slurmdb_federation_cond_t *fed_cond)
+{
+	return NULL;
+}
+
 extern List acct_storage_p_get_config(void *db_conn, char *config_name)
 {
 	return NULL;
@@ -364,7 +391,8 @@ extern int acct_storage_p_get_usage(void *db_conn, uid_t uid,
 
 extern int acct_storage_p_roll_usage(void *db_conn,
 				     time_t sent_start, time_t sent_end,
-				     uint16_t archive_data)
+				     uint16_t archive_data,
+				     rollup_stats_t *rollup_stats)
 {
 	int rc = SLURM_SUCCESS;
 
@@ -513,3 +541,18 @@ extern int acct_storage_p_reset_lft_rgt(void *db_conn, uid_t uid,
 {
 	return SLURM_SUCCESS;
 }
+
+extern int acct_storage_p_get_stats(void *db_conn, bool dbd)
+{
+	return SLURM_SUCCESS;
+}
+
+extern int acct_storage_p_clear_stats(void *db_conn, bool dbd)
+{
+	return SLURM_SUCCESS;
+}
+
+extern int acct_storage_p_shutdown(void *db_conn, bool dbd)
+{
+	return SLURM_SUCCESS;
+}
