@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -36,34 +36,13 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#  if STDC_HEADERS
-#    include <string.h>
-#  endif
-#  if HAVE_SYS_TYPES_H
-#    include <sys/types.h>
-#  endif /* HAVE_SYS_TYPES_H */
-#  if HAVE_UNISTD_H
-#    include <unistd.h>
-#  endif
-#  if HAVE_INTTYPES_H
-#    include <inttypes.h>
-#  else /* ! HAVE_INTTYPES_H */
-#    if HAVE_STDINT_H
-#      include <stdint.h>
-#    endif
-#  endif /* HAVE_INTTYPES_H */
-#else /* ! HAVE_CONFIG_H */
-#  include <sys/types.h>
-#  include <unistd.h>
-#  include <stdint.h>
-#  include <string.h>
-#endif /* HAVE_CONFIG_H */
-
 #include <ctype.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "slurm/slurm.h"
 #include "slurm/slurm_errno.h"
@@ -243,7 +222,7 @@ static bool _use_local_device_index(void)
  * Set environment variables as appropriate for a job (i.e. all tasks) based
  * upon the job's GRES state.
  */
-extern void job_set_env(char ***job_env_ptr, void *gres_ptr)
+extern void job_set_env(char ***job_env_ptr, void *gres_ptr, int node_inx)
 {
 	int i, len, local_inx = 0;
 	char *dev_list = NULL;
@@ -251,12 +230,12 @@ extern void job_set_env(char ***job_env_ptr, void *gres_ptr)
 	bool use_local_dev_index = _use_local_device_index();
 
 	if ((gres_job_ptr != NULL) &&
-	    (gres_job_ptr->node_cnt == 1) &&
+	    (node_inx >= 0) && (node_inx < gres_job_ptr->node_cnt) &&
 	    (gres_job_ptr->gres_bit_alloc != NULL) &&
-	    (gres_job_ptr->gres_bit_alloc[0] != NULL)) {
-		len = bit_size(gres_job_ptr->gres_bit_alloc[0]);
+	    (gres_job_ptr->gres_bit_alloc[node_inx] != NULL)) {
+		len = bit_size(gres_job_ptr->gres_bit_alloc[node_inx]);
 		for (i = 0; i < len; i++) {
-			if (!bit_test(gres_job_ptr->gres_bit_alloc[0], i))
+			if (!bit_test(gres_job_ptr->gres_bit_alloc[node_inx],i))
 				continue;
 			if (!dev_list)
 				dev_list = xmalloc(128);
