@@ -6,7 +6,7 @@
  *  Written by Morris Jette <jette@schedmd.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -35,26 +35,14 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#   include "config.h"
-#endif
-
-#if HAVE_STDINT_H
-#  include <stdint.h>
-#endif
-
-#if HAVE_INTTYPES_H
-#  include <inttypes.h>
-#endif
-
-#include <stdio.h>
-
-#include <sys/types.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <unistd.h>
 #include <dlfcn.h>
+#include <inttypes.h>
 #include <pthread.h>
+#include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "slurm/slurm.h"
 #include "slurm/slurm_errno.h"
@@ -159,11 +147,16 @@ static void _decr_depend_cnt(struct job_record *job_ptr)
  * later. */
 static void *_dep_agent(void *args)
 {
+	/* Locks: Write job, read node, read partition */
+	slurmctld_lock_t job_write_lock = {
+		READ_LOCK, WRITE_LOCK, READ_LOCK, READ_LOCK, NO_LOCK };
+
 	struct job_record *job_ptr = (struct job_record *) args;
 	char *end_ptr = NULL, *tok;
 	int cnt = 0;
 
 	usleep(100000);
+	lock_slurmctld(job_write_lock);
 	if (job_ptr && job_ptr->details && (job_ptr->magic == JOB_MAGIC) &&
 	    job_ptr->comment && strstr(job_ptr->comment, "on:")) {
 		char *new_depend = job_ptr->details->dependency;
@@ -175,6 +168,8 @@ static void *_dep_agent(void *args)
 	}
 	if (cnt == 0)
 		set_job_prio(job_ptr);
+	unlock_slurmctld(job_write_lock);
+
 	return NULL;
 }
 
@@ -314,7 +309,7 @@ extern int job_submit(struct job_descriptor *job_desc, uint32_t submit_uid)
 	char *std_out, *tok;
 	uint32_t my_job_id;
 
-	my_job_id = get_next_job_id();
+	my_job_id = get_next_job_id(true);
 	_xlate_dependency(job_desc, submit_uid, my_job_id);
 
 	if (job_desc->account)
