@@ -6,7 +6,7 @@
  *  Written by Artem Polyakov <artpol84@gmail.com, artemp@mellanox.com>.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -34,18 +34,20 @@
  *  with SLURM; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  \*****************************************************************************/
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/un.h>
-#include <errno.h>
-#include <poll.h>
-#include <time.h>
-#include <sys/stat.h>
-#include <unistd.h>
+
 #include <dirent.h>
+#include <errno.h>
+#include <limits.h>
+#include <poll.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/socket.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <sys/un.h>
+#include <time.h>
+#include <unistd.h>
 
 #include "pmixp_common.h"
 #include "pmixp_utils.h"
@@ -527,7 +529,7 @@ int pmixp_mkdir(char *path, mode_t rights)
 
 	if (0 != mkdir(path, rights) ) {
 		PMIXP_ERROR_STD("Cannot create directory \"%s\"",
-				pmixp_info_tmpdir_lib());
+				path);
 		return errno;
 	}
 
@@ -540,7 +542,7 @@ int pmixp_mkdir(char *path, mode_t rights)
 	}
 
 	if (chown(path, (uid_t) pmixp_info_jobuid(), (gid_t) -1) < 0) {
-		error("%s: chown(%s): %m", __func__, pmixp_info_tmpdir_lib());
+		error("%s: chown(%s): %m", __func__, path);
 		return errno;
 	}
 	return 0;
