@@ -7,7 +7,7 @@
  *  Written by Rod Schultz <rod.schultz@bull.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -36,12 +36,8 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if     HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
-#include <stdlib.h>
 #include <signal.h>
+#include <stdlib.h>
 #include <sys/types.h>
 
 #include "slurm/slurm_errno.h"
@@ -160,7 +156,7 @@ extern int route_p_split_hostlist(hostlist_t hl,
 		if (init_node_conf()) {
 			fatal("ROUTE: Failed to init slurm config");
 		}
-		if (build_all_nodeline_info(false)) {
+		if (build_all_nodeline_info(false, 0)) {
 			fatal("ROUTE: Failed to build node config");
 		}
 		rehash_node();
