@@ -21,7 +21,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -50,12 +50,10 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include "config.h"
 
 #if HAVE_SYS_PRCTL_H
-#include <sys/prctl.h>
+#  include <sys/prctl.h>
 #endif
 
 #include <pthread.h>
@@ -70,8 +68,10 @@
 #include "slurm/slurm_errno.h"
 
 #include "src/common/assoc_mgr.h"
+#include "src/common/gres.h"
 #include "src/common/list.h"
 #include "src/common/macros.h"
+#include "src/common/node_features.h"
 #include "src/common/node_select.h"
 #include "src/common/parse_time.h"
 #include "src/common/power.h"
@@ -84,6 +84,7 @@
 
 #include "src/slurmctld/acct_policy.h"
 #include "src/slurmctld/burst_buffer.h"
+#include "src/slurmctld/fed_mgr.h"
 #include "src/slurmctld/front_end.h"
 #include "src/slurmctld/job_scheduler.h"
 #include "src/slurmctld/licenses.h"
@@ -127,6 +128,7 @@ static uint64_t debug_flags = 0;
 static int backfill_interval = BACKFILL_INTERVAL;
 static int backfill_resolution = BACKFILL_RESOLUTION;
 static int backfill_window = BACKFILL_WINDOW;
+static int bf_job_part_count_reserve = 0;
 static int bf_max_job_array_resv = BF_MAX_JOB_ARRAY_RESV;
 static int bf_min_age_reserve = 0;
 static uint32_t bf_min_prio_reserve = 0;
@@ -146,8 +148,7 @@ static void _add_reservation(uint32_t start_time, uint32_t end_reserve,
 			     node_space_map_t *node_space,
 			     int *node_space_recs);
 static int  _attempt_backfill(void);
-static void _clear_job_start_times(void);
-static int  _delta_tv(struct timeval *tv);
+static int  _clear_job_start_times(void *x, void *arg);
 static void _do_diag_stats(struct timeval *tv1, struct timeval *tv2);
 static bool _job_part_valid(struct job_record *job_ptr,
 			    struct part_record *part_ptr);
@@ -166,6 +167,7 @@ static int  _try_sched(struct job_record *job_ptr, bitstr_t **avail_bitmap,
 		       uint32_t min_nodes, uint32_t max_nodes,
 		       uint32_t req_nodes, bitstr_t *exc_core_bitmap);
 static int  _yield_locks(int usec);
+static int _clear_qos_blocked_times(void *x, void *arg);
 
 /* Log resources to be allocated to a pending job */
 static void _dump_job_sched(struct job_record *job_ptr, time_t end_time,
@@ -263,6 +265,14 @@ static int _num_feature_count(struct job_record *job_ptr, bool *has_xor)
 	return rc;
 }
 
+static int _clear_qos_blocked_times(void *x, void *arg)
+{
+	slurmdb_qos_rec_t *qos_ptr = (slurmdb_qos_rec_t *) x;
+	qos_ptr->blocked_until = 0;
+
+	return 0;
+}
+
 /* Attempt to schedule a specific job on specific available nodes
  * IN job_ptr - job to schedule
  * IN/OUT avail_bitmap - nodes available/selected to use
@@ -450,24 +460,10 @@ extern void stop_backfill_agent(void)
 {
 	slurm_mutex_lock(&term_lock);
 	stop_backfill = true;
-	pthread_cond_signal(&term_cond);
+	slurm_cond_signal(&term_cond);
 	slurm_mutex_unlock(&term_lock);
 }
 
-/* Return the number of micro-seconds between now and argument "tv" */
-static int _delta_tv(struct timeval *tv)
-{
-	struct timeval now = {0, 0};
-	int delta_t;
-
-	if (gettimeofday(&now, NULL))
-		return 1;		/* Some error */
-
-	delta_t  = (now.tv_sec - tv->tv_sec) * 1000000;
-	delta_t += (now.tv_usec - tv->tv_usec);
-	return delta_t;
-}
-
 /* Sleep for at least specified time, returns actual sleep time in usec */
 static uint32_t _my_sleep(int usec)
 {
@@ -487,7 +483,7 @@ static uint32_t _my_sleep(int usec)
 	ts.tv_nsec = nsec % 1000000000;
 	slurm_mutex_lock(&term_lock);
 	if (!stop_backfill)
-		pthread_cond_timedwait(&term_cond, &term_lock, &ts);
+		slurm_cond_timedwait(&term_cond, &term_lock, &ts);
 	slurm_mutex_unlock(&term_lock);
 	if (gettimeofday(&tv2, NULL))
 		return usec;
@@ -609,6 +605,18 @@ static void _load_config(void)
 		     max_backfill_job_per_user, max_backfill_job_cnt);
 	}
 
+	bf_job_part_count_reserve = 0;
+	if (sched_params &&
+	    (tmp_ptr = strstr(sched_params, "bf_job_part_count_reserve="))) {
+		int job_cnt = atoi(tmp_ptr + 26);
+		if (job_cnt < 0) {
+			error("Invalid SchedulerParameters bf_job_part_count_reserve: %d",
+			      job_cnt);
+		} else {
+			bf_job_part_count_reserve = job_cnt;
+		}
+	}
+
 	bf_min_age_reserve = 0;
 	if (sched_params &&
 	    (tmp_ptr = strstr(sched_params, "bf_min_age_reserve="))) {
@@ -733,7 +741,7 @@ extern void *backfill_agent(void *args)
 	static time_t last_backfill_time = 0;
 	/* Read config and partitions; Write jobs and nodes */
 	slurmctld_lock_t all_locks = {
-		READ_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK };
+		READ_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK, READ_LOCK };
 	bool load_config;
 	bool short_sleep = false;
 
@@ -764,7 +772,7 @@ extern void *backfill_agent(void *args)
 		now = time(NULL);
 		wait_time = difftime(now, last_backfill_time);
 		if ((wait_time < backfill_interval) ||
-		    job_is_completing() || _many_pending_rpcs() ||
+		    job_is_completing(NULL) || _many_pending_rpcs() ||
 		    !avail_front_end(NULL) || !_more_work(last_backfill_time)) {
 			short_sleep = true;
 			continue;
@@ -782,17 +790,12 @@ extern void *backfill_agent(void *args)
 /* Clear the start_time for all pending jobs. This is used to ensure that a job which
  * can run in multiple partitions has its start_time set to the smallest
  * value in any of those partitions. */
-static void _clear_job_start_times(void)
+static int _clear_job_start_times(void *x, void *arg)
 {
-	ListIterator job_iterator;
-	struct job_record *job_ptr;
-
-	job_iterator = list_iterator_create(job_list);
-	while ((job_ptr = (struct job_record *) list_next(job_iterator))) {
-		if (IS_JOB_PENDING(job_ptr))
-			job_ptr->start_time = 0;
-	}
-	list_iterator_destroy(job_iterator);
+	struct job_record *job_ptr = (struct job_record *) x;
+	if (IS_JOB_PENDING(job_ptr))
+		job_ptr->start_time = 0;
+	return SLURM_SUCCESS;
 }
 
 /* Return non-zero to break the backfill loop if change in job, node or
@@ -800,7 +803,7 @@ static void _clear_job_start_times(void)
 static int _yield_locks(int usec)
 {
 	slurmctld_lock_t all_locks = {
-		READ_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK };
+		READ_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK, READ_LOCK };
 	time_t job_update, node_update, part_update;
 	bool load_config = false;
 	int max_rpc_cnt;
@@ -883,14 +886,14 @@ static bool _job_runnable_now(struct job_record *job_ptr)
 static int _attempt_backfill(void)
 {
 	DEF_TIMERS;
-	bool filter_root = false;
 	List job_queue;
 	job_queue_rec_t *job_queue_rec;
-	slurmdb_qos_rec_t *qos_ptr = NULL;
+	slurmdb_qos_rec_t *qos_ptr = NULL, *qos_part_ptr = NULL;;
 	int bb, i, j, node_space_recs, mcs_select = 0;
 	struct job_record *job_ptr;
 	struct part_record *part_ptr, **bf_part_ptr = NULL;
-	uint32_t end_time, end_reserve, deadline_time_limit;
+	uint32_t end_time, end_reserve, deadline_time_limit, boot_time;
+	uint32_t orig_end_time;
 	uint32_t time_limit, comp_time_limit, orig_time_limit, part_time_limit;
 	uint32_t min_nodes, max_nodes, req_nodes;
 	bitstr_t *active_bitmap = NULL, *avail_bitmap = NULL;
@@ -901,7 +904,8 @@ static int _attempt_backfill(void)
 	struct timeval bf_time1, bf_time2;
 	int rc = 0;
 	int job_test_count = 0, test_time_count = 0, pend_time;
-	uint32_t *uid = NULL, nuser = 0, bf_parts = 0, *bf_part_jobs = NULL;
+	uint32_t *uid = NULL, nuser = 0, bf_parts = 0;
+	uint32_t *bf_part_jobs = NULL, *bf_part_resv = NULL;
 	uint16_t *njobs = NULL;
 	bool already_counted;
 	uint32_t reject_array_job_id = 0;
@@ -916,6 +920,12 @@ static int _attempt_backfill(void)
 	bool resv_overlap = false;
 	uint8_t save_share_res, save_whole_node;
 	int test_fini;
+	uint32_t qos_flags = 0;
+	time_t qos_blocked_until = 0, qos_part_blocked_until = 0;
+	/* QOS Read lock */
+	assoc_mgr_lock_t qos_read_lock =
+		{ NO_LOCK, NO_LOCK, READ_LOCK, NO_LOCK,
+		  NO_LOCK, NO_LOCK, NO_LOCK };
 
 	bf_sleep_usec = 0;
 #ifdef HAVE_ALPS_CRAY
@@ -947,9 +957,6 @@ static int _attempt_backfill(void)
 	sched_start = orig_sched_start = now = time(NULL);
 	gettimeofday(&start_tv, NULL);
 
-	if (slurm_get_root_filter())
-		filter_root = true;
-
 	job_queue = build_job_queue(true, true);
 	job_test_count = list_count(job_queue);
 	if (job_test_count == 0) {		
@@ -965,7 +972,7 @@ static int _attempt_backfill(void)
 	}
 
 	if (backfill_continue)
-		_clear_job_start_times();
+		list_for_each(job_list, _clear_job_start_times, NULL);
 
 	gettimeofday(&bf_time1, NULL);
 
@@ -988,12 +995,13 @@ static int _attempt_backfill(void)
 	if (debug_flags & DEBUG_FLAG_BACKFILL_MAP)
 		_dump_node_space_table(node_space);
 
-	if (max_backfill_job_per_part) {
+	if (bf_job_part_count_reserve || max_backfill_job_per_part) {
 		ListIterator part_iterator;
 		struct part_record *part_ptr;
 		bf_parts = list_count(part_list);
 		bf_part_ptr  = xmalloc(sizeof(struct part_record *) * bf_parts);
 		bf_part_jobs = xmalloc(sizeof(uint32_t) * bf_parts);
+		bf_part_resv = xmalloc(sizeof(uint32_t) * bf_parts);
 		part_iterator = list_iterator_create(part_list);
 		i = 0;
 		while ((part_ptr = (struct part_record *)
@@ -1006,22 +1014,38 @@ static int _attempt_backfill(void)
 		uid = xmalloc(BF_MAX_USERS * sizeof(uint32_t));
 		njobs = xmalloc(BF_MAX_USERS * sizeof(uint16_t));
 	}
+	if (assoc_limit_stop) {
+		assoc_mgr_lock(&qos_read_lock);
+		list_for_each(assoc_mgr_qos_list,
+			      _clear_qos_blocked_times, NULL);
+		assoc_mgr_unlock(&qos_read_lock);
+	}
+
 	sort_job_queue(job_queue);
 	while (1) {
+		uint32_t bf_job_id, bf_array_task_id, bf_job_priority;
+
 		job_queue_rec = (job_queue_rec_t *) list_pop(job_queue);
 		if (!job_queue_rec) {
 			if (debug_flags & DEBUG_FLAG_BACKFILL)
 				info("backfill: reached end of job queue");
 			break;
 		}
+
+		job_ptr          = job_queue_rec->job_ptr;
+		part_ptr         = job_queue_rec->part_ptr;
+		bf_job_id        = job_queue_rec->job_id;
+		bf_job_priority  = job_queue_rec->priority;
+		bf_array_task_id = job_queue_rec->array_task_id;
+		xfree(job_queue_rec);
+
 		if (slurmctld_config.shutdown_time ||
 		    (difftime(time(NULL),orig_sched_start)>=backfill_interval)){
-			xfree(job_queue_rec);
 			break;
 		}
 		if (((defer_rpc_cnt > 0) &&
 		     (slurmctld_config.server_thread_count >= defer_rpc_cnt)) ||
-		    (_delta_tv(&start_tv) >= sched_timeout)) {
+		    (slurm_delta_tv(&start_tv) >= sched_timeout)) {
 			if (debug_flags & DEBUG_FLAG_BACKFILL) {
 				END_TIMER;
 				info("backfill: yielding locks after testing "
@@ -1040,7 +1064,6 @@ static int _attempt_backfill(void)
 					     job_test_count);
 				}
 				rc = 1;
-				xfree(job_queue_rec);
 				break;
 			}
 			/* Reset backfill scheduling timers, resume testing */
@@ -1051,17 +1074,14 @@ static int _attempt_backfill(void)
 			START_TIMER;
 		}
 
-		job_ptr  = job_queue_rec->job_ptr;
-
 		/* With bf_continue configured, the original job could have
 		 * been cancelled and purged. Validate pointer here. */
 		if ((job_ptr->magic  != JOB_MAGIC) ||
-		    (job_ptr->job_id != job_queue_rec->job_id)) {
-			xfree(job_queue_rec);
+		    (job_ptr->job_id != bf_job_id)) {
 			continue;
 		}
-		if ((job_ptr->array_task_id != job_queue_rec->array_task_id) &&
-		    (job_queue_rec->array_task_id == NO_VAL)) {
+		if ((job_ptr->array_task_id != bf_array_task_id) &&
+		    (bf_array_task_id == NO_VAL)) {
 			/* Job array element started in other partition,
 			 * reset pointer to "master" job array record */
 			job_ptr = find_job_record(job_ptr->array_job_id);
@@ -1072,9 +1092,8 @@ static int _attempt_backfill(void)
 		if (!_job_runnable_now(job_ptr))
 			continue;
 
-		part_ptr = job_queue_rec->part_ptr;
 		job_ptr->part_ptr = part_ptr;
-		job_ptr->priority = job_queue_rec->priority;
+		job_ptr->priority = bf_job_priority;
 		mcs_select = slurm_mcs_get_select(job_ptr);
 
 		if (job_ptr->state_reason == FAIL_ACCOUNT) {
@@ -1125,19 +1144,36 @@ static int _attempt_backfill(void)
 			}
 		}
 
+		assoc_mgr_lock(&qos_read_lock);
 		qos_ptr = (slurmdb_qos_rec_t *)job_ptr->qos_ptr;
+		qos_part_ptr = (slurmdb_qos_rec_t *)job_ptr->part_ptr->qos_ptr;
+		if (qos_ptr) {
+			qos_flags = qos_ptr->flags;
+			qos_blocked_until = qos_ptr->blocked_until;
+		} else {
+			qos_flags = 0;
+			qos_blocked_until = 0;
+		}
+
+		if (qos_part_ptr)
+			qos_part_blocked_until = qos_part_ptr->blocked_until;
+		else
+			qos_part_blocked_until = 0;
+
 		if (part_policy_valid_qos(job_ptr->part_ptr, qos_ptr) !=
 		    SLURM_SUCCESS) {
+			assoc_mgr_unlock(&qos_read_lock);
 			xfree(job_ptr->state_desc);
 			job_ptr->state_reason = WAIT_QOS;
 			last_job_update = now;
 			continue;
 		}
+		assoc_mgr_unlock(&qos_read_lock);
 
-		if (!acct_policy_job_runnable_state(job_ptr) &&
-		    (!assoc_limit_stop ||
-		     !acct_policy_job_runnable_pre_select(job_ptr)))
+		if (!assoc_limit_stop &&
+		    !acct_policy_job_runnable_pre_select(job_ptr)) {
 			continue;
+		}
 
 		job_no_reserve = 0;
 		if (bf_min_prio_reserve &&
@@ -1150,9 +1186,19 @@ static int _attempt_backfill(void)
 				job_no_reserve = TEST_NOW_ONLY;
 		}
 
+		if ((job_no_reserve == 0) && bf_job_part_count_reserve) {
+			for (j = 0; j < bf_parts; j++) {
+				if (bf_part_ptr[j] != job_ptr->part_ptr)
+					continue;
+				if (bf_part_resv[j] >=
+				    bf_job_part_count_reserve)
+					job_no_reserve = TEST_NOW_ONLY;
+				break;
+			}
+		}
+
 		orig_start_time = job_ptr->start_time;
 		orig_time_limit = job_ptr->time_limit;
-		xfree(job_queue_rec);
 
 next_task:
 		job_test_count++;
@@ -1254,8 +1300,7 @@ next_task:
 		}
 
 		if (((part_ptr->state_up & PARTITION_SCHED) == 0) ||
-		    (part_ptr->node_bitmap == NULL) ||
-		    ((part_ptr->flags & PART_FLAG_ROOT_ONLY) && filter_root)) {
+		    (part_ptr->node_bitmap == NULL)) {
 			if (debug_flags & DEBUG_FLAG_BACKFILL)
 				info("backfill: partition %s not usable",
 				     job_ptr->part_ptr->name);
@@ -1271,13 +1316,21 @@ next_task:
 		}
 
 		/* Determine minimum and maximum node counts */
-		min_nodes = MAX(job_ptr->details->min_nodes,
-				part_ptr->min_nodes);
+
+		/* check whether job is allowed to override partition limit */
+		if (qos_flags & QOS_FLAG_PART_MIN_NODE)
+			min_nodes = job_ptr->details->min_nodes;
+		else
+			min_nodes = MAX(job_ptr->details->min_nodes,
+					part_ptr->min_nodes);
 		if (job_ptr->details->max_nodes == 0)
 			max_nodes = part_ptr->max_nodes;
+		else if (qos_flags & QOS_FLAG_PART_MAX_NODE)
+			max_nodes = job_ptr->details->max_nodes;
 		else
 			max_nodes = MIN(job_ptr->details->max_nodes,
 					part_ptr->max_nodes);
+
 		max_nodes = MIN(max_nodes, 500000);     /* prevent overflows */
 		if (job_ptr->details->max_nodes)
 			req_nodes = max_nodes;
@@ -1329,15 +1382,29 @@ next_task:
 			comp_time_limit = MIN(time_limit, deadline_time_limit);
 		else
 			comp_time_limit = time_limit;
-		qos_ptr = job_ptr->qos_ptr;
-		if (qos_ptr && (qos_ptr->flags & QOS_FLAG_NO_RESERVE) &&
+		if ((qos_flags & QOS_FLAG_NO_RESERVE) &&
 		    slurm_get_preempt_mode())
 			time_limit = job_ptr->time_limit = 1;
 		else if (job_ptr->time_min && (job_ptr->time_min < time_limit))
 			time_limit = job_ptr->time_limit = job_ptr->time_min;
 
-		/* Determine impact of any resource reservations */
 		later_start = now;
+
+		if (assoc_limit_stop) {
+			if (qos_blocked_until > later_start) {
+				later_start = qos_blocked_until;
+				if (debug_flags & DEBUG_FLAG_BACKFILL)
+					info("QOS blocked_until move start_res to %ld",
+					     later_start);
+			}
+			if (qos_part_blocked_until > later_start) {
+				later_start = qos_part_blocked_until;
+				if (debug_flags & DEBUG_FLAG_BACKFILL)
+					info("Part QOS blocked_until move start_res to %ld",
+					     later_start);
+			}
+		}
+
  TRY_LATER:
 		if (slurmctld_config.shutdown_time ||
 		    (difftime(time(NULL), orig_sched_start) >=
@@ -1348,7 +1415,7 @@ next_task:
 		test_time_count++;
 		if (((defer_rpc_cnt > 0) &&
 		     (slurmctld_config.server_thread_count >= defer_rpc_cnt)) ||
-		    (_delta_tv(&start_tv) >= sched_timeout)) {
+		    (slurm_delta_tv(&start_tv) >= sched_timeout)) {
 			uint32_t save_job_id = job_ptr->job_id;
 			uint32_t save_time_limit = job_ptr->time_limit;
 			_set_job_time_limit(job_ptr, orig_time_limit);
@@ -1373,6 +1440,13 @@ next_task:
 				break;
 			}
 
+			/* Reset backfill scheduling timers, resume testing */
+			sched_start = time(NULL);
+			gettimeofday(&start_tv, NULL);
+			job_test_count = 1;
+			test_time_count = 0;
+			START_TIMER;
+
 			/* With bf_continue configured, the original job could
 			 * have been scheduled or cancelled and purged.
 			 * Revalidate job the record here. */
@@ -1391,20 +1465,15 @@ next_task:
 
 			job_ptr->time_limit = save_time_limit;
 			job_ptr->part_ptr = part_ptr;
-			/* Reset backfill scheduling timers, resume testing */
-			sched_start = time(NULL);
-			gettimeofday(&start_tv, NULL);
-			job_test_count = 1;
-			test_time_count = 0;
-			START_TIMER;
 		}
 
 		FREE_NULL_BITMAP(avail_bitmap);
 		FREE_NULL_BITMAP(exc_core_bitmap);
 		start_res   = later_start;
 		later_start = 0;
+		/* Determine impact of any advance reservations */
 		j = job_test_resv(job_ptr, &start_res, true, &avail_bitmap,
-				  &exc_core_bitmap, &resv_overlap);
+				  &exc_core_bitmap, &resv_overlap, false);
 		if (j != SLURM_SUCCESS) {
 			if (debug_flags & DEBUG_FLAG_BACKFILL)
 				info("backfill: job %u reservation defer",
@@ -1424,7 +1493,7 @@ next_task:
 		bit_and(avail_bitmap, up_node_bitmap);
 		filter_by_node_owner(job_ptr, avail_bitmap);
 		filter_by_node_mcs(job_ptr, mcs_select, avail_bitmap);
-		for (j=0; ; ) {
+		for (j = 0; ; ) {
 			if ((node_space[j].end_time > start_res) &&
 			     node_space[j].next && (later_start == 0))
 				later_start = node_space[j].end_time;
@@ -1513,7 +1582,47 @@ next_task:
 				test_fini = 0;
 			}
 		}
+		boot_time = 0;
+		if (test_fini == 0) {
+			/* Unable to start job using currently active features,
+			 * need to try using features which can be made
+			 * available after node reboot */
+			bitstr_t *tmp_core_bitmap = NULL;
+			bitstr_t *tmp_node_bitmap = NULL;
+			debug2("backfill: entering _try_sched for job %u. "
+			       "Need to use features which can be made "
+			       "available after node reboot", job_ptr->job_id);
+			/* Determine impact of any advance reservations */
+			j = job_test_resv(job_ptr, &start_res, true,
+					  &tmp_node_bitmap, &tmp_core_bitmap,
+					  &resv_overlap, true);
+			if (j == SLURM_SUCCESS) {
+				FREE_NULL_BITMAP(exc_core_bitmap);
+				exc_core_bitmap = tmp_core_bitmap;
+				bit_and(avail_bitmap, tmp_node_bitmap);
+				FREE_NULL_BITMAP(tmp_node_bitmap);
+			}
+			boot_time = node_features_g_boot_time();
+			orig_end_time = end_time;
+			end_time += boot_time;
+
+			for (j = 0; ; ) {
+				if (node_space[j].end_time <= start_res)
+					;
+				else if (node_space[j].begin_time <= end_time) {
+					if (node_space[j].begin_time >
+					    orig_end_time)
+						bit_and(avail_bitmap,
+						node_space[j].avail_bitmap);
+				} else
+					break;
+				if ((j = node_space[j].next) == 0)
+					break;
+			}
+		}
 		if (test_fini != 1) {
+			/* Either active_bitmap was NULL or not usable by the
+			 * job. Test using avail_bitmap instead */
 			j = _try_sched(job_ptr, &avail_bitmap, min_nodes,
 				       max_nodes, req_nodes, exc_core_bitmap);
 			if (test_fini == 0) {
@@ -1574,8 +1683,32 @@ next_task:
 			uint32_t save_time_limit = job_ptr->time_limit;
 			uint32_t hard_limit;
 			bool reset_time = false;
-			int rc = _start_job(job_ptr, resv_bitmap);
-			if (qos_ptr && (qos_ptr->flags & QOS_FLAG_NO_RESERVE)) {
+			int rc;
+
+			/* get fed job lock from origin cluster */
+			if (fed_mgr_job_lock(job_ptr, INFINITE)) {
+				xfree(job_ptr->state_desc);
+				job_ptr->state_reason = WAIT_FED_JOB_LOCK;
+				info("sched: JobId=%u can't get fed job lock from origin cluster to backfill job",
+				     job_ptr->job_id);
+				last_job_update = now;
+				continue;
+			}
+
+			rc = _start_job(job_ptr, resv_bitmap);
+
+			if (rc == SLURM_SUCCESS) {
+				/* If the following fails because of network
+				 * connectivity, the origin cluster should ask
+				 * when it comes back up if the cluster_lock
+				 * cluster actually started the job */
+				fed_mgr_job_start(job_ptr, INFINITE,
+						  job_ptr->start_time);
+			} else {
+				fed_mgr_job_unlock(job_ptr, INFINITE);
+			}
+
+			if (qos_flags & QOS_FLAG_NO_RESERVE) {
 				if (orig_time_limit == NO_VAL) {
 					acct_policy_alter_job(
 						job_ptr, comp_time_limit);
@@ -1623,7 +1756,8 @@ next_task:
 			}
 
 			if ((rc == ESLURM_RESERVATION_BUSY) ||
-			    (rc == ESLURM_ACCOUNTING_POLICY) ||
+			    (rc == ESLURM_ACCOUNTING_POLICY &&
+			     !assoc_limit_stop) ||
 			    (rc == ESLURM_POWER_NOT_AVAIL) ||
 			    (rc == ESLURM_POWER_RESERVED)) {
 				/* Unknown future start time, just skip job */
@@ -1634,6 +1768,31 @@ next_task:
 					job_ptr->start_time = 0;
 				_set_job_time_limit(job_ptr, orig_time_limit);
 				continue;
+			} else if (rc == ESLURM_ACCOUNTING_POLICY) {
+				/* Unknown future start time. Determining
+				 * when it can start with certainty requires
+				 * when every running and pending job starts
+				 * and ends and tracking all of there resources.
+				 * That requires very high overhead, that we
+				 * don't want to add. Estimate that it can start
+				 * after the next job ends (or in 5 minutes if
+				 * we don't have that information yet). */
+				if (later_start)
+					job_ptr->start_time = later_start;
+				else
+					job_ptr->start_time = now + 500;
+				if (job_ptr->qos_blocking_ptr &&
+				    job_state_qos_grp_limit(
+					    job_ptr->state_reason)) {
+					assoc_mgr_lock(&qos_read_lock);
+					qos_ptr = job_ptr->qos_blocking_ptr;
+					if (qos_ptr->blocked_until <
+					    job_ptr->start_time) {
+						qos_ptr->blocked_until =
+						job_ptr->start_time;
+					}
+					assoc_mgr_unlock(&qos_read_lock);
+				}
 			} else if (rc != SLURM_SUCCESS) {
 				if (debug_flags & DEBUG_FLAG_BACKFILL) {
 					info("backfill: planned start of job %u"
@@ -1678,18 +1837,29 @@ next_task:
 			_set_job_time_limit(job_ptr, orig_time_limit);
 		}
 
-		if ((job_ptr->start_time > now) && (job_no_reserve != 0))
+		if ((job_ptr->start_time > now) && (job_no_reserve != 0)) {
+			if ((orig_start_time != 0) &&
+			    (orig_start_time < job_ptr->start_time)) {
+				/* Can start earlier in different partition */
+				job_ptr->start_time = orig_start_time;
+			}
 			continue;
+		}
 
 		if (later_start && (job_ptr->start_time > later_start)) {
 			/* Try later when some nodes currently reserved for
 			 * pending jobs are free */
+			if (debug_flags & DEBUG_FLAG_BACKFILL) {
+				info("backfill: Try later job %u later_start %ld",
+			             job_ptr->job_id, later_start);
+			}
 			job_ptr->start_time = 0;
 			goto TRY_LATER;
 		}
 
 		start_time  = job_ptr->start_time;
-		end_reserve = job_ptr->start_time + (time_limit * 60);
+		end_reserve = job_ptr->start_time + boot_time +
+			      (time_limit * 60);
 		start_time  = (start_time / backfill_resolution) *
 			      backfill_resolution;
 		end_reserve = (end_reserve / backfill_resolution) *
@@ -1739,16 +1909,73 @@ next_task:
 			 * plugin does not know about. Try again later. */
 			later_start = job_ptr->start_time;
 			job_ptr->start_time = 0;
+			if (debug_flags & DEBUG_FLAG_BACKFILL) {
+				info("backfill: Job %u overlaps with existing "
+				     "reservation start_time=%u "
+				     "end_reserve=%u boot_time=%u "
+				     "later_start %ld", job_ptr->job_id,
+				     start_time, end_reserve, boot_time,
+				     later_start);
+			}
 			goto TRY_LATER;
 		}
 
 		/*
 		 * Add reservation to scheduling table if appropriate
 		 */
+		if (!assoc_limit_stop) {
+			uint32_t selected_node_cnt;
+			uint64_t tres_req_cnt[slurmctld_tres_cnt];
+
+			selected_node_cnt = bit_set_count(avail_bitmap);
+			memcpy(tres_req_cnt, job_ptr->tres_req_cnt,
+			       sizeof(tres_req_cnt));
+			tres_req_cnt[TRES_ARRAY_CPU] =
+				(uint64_t)(job_ptr->total_cpus ?
+					   job_ptr->total_cpus :
+					   job_ptr->details->min_cpus);
+
+			tres_req_cnt[TRES_ARRAY_MEM] = job_get_tres_mem(
+						job_ptr->details->pn_min_memory,
+						tres_req_cnt[TRES_ARRAY_CPU],
+						selected_node_cnt);
+
+			tres_req_cnt[TRES_ARRAY_NODE] =
+				(uint64_t)selected_node_cnt;
+
+			gres_set_job_tres_cnt(job_ptr->gres_list,
+					      selected_node_cnt,
+					      tres_req_cnt,
+					      false);
+
+			if (!acct_policy_job_runnable_post_select(job_ptr,
+							  tres_req_cnt)) {
+				if (debug_flags & DEBUG_FLAG_BACKFILL) {
+					info("backfill: adding reservation for "
+					     "job %u blocked by "
+					     "acct_policy_job_runnable_post_select",
+					     job_ptr->job_id);
+				}
+				continue;
+			}
+		}
 		if (debug_flags & DEBUG_FLAG_BACKFILL)
 			_dump_job_sched(job_ptr, end_reserve, avail_bitmap);
-		if (qos_ptr && (qos_ptr->flags & QOS_FLAG_NO_RESERVE))
+		if (qos_flags & QOS_FLAG_NO_RESERVE)
 			continue;
+		if (bf_job_part_count_reserve) {
+			bool do_reserve = true;
+			for (j = 0; j < bf_parts; j++) {
+				if (bf_part_ptr[j] != job_ptr->part_ptr)
+					continue;
+				if (bf_part_resv[j]++ >=
+				    bf_job_part_count_reserve)
+					do_reserve = false;
+				break;
+			}
+			if (!do_reserve)
+				continue;
+		}
 		reject_array_job_id = 0;
 		reject_array_part   = NULL;
 		xfree(job_ptr->sched_nodes);
@@ -1777,6 +2004,7 @@ next_task:
 		}
 	}
 	xfree(bf_part_jobs);
+	xfree(bf_part_resv);
 	xfree(bf_part_ptr);
 	xfree(uid);
 	xfree(njobs);
