@@ -9,7 +9,7 @@
  *  Written by Danny Auble <da@schedmd.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -38,13 +38,10 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <math.h>
+
 #include "block_allocator.h"
 #include "src/common/uid.h"
 #include "src/common/timers.h"
@@ -263,7 +260,7 @@ extern void ba_create_system()
 					ba_setup_mp(ba_mp, true, false);
 					ba_mp->state = NODE_STATE_IDLE;
 					/* This might get changed
-					   later, but just incase set
+					   later, but just in case set
 					   it up here.
 					*/
 					ba_mp->index = i++;
