@@ -9,7 +9,7 @@
  *  Written by Martin Perry <martin.perry@bull.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -329,7 +329,6 @@ static void _block_sync_core_bitmap(struct job_record *job_ptr,
 	uint16_t cpus_per_task = job_ptr->details->cpus_per_task;
 	job_resources_t *job_res = job_ptr->job_resrcs;
 	bool alloc_cores = false, alloc_sockets = false;
-	uint16_t ncpus_per_core = 0xffff;	/* Usable CPUs per core */
 	uint16_t ntasks_per_core = 0xffff;
 	int tmp_cpt = 0;
 	int count, cpu_min, b_min, elig, s_min, comb_idx, sock_idx;
@@ -376,11 +375,6 @@ static void _block_sync_core_bitmap(struct job_record *job_ptr,
 		if ((mc_ptr->ntasks_per_core != (uint16_t) INFINITE) &&
 		    (mc_ptr->ntasks_per_core)) {
 			ntasks_per_core = mc_ptr->ntasks_per_core;
-			ncpus_per_core  = ntasks_per_core * cpus_per_task;
-		}
-		if ((mc_ptr->threads_per_core != (uint16_t) NO_VAL) &&
-		    (mc_ptr->threads_per_core <  ncpus_per_core)) {
-			ncpus_per_core = mc_ptr->threads_per_core;
 		}
 	}
 
@@ -409,7 +403,7 @@ static void _block_sync_core_bitmap(struct job_record *job_ptr,
 			fatal("cons_res: _block_sync_core_bitmap index error");
 
 		cpus  = job_res->cpus[i];
-		vpus = MIN(select_node_record[n].vpus, ncpus_per_core);
+		vpus = cr_cpus_per_core(job_ptr->details, n);
 
 		/* compute still required cores on the node */
 		req_cores = cpus / vpus;
@@ -721,12 +715,10 @@ static int _cyclic_sync_core_bitmap(struct job_record *job_ptr,
 {
 	uint32_t c, i, j, s, n, *sock_start, *sock_end, size, csize, core_cnt;
 	uint16_t cps = 0, cpus, vpus, sockets, sock_size;
-	uint16_t cpus_per_task = job_ptr->details->cpus_per_task;
 	job_resources_t *job_res = job_ptr->job_resrcs;
 	bitstr_t *core_map;
 	bool *sock_used, *sock_avoid;
 	bool alloc_cores = false, alloc_sockets = false;
-	uint16_t ncpus_per_core = 0xffff;	/* Usable CPUs per core */
 	uint16_t ntasks_per_socket = 0xffff;
 	uint16_t ntasks_per_core = 0xffff;
 	int error_code = SLURM_SUCCESS;
@@ -747,12 +739,6 @@ static int _cyclic_sync_core_bitmap(struct job_record *job_ptr,
 		if ((mc_ptr->ntasks_per_core != (uint16_t) INFINITE) &&
 		    (mc_ptr->ntasks_per_core)) {
 			ntasks_per_core = mc_ptr->ntasks_per_core;
-			ncpus_per_core  = ntasks_per_core * cpus_per_task;
-		}
-
-		if ((mc_ptr->threads_per_core != (uint16_t) NO_VAL) &&
-		    (mc_ptr->threads_per_core <  ncpus_per_core)) {
-			ncpus_per_core = mc_ptr->threads_per_core;
 		}
 
 		if (mc_ptr->ntasks_per_socket)
@@ -772,7 +758,7 @@ static int _cyclic_sync_core_bitmap(struct job_record *job_ptr,
 			continue;
 		sockets = select_node_record[n].sockets;
 		cps     = select_node_record[n].cores;
-		vpus = MIN(select_node_record[n].vpus, ncpus_per_core);
+		vpus    = cr_cpus_per_core(job_ptr->details, n);
 
 		if (select_debug_flags & DEBUG_FLAG_SELECT_TYPE) {
 			info("DEBUG: job %u node %s vpus %u cpus %u",
@@ -954,29 +940,36 @@ fini:	xfree(sock_avoid);
 }
 
 /* Remove any specialized cores from those allocated to the job */
-static void _clear_spec_cores(bitstr_t *alloc_node_bitmap,
-			      bitstr_t *alloc_core_bitmap,
+static void _clear_spec_cores(job_resources_t *job_res,
 			      bitstr_t *avail_core_bitmap)
 {
 	int first_node, last_node, i_node;
 	int first_core, last_core, i_core;
-	int alloc_core = -1;
+	int alloc_node = -1, alloc_core = -1, size;
 
-	first_node = bit_ffs(alloc_node_bitmap);
+	size = bit_size(job_res->core_bitmap);
+	bit_nset(job_res->core_bitmap, 0, size - 1);
+
+	first_node = bit_ffs(job_res->node_bitmap);
 	if (first_node >= 0)
-		last_node = bit_fls(alloc_node_bitmap);
+		last_node = bit_fls(job_res->node_bitmap);
 	else
 		last_node = first_node - 1;
 
 	for (i_node = first_node; i_node <= last_node; i_node++) {
-		if (!bit_test(alloc_node_bitmap, i_node))
+		if (!bit_test(job_res->node_bitmap, i_node))
 			continue;
+		job_res->cpus[++alloc_node] = 0;
 		first_core = cr_get_coremap_offset(i_node);
 		last_core  = cr_get_coremap_offset(i_node + 1) - 1;
 		for (i_core = first_core; i_core <= last_core; i_core++) {
 			alloc_core++;
-			if (!bit_test(avail_core_bitmap, i_core))
-				bit_clear(alloc_core_bitmap, alloc_core);
+			if (bit_test(avail_core_bitmap, i_core)) {
+				job_res->cpus[alloc_node] +=
+					select_node_record[i_node].vpus;
+			} else {
+				bit_clear(job_res->core_bitmap, alloc_core);
+			}
 		}
 	}
 }
@@ -1029,13 +1022,11 @@ extern int cr_dist(struct job_record *job_ptr, const uint16_t cr_type,
 	if ((job_ptr->job_resrcs->node_req == NODE_CR_RESERVED) ||
 	    (job_ptr->details->whole_node == 1)) {
 		/* The job has been allocated an EXCLUSIVE set of nodes,
-		 * so it gets all of the bits in the core_bitmap and
-		 * all of the available CPUs in the cpus array. */
-		int size = bit_size(job_ptr->job_resrcs->core_bitmap);
-		bit_nset(job_ptr->job_resrcs->core_bitmap, 0, size - 1);
-		_clear_spec_cores(job_ptr->job_resrcs->node_bitmap,
-				  job_ptr->job_resrcs->core_bitmap,
-				  avail_core_bitmap);
+		 * so it gets all of the bits in the core_bitmap and all of
+		 * the available CPUs in the cpus array. Up to this point
+		 * we might not have the correct CPU count, but a core count
+		 * and ignoring specialized cores. Fix that too. */
+		_clear_spec_cores(job_ptr->job_resrcs, avail_core_bitmap);
 		return SLURM_SUCCESS;
 	}
 
