@@ -5,7 +5,7 @@
  *  Written by Morris Jette <jette@schedmd.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com>.
+ *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -34,10 +34,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <poll.h>
 #include <pthread.h>
 #include <stdlib.h>
@@ -62,16 +58,13 @@
 
 /* This version string is defined at configure time of libsmd. The
  * META of libsmd needs to reflect this version. */
-char *version_string = "VERSION:16.05";
+char *version_string = "VERSION:17.02";
 
 /* When a remote socket closes on AIX, we have seen poll() return EAGAIN
  * indefinitely for a pending write request. Rather than locking up
  * socket, abort after _MAX_RETRIES poll() failures. */
 #define _MAX_RETRIES	10
 
-/* Maximum size of any single field returned (e.g. node list, job name). */
-#define _MAX_NAME_SIZE	256
-
 static bool thread_running = false;
 static bool thread_shutdown = false;
 static pthread_mutex_t thread_flag_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -149,7 +142,7 @@ static size_t _write_bytes(int fd, char *buf, size_t size)
 	return size;
 }
 
-static char *_recv_msg(slurm_fd_t new_fd)
+static char *_recv_msg(int new_fd)
 {
 	char header[10];
 	unsigned long size;
@@ -179,7 +172,7 @@ static char *_recv_msg(slurm_fd_t new_fd)
 	return buf;
 }
 
-static void _send_reply(slurm_fd_t new_fd, char *msg)
+static void _send_reply(int new_fd, char *msg)
 {
 	uint32_t data_sent, msg_size = 0;
 	char header[10];
@@ -214,20 +207,20 @@ static char *_decrypt(char *msg, uid_t *uid)
 	return (char *) buf_out;
 }
 
-static void _proc_msg(slurm_fd_t new_fd, char *msg, slurm_addr_t cli_addr)
+static void _proc_msg(int new_fd, char *msg, slurm_addr_t cli_addr)
 {
 	/* Locks: Read job and node data */
 	slurmctld_lock_t job_read_lock = {
-		NO_LOCK, READ_LOCK, READ_LOCK, NO_LOCK };
+		NO_LOCK, READ_LOCK, READ_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Write job */
 	slurmctld_lock_t job_write_lock = {
-		NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
+		NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Write job, write node, read partition */
 	slurmctld_lock_t job_write_lock2 = {
-		NO_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK };
+		NO_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK, READ_LOCK };
 	/* Locks: Write node data */
 	slurmctld_lock_t node_write_lock = {
-		NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK };
+		NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK, READ_LOCK };
 	char *cmd_ptr, *resp = NULL, *msg_decrypted = NULL;
 	uid_t cmd_uid;
 	uint32_t protocol_version = 0;
@@ -306,7 +299,7 @@ static void _proc_msg(slurm_fd_t new_fd, char *msg, slurm_addr_t cli_addr)
 
 static void *_msg_thread(void *no_data)
 {
-	slurm_fd_t sock_fd = -1, new_fd;
+	int sock_fd = -1, new_fd;
 	slurm_addr_t cli_addr;
 	char *msg;
 	int i;
