@@ -7,7 +7,7 @@
  *  Written by Morris Jette <jette@schedmd.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -36,19 +36,13 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
-#include <netinet/in.h>
 #include <arpa/inet.h>
-#include <sys/types.h>
-#include <sys/socket.h>
 #include <ifaddrs.h>
 #include <netdb.h>
+#include <netinet/in.h>
 #include <signal.h>
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -482,15 +476,18 @@ int switch_p_pack_jobinfo(switch_jobinfo_t *switch_job, Buf buffer,
 	return SLURM_SUCCESS;
 }
 
-int switch_p_unpack_jobinfo(switch_jobinfo_t *switch_job, Buf buffer,
+int switch_p_unpack_jobinfo(switch_jobinfo_t **switch_job, Buf buffer,
 			    uint16_t protocol_version)
 {
-	sw_gen_step_info_t *gen_step_info = (sw_gen_step_info_t *) switch_job;
+	sw_gen_step_info_t *gen_step_info;
 	sw_gen_node_t *node_ptr;
 	sw_gen_ifa_t *ifa_ptr;
 	uint32_t uint32_tmp;
 	int i, j;
 
+	switch_p_alloc_jobinfo(switch_job, 0, 0);
+	gen_step_info = (sw_gen_step_info_t *) *switch_job;
+
 	if (debug_flags & DEBUG_FLAG_SWITCH)
 		info("switch_p_unpack_jobinfo() starting");
 	safe_unpack32(&gen_step_info->node_cnt, buffer);
@@ -524,21 +521,10 @@ int switch_p_unpack_jobinfo(switch_jobinfo_t *switch_job, Buf buffer,
 	return SLURM_SUCCESS;
 
 unpack_error:
-	for (i = 0; i < gen_step_info->node_cnt; i++) {
-		node_ptr = gen_step_info->node_array[i];
-		for (j = 0; j < node_ptr->ifa_cnt; j++) {
-			ifa_ptr = node_ptr->ifa_array[j];
-			xfree(ifa_ptr->ifa_addr);
-			xfree(ifa_ptr->ifa_family);
-			xfree(ifa_ptr->ifa_name);
-			xfree(ifa_ptr);
-		}
-		xfree(node_ptr->ifa_array);
-		xfree(node_ptr->node_name);
-		xfree(node_ptr);
-	}
-	gen_step_info->node_cnt = 0;
-	xfree(gen_step_info->node_array);
+
+	switch_p_free_jobinfo((switch_jobinfo_t *)gen_step_info);
+	*switch_job = NULL;
+
 	return SLURM_ERROR;
 }
 
@@ -709,7 +695,7 @@ extern int switch_p_get_jobinfo(switch_jobinfo_t *switch_job,
 	sw_gen_ifa_t *ifa_ptr;
 	int i, s;
 	int bufsize = 1024;
-	char *buf = xmalloc(bufsize);
+	char *buf;
 
 #if defined(__FreeBSD__)
 #define IFNAMSIZ 16
@@ -731,6 +717,7 @@ extern int switch_p_get_jobinfo(switch_jobinfo_t *switch_job,
 		return SLURM_ERROR;
 	}
 
+	buf = xmalloc(bufsize);
 	s = snprintf(buf, bufsize, "(%s", node_ptr->node_name);
 	/* appends in buf triplets (ifname,ipversion,address) */
 	for (i = 0; i < node_ptr->ifa_cnt; i++) {
@@ -876,16 +863,42 @@ extern int switch_p_pack_node_info(switch_node_info_t *switch_node,
 	return SLURM_SUCCESS;
 }
 
-extern int switch_p_unpack_node_info(switch_node_info_t *switch_node,
+extern int switch_p_free_node_info(switch_node_info_t **switch_node)
+{
+	sw_gen_node_info_t *gen_node_info = (sw_gen_node_info_t *) *switch_node;
+	int i;
+
+	if (debug_flags & DEBUG_FLAG_SWITCH)
+		info("switch_p_free_node_info() starting");
+	xassert(gen_node_info);
+	xassert(gen_node_info->magic == SW_GEN_NODE_INFO_MAGIC);
+	for (i = 0; i < gen_node_info->ifa_cnt; i++) {
+		xfree(gen_node_info->ifa_array[i]->ifa_addr);
+		xfree(gen_node_info->ifa_array[i]->ifa_family);
+		xfree(gen_node_info->ifa_array[i]->ifa_name);
+		xfree(gen_node_info->ifa_array[i]);
+	}
+	xfree(gen_node_info->ifa_array);
+	xfree(gen_node_info->node_name);
+	xfree(gen_node_info);
+
+	return SLURM_SUCCESS;
+}
+
+extern int switch_p_unpack_node_info(switch_node_info_t **switch_node,
 				     Buf buffer, uint16_t protocol_version)
 {
-	sw_gen_node_info_t *gen_node_info = (sw_gen_node_info_t *) switch_node;
+	sw_gen_node_info_t *gen_node_info;
 	sw_gen_ifa_t *ifa_ptr;
 	uint32_t uint32_tmp;
 	int i;
 
 	if (debug_flags & DEBUG_FLAG_SWITCH)
 		info("switch_p_unpack_node_info() starting");
+
+	switch_p_alloc_node_info(switch_node);
+	gen_node_info = (sw_gen_node_info_t *) *switch_node;
+
 	safe_unpack16(&gen_node_info->ifa_cnt, buffer);
 	gen_node_info->ifa_array = xmalloc(sizeof(sw_gen_ifa_t *) *
 					   gen_node_info->ifa_cnt);
@@ -911,40 +924,12 @@ extern int switch_p_unpack_node_info(switch_node_info_t *switch_node,
 	return SLURM_SUCCESS;
 
 unpack_error:
-	for (i = 0; i < gen_node_info->ifa_cnt; i++) {
-		xfree(gen_node_info->ifa_array[i]->ifa_addr);
-		xfree(gen_node_info->ifa_array[i]->ifa_family);
-		xfree(gen_node_info->ifa_array[i]->ifa_name);
-		xfree(gen_node_info->ifa_array[i]);
-	}
-	xfree(gen_node_info->ifa_array);
-	xfree(gen_node_info->node_name);
-	gen_node_info->ifa_cnt = 0;
+
+	switch_p_free_node_info(switch_node);
+
 	return SLURM_ERROR;
 }
 
-extern int switch_p_free_node_info(switch_node_info_t **switch_node)
-{
-	sw_gen_node_info_t *gen_node_info = (sw_gen_node_info_t *) *switch_node;
-	int i;
-
-	if (debug_flags & DEBUG_FLAG_SWITCH)
-		info("switch_p_free_node_info() starting");
-	xassert(gen_node_info);
-	xassert(gen_node_info->magic == SW_GEN_NODE_INFO_MAGIC);
-	for (i = 0; i < gen_node_info->ifa_cnt; i++) {
-		xfree(gen_node_info->ifa_array[i]->ifa_addr);
-		xfree(gen_node_info->ifa_array[i]->ifa_family);
-		xfree(gen_node_info->ifa_array[i]->ifa_name);
-		xfree(gen_node_info->ifa_array[i]);
-	}
-	xfree(gen_node_info->ifa_array);
-	xfree(gen_node_info->node_name);
-	xfree(gen_node_info);
-
-	return SLURM_SUCCESS;
-}
-
 extern char *switch_p_sprintf_node_info(switch_node_info_t *switch_node,
 				        char *buf, size_t size)
 {
