@@ -1,12 +1,11 @@
 /*****************************************************************************\
  *  shr_64.c - This plug is used by POE to interact with SLURM.
- *
  *****************************************************************************
  *  Copyright (C) 2012 SchedMD LLC.
  *  Written by Danny Auble <da@schedmd.com> et. al.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -35,27 +34,16 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
+#include "config.h"
+
+#include <arpa/inet.h>
 #include <ctype.h>
 #include <dlfcn.h>
 #include <fcntl.h>
+#include <nrt.h>
+#include <permapi.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <arpa/inet.h>
-
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
-#if HAVE_NRT_H
-# include <nrt.h>
-#else
-# error "Must have nrt.h to compile this module!"
-#endif
-#if HAVE_PERMAPI_H
-# include <permapi.h>
-#else
-# error "Must have permapi.h to compile this module!"
-#endif
 
 #include "src/common/slurm_xlator.h"
 #include "slurm/slurm.h"
@@ -108,7 +96,7 @@ extern FILE *pmd_lfp;
 
 typedef struct agent_data {
 	uint32_t   fe_auth_key;
-	slurm_fd_t fe_comm_socket;
+	int fe_comm_socket;
 } agent_data_t;
 
 static char *_name_from_addr(char *addr)
@@ -256,7 +244,7 @@ unpack_error:
 
 /* Validate a message connection
  * Return: true=valid/authenticated */
-static bool _validate_connect(slurm_fd_t socket_conn, uint32_t auth_key)
+static bool _validate_connect(int socket_conn, uint32_t auth_key)
 {
 	struct timeval tv;
 	fd_set read_fds;
@@ -294,9 +282,9 @@ static bool _validate_connect(slurm_fd_t socket_conn, uint32_t auth_key)
 }
 
 /* Process a message from PMD */
-static void _agent_proc_connect(slurm_fd_t fe_comm_socket,uint32_t fe_auth_key)
+static void _agent_proc_connect(int fe_comm_socket,uint32_t fe_auth_key)
 {
-	slurm_fd_t fe_comm_conn = -1;
+	int fe_comm_conn = -1;
 	slurm_addr_t be_addr;
 	bool be_connected = false;
 	Buf buffer = NULL;
@@ -358,7 +346,7 @@ static void *_agent_thread(void *arg)
 {
         agent_data_t *agent_data_ptr = (agent_data_t *) arg;
 	uint32_t   fe_auth_key    = agent_data_ptr->fe_auth_key;
-	slurm_fd_t fe_comm_socket = agent_data_ptr->fe_comm_socket;
+	int fe_comm_socket = agent_data_ptr->fe_comm_socket;
 	fd_set except_fds, read_fds;
 	struct timeval tv;
 	int i, n_fds;
@@ -408,7 +396,7 @@ static void _spawn_fe_agent(void)
 {
 	char hostname[256];
 	uint32_t   fe_auth_key = 0;
-	slurm_fd_t fe_comm_socket = -1;
+	int fe_comm_socket = -1;
 	slurm_addr_t comm_addr;
 	uint16_t comm_port;
 	pthread_attr_t agent_attr;
@@ -496,7 +484,7 @@ srun_job_t * _read_job_srun_agent(void)
 	char *key_str  = getenv("SLURM_FE_KEY");
 	char *sock_str = getenv("SLURM_FE_SOCKET");
 	char buf[32], *host, *sep;
-	slurm_fd_t resp_socket;
+	int resp_socket;
 	uint16_t resp_port;
 	uint32_t resp_auth_key, buf_size;
 	srun_job_t *srun_job = NULL;
