@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -137,7 +137,7 @@ extern int _addto_uid_char_list(List char_list, char *names)
 	return count;
 }
 
-static int _set_cond(int *start, int argc, char *argv[],
+static int _set_cond(int *start, int argc, char **argv,
 		     slurmdb_archive_cond_t *arch_cond)
 {
 	int i;
@@ -189,6 +189,14 @@ static int _set_cond(int *start, int argc, char *argv[],
 					  MAX(command_len, 1))) {
 			arch_cond->purge_suspend |= SLURMDB_PURGE_ARCHIVE;
 			set = 1;
+		} else if (!end && !strncasecmp(argv[i], "txn",
+					  MAX(command_len, 1))) {
+			arch_cond->purge_txn |= SLURMDB_PURGE_ARCHIVE;
+			set = 1;
+		} else if (!end && !strncasecmp(argv[i], "usage",
+					  MAX(command_len, 1))) {
+			arch_cond->purge_usage |= SLURMDB_PURGE_ARCHIVE;
+			set = 1;
 		} else if (!end
 			  || !strncasecmp(argv[i], "Clusters",
 					  MAX(command_len, 1))) {
@@ -315,6 +323,24 @@ static int _set_cond(int *start, int argc, char *argv[],
 				arch_cond->purge_suspend |= tmp;
 				set = 1;
 			}
+		} else if (!strncasecmp (argv[i], "PurgeTXNAfter",
+					 MAX(command_len, 10))) {
+			if ((tmp = slurmdb_parse_purge(argv[i]+end))
+			    == NO_VAL) {
+				exit_code = 1;
+			} else {
+				arch_cond->purge_txn |= tmp;
+				set = 1;
+			}
+		} else if (!strncasecmp (argv[i], "PurgeUsageAfter",
+					 MAX(command_len, 10))) {
+			if ((tmp = slurmdb_parse_purge(argv[i]+end))
+			    == NO_VAL) {
+				exit_code = 1;
+			} else {
+				arch_cond->purge_usage |= tmp;
+				set = 1;
+			}
 		} else if (!strncasecmp (argv[i], "PurgeEventMonths",
 					 MAX(command_len, 6))) {
 			if (get_uint(argv[i]+end, &tmp, "PurgeEventMonths")
@@ -366,6 +392,28 @@ static int _set_cond(int *start, int argc, char *argv[],
 					|= SLURMDB_PURGE_MONTHS;
 				set = 1;
 			}
+		} else if (!strncasecmp (argv[i], "PurgeTXNMonths",
+					 MAX(command_len, 6))) {
+			if (get_uint(argv[i]+end, &tmp, "PurgeTXNMonths")
+			    != SLURM_SUCCESS) {
+				exit_code = 1;
+			} else {
+				arch_cond->purge_txn |= tmp;
+				arch_cond->purge_txn
+					|= SLURMDB_PURGE_MONTHS;
+				set = 1;
+			}
+		} else if (!strncasecmp (argv[i], "PurgeUsageMonths",
+					 MAX(command_len, 6))) {
+			if (get_uint(argv[i]+end, &tmp, "PurgeUsageMonths")
+			    != SLURM_SUCCESS) {
+				exit_code = 1;
+			} else {
+				arch_cond->purge_usage |= tmp;
+				arch_cond->purge_usage
+					|= SLURMDB_PURGE_MONTHS;
+				set = 1;
+			}
 		} else if (!strncasecmp (argv[i], "Start",
 					 MAX(command_len, 2))) {
 			job_cond->usage_start = parse_time(argv[i]+end, 1);
@@ -394,15 +442,15 @@ static int _set_cond(int *start, int argc, char *argv[],
 	return set;
 }
 
-extern int sacctmgr_archive_dump(int argc, char *argv[])
+extern int sacctmgr_archive_dump(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_archive_cond_t *arch_cond =
 		xmalloc(sizeof(slurmdb_archive_cond_t));
-	int i=0;
+	int i;
 	struct stat st;
 
-	for (i=0; i<argc; i++) {
+	for (i = 0; i < argc; i++) {
 		int command_len = strlen(argv[i]);
 		if (!strncasecmp (argv[i], "Where", MAX(command_len, 5))
 		    || !strncasecmp (argv[i], "Set", MAX(command_len, 3)))
@@ -420,6 +468,10 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 		arch_cond->purge_step = NO_VAL;
 	if (!arch_cond->purge_suspend)
 		arch_cond->purge_suspend = NO_VAL;
+	if (!arch_cond->purge_txn)
+		arch_cond->purge_txn = NO_VAL;
+	if (!arch_cond->purge_usage)
+		arch_cond->purge_usage = NO_VAL;
 
 	if (exit_code) {
 		slurmdb_destroy_archive_cond(arch_cond);
@@ -434,6 +486,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 				"the directory must be on "
 				"the calling host.\n",
 				arch_cond->archive_dir, slurm_strerror(errno));
+			slurmdb_destroy_archive_cond(arch_cond);
 			return SLURM_ERROR;
 		}
 
@@ -442,6 +495,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 			fprintf(stderr, " dump: "
 				"archive dir %s isn't a directory\n",
 				arch_cond->archive_dir);
+			slurmdb_destroy_archive_cond(arch_cond);
 			return SLURM_ERROR;
 		}
 
@@ -450,6 +504,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 			fprintf(stderr, " dump: "
 				"archive dir %s is not writable\n",
 				arch_cond->archive_dir);
+			slurmdb_destroy_archive_cond(arch_cond);
 			return SLURM_ERROR;
 		}
 	}
@@ -462,6 +517,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 				"the calling host.\n",
 				arch_cond->archive_script,
 				slurm_strerror(errno));
+			slurmdb_destroy_archive_cond(arch_cond);
 			return SLURM_ERROR;
 		}
 		if (!(st.st_mode & S_IFREG)) {
@@ -469,6 +525,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 			fprintf(stderr, " dump: "
 				"archive script %s isn't a regular file\n",
 				arch_cond->archive_script);
+			slurmdb_destroy_archive_cond(arch_cond);
 			return SLURM_ERROR;
 		}
 
@@ -477,6 +534,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 			fprintf(stderr, " dump: "
 				"archive script %s is not executable\n",
 				arch_cond->archive_script);
+			slurmdb_destroy_archive_cond(arch_cond);
 			return SLURM_ERROR;
 		}
 	}
@@ -490,7 +548,7 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 			acct_storage_g_commit(db_conn, 0);
 		}
 	} else {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Problem dumping archive: %s\n",
 			slurm_strerror(rc));
 		rc = SLURM_ERROR;
@@ -500,15 +558,15 @@ extern int sacctmgr_archive_dump(int argc, char *argv[])
 	return rc;
 }
 
-extern int sacctmgr_archive_load(int argc, char *argv[])
+extern int sacctmgr_archive_load(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_archive_rec_t *arch_rec =
 		xmalloc(sizeof(slurmdb_archive_rec_t));
-	int i=0, command_len = 0;
+	int i, command_len = 0;
 	struct stat st;
 
-	for (i=0; i<argc; i++) {
+	for (i = 0; i < argc; i++) {
 		int end = parse_option_end(argv[i]);
 		if (!end)
 			command_len=strlen(argv[i]);
@@ -527,7 +585,7 @@ extern int sacctmgr_archive_load(int argc, char *argv[])
 					 MAX(command_len, 2))) {
 			arch_rec->insert = strip_quotes(argv[i]+end, NULL, 1);
 		} else {
-			exit_code=1;
+			exit_code = 1;
 			fprintf(stderr, " Unknown option: %s\n", argv[i]);
 		}
 	}
@@ -557,6 +615,7 @@ extern int sacctmgr_archive_load(int argc, char *argv[])
 				"Note: For archive load, the file must be on "
 				"the calling host.\n",
 				arch_rec->archive_file, slurm_strerror(errno));
+			slurmdb_destroy_archive_rec(arch_rec);
 			return SLURM_ERROR;
 		}
 	}
@@ -570,7 +629,7 @@ extern int sacctmgr_archive_load(int argc, char *argv[])
 			acct_storage_g_commit(db_conn, 0);
 		}
 	} else {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Problem loading archive file: %s\n",
 			slurm_strerror(rc));
 		rc = SLURM_ERROR;
