@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -112,7 +112,7 @@ static uint16_t _parse_preempt_modes(char *names)
 	return preempt_mode;
 }
 
-static int _set_cond(int *start, int argc, char *argv[],
+static int _set_cond(int *start, int argc, char **argv,
 		     slurmdb_qos_cond_t *qos_cond,
 		     List format_list)
 {
@@ -231,7 +231,7 @@ static int _set_cond(int *start, int argc, char *argv[],
 	return set;
 }
 
-static int _set_rec(int *start, int argc, char *argv[],
+static int _set_rec(int *start, int argc, char **argv,
 		    List name_list,
 		    slurmdb_qos_rec_t *qos)
 {
@@ -768,10 +768,10 @@ end_it:
 }
 
 
-extern int sacctmgr_add_qos(int argc, char *argv[])
+extern int sacctmgr_add_qos(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
-	int i=0, limit_set=0;
+	int i, limit_set = 0;
 	ListIterator itr = NULL;
 	slurmdb_qos_rec_t *qos = NULL;
 	slurmdb_qos_rec_t *start_qos = xmalloc(sizeof(slurmdb_qos_rec_t));
@@ -783,7 +783,7 @@ extern int sacctmgr_add_qos(int argc, char *argv[])
 
 	slurmdb_init_qos_rec(start_qos, 0, NO_VAL);
 
-	for (i=0; i<argc; i++) {
+	for (i = 0; i < argc; i++) {
 		int command_len = strlen(argv[i]);
 		if (!strncasecmp (argv[i], "Where", MAX(command_len, 5))
 		    || !strncasecmp (argv[i], "Set", MAX(command_len, 3)))
@@ -794,12 +794,12 @@ extern int sacctmgr_add_qos(int argc, char *argv[])
 
 	if (exit_code) {
 		FREE_NULL_LIST(name_list);
-		xfree(description);
+		slurmdb_destroy_qos_rec(start_qos);
 		return SLURM_ERROR;
 	} else if (!list_count(name_list)) {
 		FREE_NULL_LIST(name_list);
 		slurmdb_destroy_qos_rec(start_qos);
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Need name of qos to add.\n");
 		return SLURM_SUCCESS;
 	}
@@ -808,12 +808,12 @@ extern int sacctmgr_add_qos(int argc, char *argv[])
 		g_qos_list = acct_storage_g_get_qos(db_conn, my_uid, NULL);
 
 		if (!g_qos_list) {
-			exit_code=1;
+			exit_code = 1;
 			fprintf(stderr, " Problem getting qos's "
 				"from database.  "
 				"Contact your admin.\n");
 			FREE_NULL_LIST(name_list);
-			xfree(description);
+			slurmdb_destroy_qos_rec(start_qos);
 			return SLURM_ERROR;
 		}
 	}
@@ -821,18 +821,18 @@ extern int sacctmgr_add_qos(int argc, char *argv[])
 	qos_list = list_create(slurmdb_destroy_qos_rec);
 
 	itr = list_iterator_create(name_list);
-	while((name = list_next(itr))) {
+	while ((name = list_next(itr))) {
 		qos = NULL;
 		if (!sacctmgr_find_qos_from_list(g_qos_list, name)) {
 			qos = xmalloc(sizeof(slurmdb_qos_rec_t));
 			slurmdb_init_qos_rec(qos, 0, NO_VAL);
 			qos->name = xstrdup(name);
-			if (start_qos->description)
+			if (start_qos->description) {
 				qos->description =
 					xstrdup(start_qos->description);
-			else
+			} else
 				qos->description = xstrdup(name);
-
+			description = qos->description;	/* No copy */
 			slurmdb_copy_qos_rec_limits(qos, start_qos);
 
 			xstrfmtcat(qos_str, "  %s\n", name);
@@ -879,7 +879,7 @@ extern int sacctmgr_add_qos(int argc, char *argv[])
 			acct_storage_g_commit(db_conn, 0);
 		}
 	} else {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Problem adding QOS: %s\n",
 			slurm_strerror(rc));
 		rc = SLURM_ERROR;
@@ -887,12 +887,12 @@ extern int sacctmgr_add_qos(int argc, char *argv[])
 
 end_it:
 	FREE_NULL_LIST(qos_list);
-	xfree(description);
+	slurmdb_destroy_qos_rec(start_qos);
 
 	return rc;
 }
 
-extern int sacctmgr_list_qos(int argc, char *argv[])
+extern int sacctmgr_list_qos(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_qos_cond_t *qos_cond = xmalloc(sizeof(slurmdb_qos_cond_t));
@@ -1232,7 +1232,7 @@ extern int sacctmgr_list_qos(int argc, char *argv[])
 	return rc;
 }
 
-extern int sacctmgr_modify_qos(int argc, char *argv[])
+extern int sacctmgr_modify_qos(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_qos_cond_t *qos_cond = xmalloc(sizeof(slurmdb_qos_cond_t));
@@ -1331,7 +1331,7 @@ extern int sacctmgr_modify_qos(int argc, char *argv[])
 	return rc;
 }
 
-extern int sacctmgr_delete_qos(int argc, char *argv[])
+extern int sacctmgr_delete_qos(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_qos_cond_t *qos_cond =
