@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -40,14 +40,14 @@
 #include "src/sacctmgr/sacctmgr.h"
 #include "src/common/assoc_mgr.h"
 #include "src/common/uid.h"
-#include "src/common/slurm_strcasestr.h"
+#include "src/common/xstring.h"
 
 typedef struct {
 	char *cluster;
 	char *user;
 } regret_t;
 
-static int _set_cond(int *start, int argc, char *argv[],
+static int _set_cond(int *start, int argc, char **argv,
 		     slurmdb_user_cond_t *user_cond,
 		     List format_list)
 {
@@ -170,7 +170,7 @@ static int _set_cond(int *start, int argc, char *argv[],
 			if (format_list) {
 				/* We need this to get the defaults. (Usually
 				 * only for the calling cluster) */
-				if (slurm_strcasestr(argv[i]+end, "default"))
+				if (xstrcasestr(argv[i]+end, "default"))
 					assoc_cond->only_defs = 1;
 
 				slurm_addto_char_list(format_list, argv[i]+end);
@@ -197,7 +197,7 @@ static int _set_cond(int *start, int argc, char *argv[],
 	return 0;
 }
 
-static int _set_rec(int *start, int argc, char *argv[],
+static int _set_rec(int *start, int argc, char **argv,
 		    slurmdb_user_rec_t *user,
 		    slurmdb_assoc_rec_t *assoc)
 {
@@ -651,7 +651,7 @@ static bool _check_user_has_default_assoc(char *user_name, List assoc_list)
 }
 
 
-extern int sacctmgr_add_user(int argc, char *argv[])
+extern int sacctmgr_add_user(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	int i=0;
@@ -767,13 +767,17 @@ extern int sacctmgr_add_user(int argc, char *argv[])
 	}
 
 	if (exit_code) {
+		xfree(default_acct);
+		xfree(default_wckey);
 		slurmdb_destroy_wckey_cond(wckey_cond);
 		slurmdb_destroy_assoc_cond(assoc_cond);
 		return SLURM_ERROR;
 	} else if (!list_count(assoc_cond->user_list)) {
+		xfree(default_acct);
+		xfree(default_wckey);
 		slurmdb_destroy_wckey_cond(wckey_cond);
 		slurmdb_destroy_assoc_cond(assoc_cond);
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Need name of user to add.\n");
 		return SLURM_ERROR;
 	} else {
@@ -794,9 +798,11 @@ extern int sacctmgr_add_user(int argc, char *argv[])
 	}
 
 	if (!local_user_list) {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Problem getting users from database.  "
 			"Contact your admin.\n");
+		xfree(default_acct);
+		xfree(default_wckey);
 		slurmdb_destroy_wckey_cond(wckey_cond);
 		slurmdb_destroy_assoc_cond(assoc_cond);
 		return SLURM_ERROR;
@@ -806,6 +812,8 @@ extern int sacctmgr_add_user(int argc, char *argv[])
 	if (!list_count(assoc_cond->cluster_list)) {
 		if (_check_and_set_cluster_list(assoc_cond->cluster_list)
 		    != SLURM_SUCCESS) {
+			xfree(default_acct);
+			xfree(default_wckey);
 			slurmdb_destroy_wckey_cond(wckey_cond);
 			slurmdb_destroy_assoc_cond(assoc_cond);
 			FREE_NULL_LIST(local_user_list);
@@ -814,6 +822,8 @@ extern int sacctmgr_add_user(int argc, char *argv[])
 		}
 	} else if (sacctmgr_validate_cluster_list(assoc_cond->cluster_list)
 		   != SLURM_SUCCESS) {
+		xfree(default_acct);
+		xfree(default_wckey);
 		slurmdb_destroy_wckey_cond(wckey_cond);
 		slurmdb_destroy_assoc_cond(assoc_cond);
 		FREE_NULL_LIST(local_user_list);
@@ -823,9 +833,11 @@ extern int sacctmgr_add_user(int argc, char *argv[])
 
 	if (!list_count(assoc_cond->acct_list)) {
 		if (!list_count(wckey_cond->name_list)) {
+			xfree(default_acct);
+			xfree(default_wckey);
 			slurmdb_destroy_wckey_cond(wckey_cond);
 			slurmdb_destroy_assoc_cond(assoc_cond);
-			exit_code=1;
+			exit_code = 1;
 			fprintf(stderr, " Need name of account to "
 				"add user to.\n");
 			return SLURM_ERROR;
@@ -1197,7 +1209,7 @@ no_default:
 		rc = SLURM_ERROR;
 		goto end_it;
 	} else if (!assoc_str && !wckey_str) {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " No associations or wckeys created.\n");
 		goto end_it;
 	}
@@ -1250,7 +1262,7 @@ no_default:
 			rc = acct_storage_g_add_wckeys(db_conn, my_uid,
 						       wckey_list);
 	} else {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Problem adding users: %s\n",
 			slurm_strerror(rc));
 		rc = SLURM_ERROR;
@@ -1268,7 +1280,7 @@ no_default:
 			acct_storage_g_commit(db_conn, 0);
 		}
 	} else {
-		exit_code=1;
+		exit_code = 1;
 		fprintf(stderr, " Problem adding user associations: %s\n",
 			slurm_strerror(rc));
 		rc = SLURM_ERROR;
@@ -1284,10 +1296,10 @@ end_it:
 	return rc;
 }
 
-extern int sacctmgr_add_coord(int argc, char *argv[])
+extern int sacctmgr_add_coord(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
-	int i=0;
+	int i = 0;
 	int cond_set = 0, prev_set = 0;
 	slurmdb_user_cond_t *user_cond = xmalloc(sizeof(slurmdb_user_cond_t));
 	char *name = NULL;
@@ -1360,7 +1372,7 @@ extern int sacctmgr_add_coord(int argc, char *argv[])
 	return rc;
 }
 
-extern int sacctmgr_list_user(int argc, char *argv[])
+extern int sacctmgr_list_user(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_user_cond_t *user_cond = xmalloc(sizeof(slurmdb_user_cond_t));
@@ -1634,7 +1646,7 @@ extern int sacctmgr_list_user(int argc, char *argv[])
 	return rc;
 }
 
-extern int sacctmgr_modify_user(int argc, char *argv[])
+extern int sacctmgr_modify_user(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_user_cond_t *user_cond = xmalloc(sizeof(slurmdb_user_cond_t));
@@ -1859,7 +1871,7 @@ assoc_end:
 	return rc;
 }
 
-extern int sacctmgr_delete_user(int argc, char *argv[])
+extern int sacctmgr_delete_user(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	slurmdb_user_cond_t *user_cond = xmalloc(sizeof(slurmdb_user_cond_t));
@@ -2070,7 +2082,7 @@ end_it:
 	return rc;
 }
 
-extern int sacctmgr_delete_coord(int argc, char *argv[])
+extern int sacctmgr_delete_coord(int argc, char **argv)
 {
 	int rc = SLURM_SUCCESS;
 	int i=0, set=0;
