@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -26,10 +26,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <netinet/in.h>
 #include <pthread.h>
 #include <stdint.h>
@@ -53,6 +49,7 @@
 #include "src/common/fd.h"
 #include "src/common/forward.h"
 #include "src/common/hostlist.h"
+#include "src/common/macros.h"
 #include "src/common/net.h"
 #include "src/common/slurm_auth.h"
 #include "src/common/slurm_cred.h"
@@ -117,7 +114,7 @@ static struct termios termdefaults;
 /**********************************************************************
  * sattach
  **********************************************************************/
-int sattach(int argc, char *argv[])
+int sattach(int argc, char **argv)
 {
 	log_options_t logopt = LOG_OPTS_STDERR_ONLY;
 	slurm_step_layout_t *layout;
@@ -163,8 +160,8 @@ int sattach(int argc, char *argv[])
 
 	_mpir_init(layout->task_cnt);
 	if (opt.input_filter_set) {
-		opt.fds.in.nodeid =
-			_nodeid_from_layout(layout, opt.fds.in.taskid);
+		opt.fds.input.nodeid =
+			_nodeid_from_layout(layout, opt.fds.input.taskid);
 	}
 
 	if (layout->front_end)
@@ -273,6 +270,7 @@ static void print_layout_info(slurm_step_layout_t *layout)
 		printf("\n");
 		free(name);
 	}
+	hostlist_destroy(nl);
 }
 
 
@@ -459,7 +457,7 @@ static message_thread_state_t *_msg_thr_create(int num_nodes, int num_tasks)
 	debug("Entering _msg_thr_create()");
 	mts = (message_thread_state_t *)xmalloc(sizeof(message_thread_state_t));
 	slurm_mutex_init(&mts->lock);
-	pthread_cond_init(&mts->cond, NULL);
+	slurm_cond_init(&mts->cond, NULL);
 	mts->tasks_started = bit_alloc(num_tasks);
 	mts->tasks_exited = bit_alloc(num_tasks);
 	mts->msg_handle = eio_handle_create(0);
@@ -499,7 +497,7 @@ static void _msg_thr_wait(message_thread_state_t *mts)
 	slurm_mutex_lock(&mts->lock);
 	while (bit_set_count(mts->tasks_exited)
 	       < bit_set_count(mts->tasks_started)) {
-		pthread_cond_wait(&mts->cond, &mts->lock);
+		slurm_cond_wait(&mts->cond, &mts->lock);
 	}
 	slurm_mutex_unlock(&mts->lock);
 }
@@ -509,8 +507,8 @@ static void _msg_thr_destroy(message_thread_state_t *mts)
 	eio_signal_shutdown(mts->msg_handle);
 	pthread_join(mts->msg_thread, NULL);
 	eio_handle_destroy(mts->msg_handle);
-	pthread_mutex_destroy(&mts->lock);
-	pthread_cond_destroy(&mts->cond);
+	slurm_mutex_destroy(&mts->lock);
+	slurm_cond_destroy(&mts->cond);
 	FREE_NULL_BITMAP(mts->tasks_started);
 	FREE_NULL_BITMAP(mts->tasks_exited);
 }
@@ -527,7 +525,7 @@ _launch_handler(message_thread_state_t *mts, slurm_msg_t *resp)
 		bit_set(mts->tasks_started, msg->task_ids[i]);
 	}
 
-	pthread_cond_signal(&mts->cond);
+	slurm_cond_signal(&mts->cond);
 	slurm_mutex_unlock(&mts->lock);
 
 }
@@ -571,7 +569,7 @@ _exit_handler(message_thread_state_t *mts, slurm_msg_t *exit_msg)
 		}
 	}
 
-	pthread_cond_signal(&mts->cond);
+	slurm_cond_signal(&mts->cond);
 	slurm_mutex_unlock(&mts->lock);
 }
 
