@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -138,11 +138,11 @@ extern void
 scontrol_pid_info(pid_t job_pid)
 {
 	int error_code;
-	uint32_t job_id;
+	uint32_t job_id = 0;
 	time_t end_time;
 	long rem_time;
 
-	error_code = slurm_pid2jobid (job_pid, &job_id);
+	error_code = slurm_pid2jobid(job_pid, &job_id);
 	if (error_code) {
 		exit_code = 1;
 		if (quiet_flag != 1)
@@ -313,6 +313,20 @@ scontrol_print_job (char * job_id_str)
 	char *end_ptr = NULL;
 
 	if (job_id_str) {
+		char *tmp_job_ptr = job_id_str;
+		/*
+		 * Check that the input is a valid job id (i.e. 123 or 123_456).
+		 */
+		while (*tmp_job_ptr) {
+			if (!isdigit(*tmp_job_ptr) && (*tmp_job_ptr != '_')) {
+				exit_code = 1;
+				slurm_seterrno(ESLURM_INVALID_JOB_ID);
+				if (quiet_flag != 1)
+					slurm_perror("scontrol_print_job error");
+				return;
+			}
+			++tmp_job_ptr;
+		}
 		job_id = (uint32_t) strtol (job_id_str, &end_ptr, 10);
 		if (end_ptr[0] == '_')
 			array_id = strtol( end_ptr + 1, &end_ptr, 10 );
@@ -545,8 +559,8 @@ static void
 _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 {
 	int fd;
-	slurmstepd_task_info_t *task_info;
-	uint32_t *pids;
+	slurmstepd_task_info_t *task_info = NULL;
+	uint32_t *pids = NULL;
 	uint32_t count = 0;
 	uint32_t tcount = 0;
 	int i;
@@ -598,10 +612,8 @@ _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 		}
 	}
 
-	if (count > 0)
-		xfree(pids);
-	if (tcount > 0)
-		xfree(task_info);
+	xfree(pids);
+	xfree(task_info);
 	close(fd);
 }
 
@@ -774,6 +786,7 @@ scontrol_encode_hostlist(char *hostlist, bool sorted)
 		if (buf_read >= buf_size) {
 			/* If over 1MB, the file is almost certainly invalid */
 			fprintf(stderr, "File %s is too large\n", hostlist);
+			xfree(io_buf);
 			return SLURM_ERROR;
 		}
 		io_buf[buf_read] = '\0';
@@ -785,6 +798,7 @@ scontrol_encode_hostlist(char *hostlist, bool sorted)
 	hl = hostlist_create(tmp_list);
 	if (hl == NULL) {
 		fprintf(stderr, "Invalid hostlist: %s\n", tmp_list);
+		xfree(io_buf);
 		return SLURM_ERROR;
 	}
 	if (sorted)
