@@ -3,14 +3,14 @@
  *****************************************************************************
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
- *  Portions Copyright (C) 2010-2011 SchedMD <http://www.schedmd.com>.
+ *  Portions Copyright (C) 2010-2011 SchedMD <https://www.schedmd.com>.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Joey Ekstrom <ekstrom1@llnl.gov>,
  *             Morris Jette <jette1@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -194,6 +194,14 @@ static inline int _diff_uint32(uint32_t value_1, uint32_t value_2)
 		return -1;
 	return 0;
 }
+static inline int _diff_uint64(uint64_t value_1, uint64_t value_2)
+{
+	if (value_1 > value_2)
+		return 1;
+	if (value_1 < value_2)
+		return -1;
+	return 0;
+}
 static void
 _get_sinfo_from_void(sinfo_data_t **s1, sinfo_data_t **s2, void *v1, void *v2)
 {
@@ -244,7 +252,7 @@ static int _sort_by_free_mem(void *void1, void *void2)
 
 	_get_sinfo_from_void(&sinfo1, &sinfo2, void1, void2);
 
-	diff = _diff_uint32(sinfo1->min_free_mem, sinfo2->min_free_mem);
+	diff = _diff_uint64(sinfo1->min_free_mem, sinfo2->min_free_mem);
 
 	if (reverse_order)
 		diff = -diff;
@@ -417,6 +425,7 @@ static int _sort_by_node_addr(void *void1, void *void2)
 	sinfo_data_t *sinfo1;
 	sinfo_data_t *sinfo2;
 	char *val1, *val2;
+	char *ptr1, *ptr2;
 #if	PURE_ALPHA_SORT == 0
 	int inx;
 #endif
@@ -427,39 +436,41 @@ static int _sort_by_node_addr(void *void1, void *void2)
 	if (val1) {
 		hostlist_push_host(sinfo1->node_addr, val1);
 		hostlist_sort(sinfo1->node_addr);
+		ptr1 = val1;
 	} else
-		val1 = "";
+		ptr1 = "";
 
 	val2 = hostlist_shift(sinfo2->node_addr);
 	if (val2) {
 		hostlist_push_host(sinfo2->node_addr, val2);
 		hostlist_sort(sinfo2->node_addr);
+		ptr2 = val2;
 	} else
-		val2 = "";
+		ptr2 = "";
 
 #if	PURE_ALPHA_SORT
-	diff = xstrcmp(val1, val2);
+	diff = xstrcmp(ptr1, ptr2);
 #else
-	for (inx=0; ; inx++) {
-		if (val1[inx] == val2[inx]) {
-			if (val1[inx] == '\0')
+	for (inx = 0; ; inx++) {
+		if (ptr1[inx] == ptr2[inx]) {
+			if (ptr1[inx] == '\0')
 				break;
 			continue;
 		}
-		if ((isdigit((int)val1[inx])) &&
-		    (isdigit((int)val2[inx]))) {
+		if ((isdigit((int)ptr1[inx])) &&
+		    (isdigit((int)ptr2[inx]))) {
 			int num1, num2;
-			num1 = atoi(val1+inx);
-			num2 = atoi(val2+inx);
+			num1 = atoi(ptr1 + inx);
+			num2 = atoi(ptr2 + inx);
 			diff = num1 - num2;
 		} else
-			diff = xstrcmp(val1, val2);
+			diff = xstrcmp(ptr1, ptr2);
 		break;
 	}
 #endif
-	if (strlen(val1))
+	if (val1)
 		free(val1);
-	if (strlen(val2))
+	if (val2)
 		free(val2);
 
 	if (reverse_order)
@@ -474,6 +485,7 @@ static int _sort_by_hostnames(void *void1, void *void2)
 	sinfo_data_t *sinfo1;
 	sinfo_data_t *sinfo2;
 	char *val1, *val2;
+	char *ptr1, *ptr2;
 #if	PURE_ALPHA_SORT == 0
 	int inx;
 #endif
@@ -484,39 +496,41 @@ static int _sort_by_hostnames(void *void1, void *void2)
 	if (val1) {
 		hostlist_push_host(sinfo1->hostnames, val1);
 		hostlist_sort(sinfo1->hostnames);
+		ptr1 = val1;
 	} else
-		val1 = "";
+		ptr1 = "";
 
 	val2 = hostlist_shift(sinfo2->hostnames);
 	if (val2) {
 		hostlist_push_host(sinfo2->hostnames, val2);
 		hostlist_sort(sinfo2->hostnames);
+		ptr2 = val2;
 	} else
-		val2 = "";
+		ptr2 = "";
 
 #if	PURE_ALPHA_SORT
-	diff = xstrcmp(val1, val2);
+	diff = xstrcmp(ptr1, ptr2);
 #else
-	for (inx=0; ; inx++) {
-		if (val1[inx] == val2[inx]) {
-			if (val1[inx] == '\0')
+	for (inx = 0; ; inx++) {
+		if (ptr1[inx] == ptr2[inx]) {
+			if (ptr1[inx] == '\0')
 				break;
 			continue;
 		}
-		if ((isdigit((int)val1[inx])) &&
-		    (isdigit((int)val2[inx]))) {
+		if ((isdigit((int)ptr1[inx])) &&
+		    (isdigit((int)ptr2[inx]))) {
 			int num1, num2;
-			num1 = atoi(val1+inx);
-			num2 = atoi(val2+inx);
+			num1 = atoi(ptr1 + inx);
+			num2 = atoi(ptr2 + inx);
 			diff = num1 - num2;
 		} else
-			diff = xstrcmp(val1, val2);
+			diff = xstrcmp(ptr1, ptr2);
 		break;
 	}
 #endif
-	if (strlen(val1))
+	if (val1)
 		free(val1);
-	if (strlen(val2))
+	if (val2)
 		free(val2);
 
 	if (reverse_order)
@@ -579,7 +593,7 @@ static int _sort_by_memory(void *void1, void *void2)
 
 	_get_sinfo_from_void(&sinfo1, &sinfo2, void1, void2);
 
-	diff = _diff_uint32(sinfo1->min_mem, sinfo2->min_mem);
+	diff = _diff_uint64(sinfo1->min_mem, sinfo2->min_mem);
 
 	if (reverse_order)
 		diff = -diff;
@@ -592,6 +606,7 @@ static int _sort_by_node_list(void *void1, void *void2)
 	sinfo_data_t *sinfo1;
 	sinfo_data_t *sinfo2;
 	char *val1, *val2;
+	char *ptr1, *ptr2;
 #if	PURE_ALPHA_SORT == 0
 	int inx;
 #endif
@@ -602,39 +617,41 @@ static int _sort_by_node_list(void *void1, void *void2)
 	if (val1) {
 		hostlist_push_host(sinfo1->nodes, val1);
 		hostlist_sort(sinfo1->nodes);
+		ptr1 = val1;
 	} else
-		val1 = "";
+		ptr1 = "";
 
 	val2 = hostlist_shift(sinfo2->nodes);
 	if (val2) {
 		hostlist_push_host(sinfo2->nodes, val2);
 		hostlist_sort(sinfo2->nodes);
+		ptr2 = val2;
 	} else
-		val2 = "";
+		ptr2 = "";
 
 #if	PURE_ALPHA_SORT
-	diff = xstrcmp(val1, val2);
+	diff = xstrcmp(ptr1, ptr2);
 #else
-	for (inx=0; ; inx++) {
-		if (val1[inx] == val2[inx]) {
-			if (val1[inx] == '\0')
+	for (inx = 0; ; inx++) {
+		if (ptr1[inx] == ptr2[inx]) {
+			if (ptr1[inx] == '\0')
 				break;
 			continue;
 		}
-		if ((isdigit((int)val1[inx])) &&
-		    (isdigit((int)val2[inx]))) {
+		if ((isdigit((int)ptr1[inx])) &&
+		    (isdigit((int)ptr2[inx]))) {
 			int num1, num2;
-			num1 = atoi(val1+inx);
-			num2 = atoi(val2+inx);
+			num1 = atoi(ptr1 + inx);
+			num2 = atoi(ptr2 + inx);
 			diff = num1 - num2;
 		} else
-			diff = xstrcmp(val1, val2);
+			diff = xstrcmp(ptr1, ptr2);
 		break;
 	}
 #endif
-	if (strlen(val1))
+	if (val1)
 		free(val1);
-	if (strlen(val2))
+	if (val2)
 		free(val2);
 
 	if (reverse_order)
