@@ -4,14 +4,14 @@
  *****************************************************************************
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
- *  Portions Copyright (C) 2010-2015 SchedMD LLC <http://www.schedmd.com>.
+ *  Portions Copyright (C) 2010-2015 SchedMD LLC <https://www.schedmd.com>.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov>, et. al.
  *  Derived from pdsh written by Jim Garlick <garlick1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -62,9 +62,7 @@
  *  used by the watchdog thread as well as the communication threads.
 \*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include "config.h"
 
 #if HAVE_SYS_PRCTL_H
 #include <sys/prctl.h>
@@ -74,12 +72,11 @@
 #include <pthread.h>
 #include <pwd.h>
 #include <signal.h>
+#include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
-#include <stdlib.h>
 
 #include "src/common/forward.h"
 #include "src/common/list.h"
@@ -174,12 +171,7 @@ typedef struct mail_info {
 	char *message;
 } mail_info_t;
 
-typedef struct retry_args {
-	bool mail_too;			/* Time to wait between retries */
-	int min_wait;			/* Send pending email too */
-} retry_args_t;
-
-static void *_agent_retry(void *arg);
+static void _agent_retry(int min_wait, bool wait_too);
 static int  _batch_launch_defer(queued_request_t *queued_req_ptr);
 static inline int _comm_err(char *node_name, slurm_msg_type_t msg_type);
 static void _list_delete_retry(void *retry_entry);
@@ -212,11 +204,15 @@ static pthread_mutex_t agent_cnt_mutex = PTHREAD_MUTEX_INITIALIZER;
 static pthread_cond_t  agent_cnt_cond  = PTHREAD_COND_INITIALIZER;
 static int agent_cnt = 0;
 static int agent_thread_cnt = 0;
-static uint16_t message_timeout = (uint16_t) NO_VAL;
+static uint16_t message_timeout = NO_VAL16;
+
+static pthread_mutex_t pending_mutex = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t  pending_cond = PTHREAD_COND_INITIALIZER;
+static int pending_wait_time = NO_VAL16;
+static bool pending_mail = false;
+static pthread_t pending_thread_id = (pthread_t) 0;
 
 static bool run_scheduler    = false;
-static bool wiki2_sched      = false;
-static bool wiki2_sched_test = false;
 
 /*
  * agent - party responsible for transmitting an common RPC in parallel
@@ -251,13 +247,6 @@ void *agent(void *args)
 	     list_count(retry_list));
 #endif
 	slurm_mutex_lock(&agent_cnt_mutex);
-	if (!wiki2_sched_test) {
-		char *sched_type = slurm_get_sched_type();
-		if (xstrcmp(sched_type, "sched/wiki2") == 0)
-			wiki2_sched = true;
-		xfree(sched_type);
-		wiki2_sched_test = true;
-	}
 
 	rpc_thread_cnt = 2 + MIN(agent_arg_ptr->node_count, AGENT_THREAD_COUNT);
 	while (1) {
@@ -267,7 +256,7 @@ void *agent(void *args)
 			agent_thread_cnt += rpc_thread_cnt;
 			break;
 		} else {	/* wait for state change and retry */
-			pthread_cond_wait(&agent_cnt_cond, &agent_cnt_mutex);
+			slurm_cond_wait(&agent_cnt_cond, &agent_cnt_mutex);
 		}
 	}
 	slurm_mutex_unlock(&agent_cnt_mutex);
@@ -305,8 +294,8 @@ void *agent(void *args)
 		slurm_mutex_lock(&agent_info_ptr->thread_mutex);
 		while (agent_info_ptr->threads_active >=
 		       AGENT_THREAD_COUNT) {
-			pthread_cond_wait(&agent_info_ptr->thread_cond,
-					  &agent_info_ptr->thread_mutex);
+			slurm_cond_wait(&agent_info_ptr->thread_cond,
+					&agent_info_ptr->thread_mutex);
 		}
 
 		/* create thread specific data, NOTE: freed from
@@ -323,10 +312,8 @@ void *agent(void *args)
 					    (void *) task_specific_ptr))) {
 			error("pthread_create error %m");
 			if (agent_info_ptr->threads_active)
-				pthread_cond_wait(&agent_info_ptr->
-						  thread_cond,
-						  &agent_info_ptr->
-						  thread_mutex);
+				slurm_cond_wait(&agent_info_ptr->thread_cond,
+						&agent_info_ptr->thread_mutex);
 			else {
 				slurm_mutex_unlock(&agent_info_ptr->
 						     thread_mutex);
@@ -349,7 +336,7 @@ void *agent(void *args)
 	}
 	slurm_mutex_lock(&agent_info_ptr->thread_mutex);
 	while (agent_info_ptr->threads_active != 0) {
-		pthread_cond_wait(&agent_info_ptr->thread_cond,
+		slurm_cond_wait(&agent_info_ptr->thread_cond,
 				&agent_info_ptr->thread_mutex);
 	}
 	slurm_mutex_unlock(&agent_info_ptr->thread_mutex);
@@ -379,11 +366,11 @@ void *agent(void *args)
 	if ((agent_thread_cnt + AGENT_THREAD_COUNT + 2) < MAX_SERVER_THREADS)
 		spawn_retry_agent = true;
 
-	pthread_cond_broadcast(&agent_cnt_cond);
+	slurm_cond_broadcast(&agent_cnt_cond);
 	slurm_mutex_unlock(&agent_cnt_mutex);
 
 	if (spawn_retry_agent)
-		agent_retry(RPC_RETRY_INTERVAL, true);
+		agent_trigger(RPC_RETRY_INTERVAL, true);
 
 	return NULL;
 }
@@ -419,8 +406,7 @@ static agent_info_t *_make_agent_info(agent_arg_t *agent_arg_ptr)
 
 	agent_info_ptr = xmalloc(sizeof(agent_info_t));
 	slurm_mutex_init(&agent_info_ptr->thread_mutex);
-	if (pthread_cond_init(&agent_info_ptr->thread_cond, NULL))
-		fatal("pthread_cond_init error %m");
+	slurm_cond_init(&agent_info_ptr->thread_cond, NULL);
 	agent_info_ptr->thread_count   = agent_arg_ptr->node_count;
 	agent_info_ptr->retry          = agent_arg_ptr->retry;
 	agent_info_ptr->threads_active = 0;
@@ -640,7 +626,7 @@ static void _notify_slurmctld_jobs(agent_info_t *agent_ptr)
 {
 	/* Locks: Write job */
 	slurmctld_lock_t job_write_lock =
-	    { NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
+	    { NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	uint32_t job_id = 0, step_id = 0;
 	thd_t *thread_ptr = agent_ptr->thread_struct;
 
@@ -688,7 +674,7 @@ static void _notify_slurmctld_nodes(agent_info_t *agent_ptr,
 	int is_ret_list = 1;
 	/* Locks: Read config, write job, write node */
 	slurmctld_lock_t node_write_lock =
-	    { READ_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
+	    { READ_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
 	thd_t *thread_ptr = agent_ptr->thread_struct;
 	int i;
 
@@ -701,7 +687,8 @@ static void _notify_slurmctld_nodes(agent_info_t *agent_ptr,
 			batch_job_launch_msg_t *launch_msg_ptr =
 					*agent_ptr->msg_args_pptr;
 			uint32_t job_id = launch_msg_ptr->job_id;
-			job_complete(job_id, 0, true, false, 0);
+			job_complete(job_id, slurmctld_conf.slurm_user_id,
+				     true, false, 0);
 		}
 		unlock_slurmctld(node_write_lock);
 	}
@@ -742,7 +729,8 @@ static void _notify_slurmctld_nodes(agent_info_t *agent_ptr,
 				down_msg = "";
 #else
 				drain_nodes(node_names,
-					    "Prolog/Epilog failure", getuid());
+					    "Prolog/Epilog failure",
+					    slurmctld_conf.slurm_user_id);
 				down_msg = ", set to state DRAIN";
 #endif
 				error("Prolog/Epilog failure on nodes %s%s",
@@ -753,7 +741,8 @@ static void _notify_slurmctld_nodes(agent_info_t *agent_ptr,
 				down_msg = "";
 #else
 				drain_nodes(node_names,
-					    "Duplicate jobid", getuid());
+					    "Duplicate jobid",
+					    slurmctld_conf.slurm_user_id);
 				down_msg = ", set to state DRAIN";
 #endif
 				error("Duplicate jobid on nodes %s%s",
@@ -850,13 +839,13 @@ static void *_thread_per_group_rpc(void *args)
 	int sig_array[2] = {SIGUSR1, 0};
 	/* Locks: Write job, write node */
 	slurmctld_lock_t job_write_lock = {
-		NO_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
+		NO_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
 	/* Lock: Read node */
 	slurmctld_lock_t node_read_lock = {
-		NO_LOCK, NO_LOCK, READ_LOCK, NO_LOCK };
+		NO_LOCK, NO_LOCK, READ_LOCK, NO_LOCK, NO_LOCK };
 	/* Lock: Write node */
 	slurmctld_lock_t node_write_lock = {
-		NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK };
+		NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
 
 	xassert(args != NULL);
 	xsignal(SIGUSR1, _sig_handler);
@@ -996,8 +985,8 @@ static void *_thread_per_group_rpc(void *args)
 			thread_state = DSH_DONE;
 			ret_data_info->err = thread_state;
 			lock_slurmctld(job_write_lock);
-			job_complete(job_id, getuid(), false, false,
-				     _wif_status());
+			job_complete(job_id, slurmctld_conf.slurm_user_id,
+				     false, false, _wif_status());
 			unlock_slurmctld(job_write_lock);
 			continue;
 		} else if ((msg_type == RESPONSE_RESOURCE_ALLOCATION) &&
@@ -1100,7 +1089,7 @@ cleanup:
 						 thread_ptr->start_time);
 	/* Signal completion so another thread can replace us */
 	(*threads_active_ptr)--;
-	pthread_cond_signal(thread_cond_ptr);
+	slurm_cond_signal(thread_cond_ptr);
 	slurm_mutex_unlock(thread_mutex_ptr);
 	return (void *) NULL;
 }
@@ -1266,42 +1255,84 @@ static void _list_delete_retry(void *retry_entry)
 	xfree(queued_req_ptr);
 }
 
+/* Start a thread to manage queued agent requests */
+static void *_agent_init(void *arg)
+{
+	int min_wait;
+	bool mail_too;
+	struct timespec ts = {0, 0};
+
+	while (true) {
+		slurm_mutex_lock(&pending_mutex);
+		while (!slurmctld_config.shutdown_time &&
+		       !pending_mail && (pending_wait_time == NO_VAL16)) {
+			ts.tv_sec  = time(NULL) + 2;
+			pthread_cond_timedwait(&pending_cond,
+					       &pending_mutex,
+					       &ts);
+		}
+		if (slurmctld_config.shutdown_time) {
+			slurm_mutex_unlock(&pending_mutex);
+			break;
+		}
+		mail_too = pending_mail;
+		min_wait = pending_wait_time;
+		pending_mail = false;
+		pending_wait_time = NO_VAL16;
+		slurm_mutex_unlock(&pending_mutex);
+
+		_agent_retry(min_wait, mail_too);
+	}
+
+	slurm_mutex_lock(&pending_mutex);
+	pending_thread_id = (pthread_t) 0;
+	slurm_mutex_unlock(&pending_mutex);
+	return NULL;
+}
+extern void agent_init(void)
+{
+	pthread_attr_t thread_attr;
+
+	slurm_mutex_lock(&pending_mutex);
+	if (pending_thread_id != (pthread_t) 0) {
+		error("%s: thread already running", __func__);
+		slurm_mutex_unlock(&pending_mutex);
+		return;
+	}
+
+	slurm_attr_init(&thread_attr);
+	if (pthread_attr_setdetachstate(&thread_attr, PTHREAD_CREATE_DETACHED))
+		error("pthread_attr_setdetachstate error %m");
+	if (pthread_create(&pending_thread_id, &thread_attr, _agent_init, NULL))
+		fatal("pthread_create error %m");
+	slurm_mutex_unlock(&pending_mutex);
+	slurm_attr_destroy(&thread_attr);
+}
+
 /*
- * agent_retry - Spawn agent for retrying pending RPCs. One pending request is
- *	issued if it has been pending for at least min_wait seconds
+ * agent_trigger - Request processing of pending RPCs
  * IN min_wait - Minimum wait time between re-issue of a pending RPC
  * IN mail_too - Send pending email too, note this performed using a
  *	fork/waitpid, so it can take longer than just creating a pthread
  *	to send RPCs
  */
-extern void agent_retry(int min_wait, bool mail_too)
+extern void agent_trigger(int min_wait, bool mail_too)
 {
-	pthread_attr_t thread_attr;
-	pthread_t thread_id = (pthread_t) 0;
-	retry_args_t *retry_args_ptr;
-
-	retry_args_ptr = xmalloc(sizeof(struct retry_args));
-	retry_args_ptr->mail_too = mail_too;
-	retry_args_ptr->min_wait = min_wait;
-
-	slurm_attr_init(&thread_attr);
-	if (pthread_attr_setdetachstate(&thread_attr, PTHREAD_CREATE_DETACHED))
-		error("pthread_attr_setdetachstate error %m");
-	if (pthread_create(&thread_id, &thread_attr, _agent_retry,
-			   (void *) retry_args_ptr)) {
-		error("pthread_create error %m");
-		xfree(retry_args_ptr);
-	}
-	slurm_attr_destroy(&thread_attr);
+	slurm_mutex_lock(&pending_mutex);
+	if ((pending_wait_time == NO_VAL16) ||
+	    (pending_wait_time >  min_wait))
+		pending_wait_time = min_wait;
+	if (mail_too)
+		pending_mail = mail_too;
+	slurm_cond_broadcast(&pending_cond);
+	slurm_mutex_unlock(&pending_mutex);
 }
 
 /* Do the work requested by agent_retry (retry pending RPCs).
  * This is a separate thread so the job records can be locked */
-static void *_agent_retry(void *arg)
+static void _agent_retry(int min_wait, bool mail_too)
 {
-	retry_args_t *retry_args_ptr = (retry_args_t *) arg;
-	bool mail_too;
-	int min_wait, rc;
+	int rc;
 	time_t now = time(NULL);
 	queued_request_t *queued_req_ptr = NULL;
 	agent_arg_t *agent_arg_ptr = NULL;
@@ -1313,10 +1344,6 @@ static void *_agent_retry(void *arg)
 	slurmctld_lock_t job_write_lock =
 		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
 
-	mail_too = retry_args_ptr->mail_too;
-	min_wait = retry_args_ptr->min_wait;
-	xfree(arg);
-
 	lock_slurmctld(job_write_lock);
 	slurm_mutex_lock(&retry_mutex);
 	if (retry_list) {
@@ -1351,7 +1378,7 @@ static void *_agent_retry(void *arg)
 		slurm_mutex_unlock(&agent_cnt_mutex);
 		slurm_mutex_unlock(&retry_mutex);
 		unlock_slurmctld(job_write_lock);
-		return NULL;
+		return;
 	}
 	slurm_mutex_unlock(&agent_cnt_mutex);
 
@@ -1442,7 +1469,7 @@ static void *_agent_retry(void *arg)
 		slurm_mutex_unlock(&agent_cnt_mutex);
 	}
 
-	return NULL;
+	return;
 }
 
 /*
@@ -1457,7 +1484,7 @@ void agent_queue_request(agent_arg_t *agent_arg_ptr)
 	if ((AGENT_THREAD_COUNT + 2) >= MAX_SERVER_THREADS)
 		fatal("AGENT_THREAD_COUNT value is too low relative to MAX_SERVER_THREADS");
 
-	if (message_timeout == (uint16_t) NO_VAL) {
+	if (message_timeout == NO_VAL16) {
 		message_timeout = MAX(slurm_get_msg_timeout(), 30);
 	}
 
@@ -1495,7 +1522,7 @@ void agent_queue_request(agent_arg_t *agent_arg_ptr)
 
 	/* now process the request in a separate pthread
 	 * (if we can create another pthread to do so) */
-	agent_retry(999, false);
+	agent_trigger(999, false);
 }
 
 /* _spawn_retry_agent - pthread_create an agent for the given task */
@@ -1635,14 +1662,15 @@ static void *_mail_proc(void *arg)
 	if (pid < 0) {		/* error */
 		error("fork(): %m");
 	} else if (pid == 0) {	/* child */
-		int fd, i;
+		int fd_0, fd_1, fd_2, i;
 		for (i = 0; i < 1024; i++)
 			(void) close(i);
-		fd = open("/dev/null", O_RDWR); // fd = 0
-		if (dup(fd) == -1)		// fd = 1
-			error("Couldn't do a dup for 1: %m");
-		if (dup(fd) == -1)		// fd = 2
-			error("Couldn't do a dup for 2 %m");
+		if ((fd_0 = open("/dev/null", O_RDWR)) == -1)	// fd = 0
+			error("Couldn't open /dev/null: %m");
+		if ((fd_1 = dup(fd_0)) == -1)			// fd = 1
+			error("Couldn't do a dup on fd 1: %m");
+		if ((fd_2 = dup(fd_0)) == -1)			// fd = 2
+			error("Couldn't do a dup on fd 2 %m");
 		execle(slurmctld_conf.mail_prog, "mail",
 			"-s", mi->message, mi->user_name,
 			NULL, NULL);
@@ -1802,9 +1830,14 @@ extern void mail_job_info (struct job_record *job_ptr, uint16_t mail_type)
 	char job_time[128], term_msg[128];
 	mail_info_t *mi = _mail_alloc();
 
-	if (!job_ptr->mail_user)
+	if (!job_ptr->mail_user) {
 		mi->user_name = uid_to_string((uid_t)job_ptr->user_id);
-	else
+		/* unqualified sender, append MailDomain if set */
+		if (slurmctld_conf.mail_domain) {
+			xstrcat(mi->user_name, "@");
+			xstrcat(mi->user_name, slurmctld_conf.mail_domain);
+		}
+	} else
 		mi->user_name = xstrdup(job_ptr->mail_user);
 
 	/* Use job array master record, if available */
