@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -38,20 +38,15 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
-#ifdef WITH_PTHREADS
-#  include <pthread.h>
-#endif				/* WITH_PTHREADS */
+#include "config.h"
 
 #if HAVE_SYS_PRCTL_H
 #  include <sys/prctl.h>
 #endif
 
-#include <grp.h>
 #include <errno.h>
+#include <grp.h>
+#include <pthread.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -98,6 +93,7 @@
 #include "src/slurmctld/acct_policy.h"
 #include "src/slurmctld/agent.h"
 #include "src/slurmctld/burst_buffer.h"
+#include "src/slurmctld/fed_mgr.h"
 #include "src/slurmctld/front_end.h"
 #include "src/slurmctld/job_scheduler.h"
 #include "src/slurmctld/job_submit.h"
@@ -172,6 +168,7 @@ int	bg_recover = DEFAULT_RECOVER;
 uint32_t cluster_cpus = 0;
 time_t	last_proc_req_start = 0;
 bool	ping_nodes_now = false;
+pthread_cond_t purge_thread_cond = PTHREAD_COND_INITIALIZER;
 int	sched_interval = 60;
 char *	slurmctld_cluster_name = NULL; /* name of cluster */
 slurmctld_config_t slurmctld_config;
@@ -192,6 +189,7 @@ static time_t	next_stats_reset = 0;
 static int	new_nice = 0;
 static char	node_name_short[MAX_SLURM_NAME];
 static char	node_name_long[MAX_SLURM_NAME];
+static pthread_mutex_t purge_thread_lock = PTHREAD_MUTEX_INITIALIZER;
 static int	recover   = DEFAULT_RECOVER;
 static pthread_mutex_t sched_cnt_mutex = PTHREAD_MUTEX_INITIALIZER;
 static pthread_cond_t server_thread_cond = PTHREAD_COND_INITIALIZER;
@@ -216,7 +214,7 @@ static void         _default_sigaction(int sig);
 static void         _init_config(void);
 static void         _init_pidfile(void);
 static void         _kill_old_slurmctld(void);
-static void         _parse_commandline(int argc, char *argv[]);
+static void         _parse_commandline(int argc, char **argv);
 inline static int   _ping_backup_controller(void);
 static void         _remove_assoc(slurmdb_assoc_rec_t *rec);
 static void         _remove_qos(slurmdb_qos_rec_t *rec);
@@ -236,22 +234,22 @@ static void         _test_thread_limit(void);
 inline static void  _update_cred_key(void);
 static bool	    _verify_clustername(void);
 static void	    _create_clustername_file(void);
+static void *       _purge_files_thread(void *no_data);
 static void         _update_nice(void);
 inline static void  _usage(char *prog_name);
 static bool         _valid_controller(void);
 static bool         _wait_for_server_thread(void);
 
 /* main - slurmctld main function, start various threads and process RPCs */
-int main(int argc, char *argv[])
+int main(int argc, char **argv)
 {
 	int cnt, error_code, i;
 	pthread_attr_t thread_attr;
 	struct stat stat_buf;
 	/* Locks: Write configuration, job, node, and partition */
 	slurmctld_lock_t config_write_lock = {
-		WRITE_LOCK, WRITE_LOCK, WRITE_LOCK, WRITE_LOCK };
+		WRITE_LOCK, WRITE_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
 	slurm_trigger_callbacks_t callbacks;
-	char *dir_name;
 	bool create_clustername_file;
 	/*
 	 * Make sure we have no extra open files which
@@ -277,7 +275,7 @@ int main(int argc, char *argv[])
 
 	/* Verify clustername from conf matches value in spool dir
 	 * exit if inconsistent to protect state files from corruption.
-	 * This needs to be done before we kill the old one just incase we
+	 * This needs to be done before we kill the old one just in case we
 	 * fail. */
 	create_clustername_file = _verify_clustername();
 
@@ -457,6 +455,7 @@ int main(int argc, char *argv[])
 	if (switch_g_slurmctld_init() != SLURM_SUCCESS )
 		fatal( "failed to initialize switch plugin");
 	config_power_mgr();
+	agent_init();
 	if (node_features_g_node_power() && !power_save_test()) {
 		fatal("PowerSave required with NodeFeatures plugin, "
 		      "but not fully configured (SuspendProgram, "
@@ -541,9 +540,12 @@ int main(int argc, char *argv[])
 		clusteracct_storage_g_register_ctld(
 			acct_db_conn,
 			slurmctld_conf.slurmctld_port);
-
 		_accounting_cluster_ready();
 
+		/* call after registering so that the current cluster's
+		 * control_host and control_port will be filled in. */
+		fed_mgr_init(acct_db_conn);
+
 		if (slurm_priority_init() != SLURM_SUCCESS)
 			fatal("failed to initialize priority plugin");
 		if (slurm_sched_init() != SLURM_SUCCESS)
@@ -599,21 +601,34 @@ int main(int argc, char *argv[])
   		 */
 		start_power_mgr(&slurmctld_config.thread_id_power);
 
+		/*
+		 * create attached thread for purging completed job files
+		 */
+		slurm_attr_init(&thread_attr);
+		while (pthread_create(&slurmctld_config.thread_id_purge_files,
+				      &thread_attr, _purge_files_thread,
+				      NULL)) {
+			error("pthread_create error %m");
+			sleep(1);
+		}
+		slurm_attr_destroy(&thread_attr);
+
 		/*
 		 * process slurm background activities, could run as pthread
 		 */
 		_slurmctld_background(NULL);
 
 		/* termination of controller */
-		dir_name = slurm_get_state_save_location();
-		switch_g_save(dir_name);
-		xfree(dir_name);
+		switch_g_save(slurmctld_conf.state_save_location);
 		slurm_priority_fini();
 		slurmctld_plugstack_fini();
 		shutdown_state_save();
+		slurm_cond_signal(&purge_thread_cond); /* wake up last time */
+		pthread_join(slurmctld_config.thread_id_purge_files, NULL);
 		pthread_join(slurmctld_config.thread_id_sig,  NULL);
 		pthread_join(slurmctld_config.thread_id_rpc,  NULL);
 		pthread_join(slurmctld_config.thread_id_save, NULL);
+		slurmctld_config.thread_id_purge_files = (pthread_t) 0;
 		slurmctld_config.thread_id_sig  = (pthread_t) 0;
 		slurmctld_config.thread_id_rpc  = (pthread_t) 0;
 		slurmctld_config.thread_id_save = (pthread_t) 0;
@@ -627,7 +642,7 @@ int main(int argc, char *argv[])
 			 * to wait for current info from the database */
 			slurm_mutex_lock(&assoc_cache_mutex);
 			running_cache = (uint16_t)NO_VAL;
-			pthread_cond_signal(&assoc_cache_cond);
+			slurm_cond_signal(&assoc_cache_cond);
 			slurm_mutex_unlock(&assoc_cache_mutex);
 			pthread_join(assoc_cache_thread, NULL);
 		}
@@ -692,9 +707,8 @@ int main(int argc, char *argv[])
 	purge_front_end_state();
 	resv_fini();
 	trigger_fini();
-	dir_name = slurm_get_state_save_location();
-	assoc_mgr_fini(dir_name);
-	xfree(dir_name);
+	fed_mgr_fini();
+	assoc_mgr_fini(slurmctld_conf.state_save_location);
 	reserve_port_config(NULL);
 	free_rpc_stats();
 
@@ -731,6 +745,10 @@ int main(int argc, char *argv[])
 			break;
 		usleep(100000);
 	}
+
+	/* do this outside of MEMORY_LEAK_DEBUG so that remote connections get
+	 * closed. */
+
 #ifdef HAVE_BG
 	/* Always call slurm_select_fini() on some systems like
 	   BlueGene we need to make sure other processes are ended
@@ -791,17 +809,10 @@ static void  _init_config(void)
 	slurmctld_config.shutdown_time  = (time_t) 0;
 	slurmctld_config.thread_id_main = pthread_self();
 	slurmctld_config.scheduling_disabled = false;
-#ifdef WITH_PTHREADS
 	slurm_mutex_init(&slurmctld_config.thread_count_lock);
 	slurmctld_config.thread_id_main    = (pthread_t) 0;
 	slurmctld_config.thread_id_sig     = (pthread_t) 0;
 	slurmctld_config.thread_id_rpc     = (pthread_t) 0;
-#else
-	slurmctld_config.thread_count_lock = 0;
-	slurmctld_config.thread_id_main    = 0;
-	slurmctld_config.thread_id_sig     = 0;
-	slurmctld_config.thread_id_rpc     = 0;
-#endif
 }
 
 /* Read configuration file.
@@ -814,7 +825,7 @@ static void _reconfigure_slurm(void)
 {
 	/* Locks: Write configuration, job, node, and partition */
 	slurmctld_lock_t config_write_lock = {
-		WRITE_LOCK, WRITE_LOCK, WRITE_LOCK, WRITE_LOCK };
+		WRITE_LOCK, WRITE_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
 	int rc;
 
 	if (slurmctld_config.shutdown_time)
@@ -923,8 +934,8 @@ static void _sig_handler(int signal)
 /* _slurmctld_rpc_mgr - Read incoming RPCs and create pthread for each */
 static void *_slurmctld_rpc_mgr(void *no_data)
 {
-	slurm_fd_t newsockfd;
-	slurm_fd_t *sockfd;	/* our set of socket file descriptors */
+	int newsockfd;
+	int *sockfd;	/* our set of socket file descriptors */
 	slurm_addr_t cli_addr, srv_addr;
 	uint16_t port;
 	char ip[32];
@@ -936,7 +947,7 @@ static void *_slurmctld_rpc_mgr(void *no_data)
 	connection_arg_t *conn_arg = NULL;
 	/* Locks: Read config */
 	slurmctld_lock_t config_read_lock = {
-		READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
+		READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	int sigarray[] = {SIGUSR1, 0};
 	char* node_addr = NULL;
 
@@ -977,7 +988,7 @@ static void *_slurmctld_rpc_mgr(void *no_data)
 		fatal("slurmctld port count is zero");
 		return NULL;	/* Fix CLANG false positive */
 	}
-	sockfd = xmalloc(sizeof(slurm_fd_t) * nports);
+	sockfd = xmalloc(sizeof(int) * nports);
 	for (i=0; i<nports; i++) {
 		sockfd[i] = slurm_init_msg_engine_addrname_port(
 					node_addr,
@@ -1089,19 +1100,20 @@ static void *_service_connection(void *arg)
 {
 	connection_arg_t *conn = (connection_arg_t *) arg;
 	void *return_code = NULL;
-	slurm_msg_t *msg = xmalloc(sizeof(slurm_msg_t));
+	slurm_msg_t msg;
 
 #if HAVE_SYS_PRCTL_H
 	if (prctl(PR_SET_NAME, "srvcn", NULL, NULL, NULL) < 0) {
 		error("%s: cannot set my name to %s %m", __func__, "srvcn");
 	}
 #endif
-	slurm_msg_t_init(msg);
+	slurm_msg_t_init(&msg);
+	msg.flags |= SLURM_MSG_KEEP_BUFFER;
 	/*
 	 * slurm_receive_msg sets msg connection fd to accepted fd. This allows
 	 * possibility for slurmctld_req() to close accepted connection.
 	 */
-	if (slurm_receive_msg(conn->newsockfd, msg, 0) != 0) {
+	if (slurm_receive_msg(conn->newsockfd, &msg, 0) != 0) {
 		char addr_buf[32];
 		slurm_print_slurm_addr(&conn->cli_addr, addr_buf,
 				       sizeof(addr_buf));
@@ -1113,21 +1125,23 @@ static void *_service_connection(void *arg)
 
 	if (errno != SLURM_SUCCESS) {
 		if (errno == SLURM_PROTOCOL_VERSION_ERROR) {
-			slurm_send_rc_msg(msg, SLURM_PROTOCOL_VERSION_ERROR);
+			slurm_send_rc_msg(&msg, SLURM_PROTOCOL_VERSION_ERROR);
 		} else
 			info("_service_connection/slurm_receive_msg %m");
 	} else {
 		/* process the request */
-		slurmctld_req(msg, conn);
+		slurmctld_req(&msg, conn);
 	}
-	if ((conn->newsockfd >= 0)
-	    && slurm_close(conn->newsockfd) < 0)
+
+	if ((conn->newsockfd >= 0) &&
+	    (slurm_close(conn->newsockfd) < 0))
 		error ("close(%d): %m",  conn->newsockfd);
 
 cleanup:
-	slurm_free_msg(msg);
+	slurm_free_msg_members(&msg);
 	xfree(arg);
 	server_thread_decr();
+
 	return return_code;
 }
 
@@ -1166,8 +1180,8 @@ static bool _wait_for_server_thread(void)
 				}
 				print_it = false;
 			}
-			pthread_cond_wait(&server_thread_cond,
-					  &slurmctld_config.thread_count_lock);
+			slurm_cond_wait(&server_thread_cond,
+					&slurmctld_config.thread_count_lock);
 		}
 	}
 	slurm_mutex_unlock(&slurmctld_config.thread_count_lock);
@@ -1182,7 +1196,7 @@ extern void server_thread_decr(void)
 		slurmctld_config.server_thread_count--;
 	else
 		error("slurmctld_config.server_thread_count underflow");
-	pthread_cond_broadcast(&server_thread_cond);
+	slurm_cond_broadcast(&server_thread_cond);
 	slurm_mutex_unlock(&slurmctld_config.thread_count_lock);
 }
 
@@ -1201,7 +1215,7 @@ static int _accounting_cluster_ready(void)
 	bitstr_t *total_node_bitmap = NULL;
 	char *cluster_nodes = NULL, *cluster_tres_str;
 	slurmctld_lock_t node_write_lock = {
-		NO_LOCK, NO_LOCK, WRITE_LOCK, WRITE_LOCK };
+		NO_LOCK, NO_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
 	assoc_mgr_lock_t locks = { NO_LOCK, NO_LOCK, NO_LOCK, NO_LOCK,
 				   WRITE_LOCK, NO_LOCK, NO_LOCK };
 
@@ -1251,8 +1265,8 @@ static int _accounting_mark_all_nodes_down(char *reason)
 	time_t event_time;
 	int rc = SLURM_ERROR;
 
-	state_file = slurm_get_state_save_location();
-	xstrcat (state_file, "/node_state");
+	state_file = xstrdup_printf("%s/node_state",
+				    slurmctld_conf.state_save_location);
 	if (stat(state_file, &stat_buf)) {
 		debug("_accounting_mark_all_nodes_down: could not stat(%s) "
 		      "to record node down time", state_file);
@@ -1274,7 +1288,7 @@ static int _accounting_mark_all_nodes_down(char *reason)
 		if ((rc = clusteracct_storage_g_node_down(
 			    acct_db_conn,
 			    node_ptr, event_time,
-			    reason, slurm_get_slurm_user_id()))
+			    reason, slurmctld_conf.slurm_user_id))
 		   == SLURM_ERROR)
 			break;
 	}
@@ -1300,7 +1314,7 @@ static void _remove_qos(slurmdb_qos_rec_t *rec)
 	ListIterator itr;
 	struct part_record *part_ptr;
 	slurmctld_lock_t part_write_lock =
-		{ NO_LOCK, NO_LOCK, NO_LOCK, WRITE_LOCK };
+		{ NO_LOCK, NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK };
 
 	lock_slurmctld(part_write_lock);
 	if (part_list) {
@@ -1314,6 +1328,7 @@ static void _remove_qos(slurmdb_qos_rec_t *rec)
 			     part_ptr->name, rec->name);
 			part_ptr->qos_ptr = NULL;
 		}
+		list_iterator_destroy(itr);
 	}
 	unlock_slurmctld(part_write_lock);
 
@@ -1331,7 +1346,7 @@ static void _update_assoc(slurmdb_assoc_rec_t *rec)
 	struct job_record *job_ptr;
 	/* Write lock on jobs */
 	slurmctld_lock_t job_write_lock =
-		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
+		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 
 	if (!job_list || !accounting_enforce
 	    || !(accounting_enforce & ACCOUNTING_ENFORCE_LIMITS))
@@ -1349,13 +1364,41 @@ static void _update_assoc(slurmdb_assoc_rec_t *rec)
 	unlock_slurmctld(job_write_lock);
 }
 
+static void _resize_qos(void)
+{
+	ListIterator itr;
+	struct part_record *part_ptr;
+	slurmctld_lock_t part_write_lock =
+		{ NO_LOCK, NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK };
+
+	lock_slurmctld(part_write_lock);
+	if (part_list) {
+		itr = list_iterator_create(part_list);
+		while ((part_ptr = list_next(itr))) {
+			if (part_ptr->allow_qos) {
+				info("got count for %s of %"BITSTR_FMT, part_ptr->name,
+				     bit_size(part_ptr->allow_qos_bitstr));
+				qos_list_build(part_ptr->allow_qos,
+					       &part_ptr->allow_qos_bitstr);
+				info("now count for %s of %"BITSTR_FMT, part_ptr->name,
+				     bit_size(part_ptr->allow_qos_bitstr));
+			}
+			if (part_ptr->deny_qos)
+				qos_list_build(part_ptr->deny_qos,
+					       &part_ptr->deny_qos_bitstr);
+		}
+		list_iterator_destroy(itr);
+	}
+	unlock_slurmctld(part_write_lock);
+}
+
 static void _update_qos(slurmdb_qos_rec_t *rec)
 {
 	ListIterator job_iterator;
 	struct job_record *job_ptr;
 	/* Write lock on jobs */
 	slurmctld_lock_t job_write_lock =
-		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
+		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 
 	if (!job_list || !accounting_enforce
 	    || !(accounting_enforce & ACCOUNTING_ENFORCE_LIMITS))
@@ -1476,8 +1519,9 @@ static int _init_tres(void)
 	FREE_NULL_LIST(char_list);
 
 	if (add_list) {
-		if (acct_storage_g_add_tres(acct_db_conn, getuid(), add_list)
-		    != SLURM_SUCCESS)
+		if (acct_storage_g_add_tres(acct_db_conn,
+					    slurmctld_conf.slurm_user_id,
+					    add_list) != SLURM_SUCCESS)
 			fatal("Problem adding tres to the database, "
 			      "can't continue until database is able to "
 			      "make new tres");
@@ -1509,7 +1553,7 @@ static void _update_cluster_tres(void)
 	struct job_record *job_ptr;
 	/* Write lock on jobs */
 	slurmctld_lock_t job_write_lock =
-		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
+		{ NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	assoc_mgr_lock_t locks = { NO_LOCK, NO_LOCK, NO_LOCK, NO_LOCK,
 				   READ_LOCK, NO_LOCK, NO_LOCK };
 
@@ -1551,10 +1595,11 @@ static void _queue_reboot_msg(void)
 	want_nodes_reboot = false;
 	for (i = 0, node_ptr = node_record_table_ptr;
 	     i < node_record_count; i++, node_ptr++) {
-		if (!IS_NODE_MAINT(node_ptr))
-			continue;
-		if (is_node_in_maint_reservation(i)) {
-			/* defer if node isn't in reservation */
+		if (!IS_NODE_MAINT(node_ptr) && !IS_NODE_REBOOT(node_ptr))
+			continue;	/* No reboot needed */
+		if (!IS_NODE_REBOOT(node_ptr) &&
+		    is_node_in_maint_reservation(i)) {
+			/* node in current maintenance reservation */
 			want_nodes_reboot = true;
 			continue;
 		}
@@ -1597,9 +1642,9 @@ static void _queue_reboot_msg(void)
 		node_ptr->node_state &= ~NODE_STATE_MAINT;
 		node_ptr->node_state &=  NODE_STATE_FLAGS;
 		node_ptr->node_state |=  NODE_STATE_DOWN;
-		node_ptr->reason = xstrdup("Scheduled reboot");
 		bit_clear(avail_node_bitmap, i);
 		bit_clear(idle_node_bitmap, i);
+		node_ptr->boot_req_time = now;
 		node_ptr->last_response = now + slurm_get_resume_timeout();
 	}
 	if (reboot_agent_args != NULL) {
@@ -1649,29 +1694,29 @@ static void *_slurmctld_background(void *no_data)
 
 	/* Locks: Read config */
 	slurmctld_lock_t config_read_lock = {
-		READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
+		READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Read config, read job */
 	slurmctld_lock_t job_read_lock = {
-		READ_LOCK, READ_LOCK, NO_LOCK, NO_LOCK };
+		READ_LOCK, READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Read config, write job, write node, read partition */
 	slurmctld_lock_t job_write_lock = {
-		READ_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK };
+		READ_LOCK, WRITE_LOCK, WRITE_LOCK, READ_LOCK, READ_LOCK };
 	/* Locks: Write job */
 	slurmctld_lock_t job_write_lock2 = {
-		NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
+		NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Read config, write job, write node
 	 * (Might kill jobs on nodes set DOWN) */
 	slurmctld_lock_t node_write_lock = {
-		READ_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
+		READ_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Write node */
 	slurmctld_lock_t node_write_lock2 = {
-		NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK };
+		NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK, NO_LOCK };
 	/* Locks: Write partition */
 	slurmctld_lock_t part_write_lock = {
-		NO_LOCK, NO_LOCK, NO_LOCK, WRITE_LOCK };
+		NO_LOCK, NO_LOCK, NO_LOCK, WRITE_LOCK, NO_LOCK };
 	/* Locks: Read job and node */
 	slurmctld_lock_t job_node_read_lock = {
-		NO_LOCK, READ_LOCK, READ_LOCK, NO_LOCK };
+		NO_LOCK, READ_LOCK, READ_LOCK, NO_LOCK, NO_LOCK };
 
 	/* Let the dust settle before doing work */
 	now = time(NULL);
@@ -1732,7 +1777,7 @@ static void *_slurmctld_background(void *no_data)
 			ts.tv_nsec = now.tv_usec * 1000;
 			slurm_mutex_lock(&slurmctld_config.thread_count_lock);
 			while (slurmctld_config.server_thread_count > 0) {
-				pthread_cond_timedwait(&server_thread_cond,
+				slurm_cond_timedwait(&server_thread_cond,
 					&slurmctld_config.thread_count_lock,
 					&ts);
 			}
@@ -1776,6 +1821,7 @@ static void *_slurmctld_background(void *no_data)
 			debug2("Testing job time limits and checkpoints");
 			lock_slurmctld(job_write_lock);
 			job_time_limit();
+			job_resv_check();
 			step_checkpoint();
 			unlock_slurmctld(job_write_lock);
 		}
@@ -1848,7 +1894,7 @@ static void *_slurmctld_background(void *no_data)
 		}
 
 		/* Process any pending agent work */
-		agent_retry(RPC_RETRY_INTERVAL, true);
+		agent_trigger(RPC_RETRY_INTERVAL, true);
 
 		group_time  = slurmctld_conf.group_info & GROUP_TIME_MASK;
 		if (group_time &&
@@ -1985,8 +2031,6 @@ static void *_slurmctld_background(void *no_data)
 /* save_all_state - save entire slurmctld state for later recovery */
 extern void save_all_state(void)
 {
-	char *save_loc;
-
 	/* Each of these functions lock their own databases */
 	schedule_front_end_save();
 	schedule_job_save();
@@ -1995,11 +2039,9 @@ extern void save_all_state(void)
 	schedule_resv_save();
 	schedule_trigger_save();
 
-	if ((save_loc = slurm_get_state_save_location())) {
-		select_g_state_save(save_loc);
-		dump_assoc_mgr_state(save_loc);
-		xfree(save_loc);
-	}
+	select_g_state_save(slurmctld_conf.state_save_location);
+	dump_assoc_mgr_state(slurmctld_conf.state_save_location);
+	fed_mgr_state_save(slurmctld_conf.state_save_location);
 }
 
 /* make sure the assoc_mgr is up and running with the most current state */
@@ -2008,11 +2050,12 @@ extern void ctld_assoc_mgr_init(slurm_trigger_callbacks_t *callbacks)
 	assoc_init_args_t assoc_init_arg;
 	int num_jobs = 0;
 	slurmctld_lock_t job_read_lock =
-		{ NO_LOCK, READ_LOCK, NO_LOCK, NO_LOCK };
+		{ NO_LOCK, READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 
 	memset(&assoc_init_arg, 0, sizeof(assoc_init_args_t));
 	assoc_init_arg.enforce = accounting_enforce;
 	assoc_init_arg.add_license_notify = license_add_remote;
+	assoc_init_arg.resize_qos_notify = _resize_qos;
 	assoc_init_arg.remove_assoc_notify = _remove_assoc;
 	assoc_init_arg.remove_license_notify = license_remove_remote;
 	assoc_init_arg.remove_qos_notify = _remove_qos;
@@ -2312,7 +2355,7 @@ extern int optind, opterr, optopt;
  * IN argv - the command line arguments
  * IN/OUT conf_ptr - pointer to current configuration, update as needed
  */
-static void _parse_commandline(int argc, char *argv[])
+static void _parse_commandline(int argc, char **argv)
 {
 	int c = 0;
 	char *tmp_char;
@@ -2336,6 +2379,7 @@ static void _parse_commandline(int argc, char *argv[])
 			daemonize = 0;
 			break;
 		case 'f':
+			xfree(slurm_conf_filename);
 			slurm_conf_filename = xstrdup(optarg);
 			break;
 		case 'h':
@@ -2343,6 +2387,7 @@ static void _parse_commandline(int argc, char *argv[])
 			exit(0);
 			break;
 		case 'L':
+			xfree(debug_logfile);
 			debug_logfile = xstrdup(optarg);
 			break;
 		case 'n':
@@ -2594,8 +2639,8 @@ static bool _verify_clustername(void)
 			      "StateSaveLocation WILL CAUSE CORRUPTION.\n"
 			      "Remove %s to override this safety check if "
 			      "this is intentional (e.g., the ClusterName "
-			      "has changed).", name,
-			      slurmctld_conf.cluster_name, filename);
+			      "has changed).", slurmctld_conf.cluster_name,
+			      name, filename);
 			exit(1);
 		}
 	} else if (slurmctld_conf.cluster_name)
@@ -2702,14 +2747,11 @@ static void *_assoc_cache_mgr(void *no_data)
 	slurmdb_assoc_rec_t assoc_rec;
 	/* Write lock on jobs, read lock on nodes and partitions */
 	slurmctld_lock_t job_write_lock =
-		{ NO_LOCK, WRITE_LOCK, READ_LOCK, WRITE_LOCK };
-
-	if (!running_cache)
-		lock_slurmctld(job_write_lock);
+		{ NO_LOCK, WRITE_LOCK, READ_LOCK, WRITE_LOCK, NO_LOCK };
 
 	while (running_cache == 1) {
 		slurm_mutex_lock(&assoc_cache_mutex);
-		pthread_cond_wait(&assoc_cache_cond, &assoc_cache_mutex);
+		slurm_cond_wait(&assoc_cache_cond, &assoc_cache_mutex);
 		/* This is here to see if we are exiting.  If we get
 		   NO_VAL then just return since we are closing down.
 		*/
@@ -2717,31 +2759,28 @@ static void *_assoc_cache_mgr(void *no_data)
 			slurm_mutex_unlock(&assoc_cache_mutex);
 			return NULL;
 		}
-		lock_slurmctld(job_write_lock);
+		/* Make sure not to have job_write_lock or assoc_mgr locks when
+		 * refresh_lists is called or you may get deadlock.
+		 */
 		assoc_mgr_refresh_lists(acct_db_conn, 0);
-		if (running_cache)
-			unlock_slurmctld(job_write_lock);
-		else if (g_tres_count != slurmctld_tres_cnt) {
-			/* This has to be done outside of the job write lock.
-			 * This should only happen in very rare situations
-			 * where we have state, but the database some how has
-			 * changed out from under us. */
-			unlock_slurmctld(job_write_lock);
+		if (g_tres_count != slurmctld_tres_cnt) {
 			info("TRES in database does not match cache "
 			     "(%u != %u).  Updating...",
 			     g_tres_count, slurmctld_tres_cnt);
 			_init_tres();
-			lock_slurmctld(job_write_lock);
 		}
 		slurm_mutex_unlock(&assoc_cache_mutex);
 	}
 
+	lock_slurmctld(job_write_lock);
+
 	if (!job_list) {
 		/* This could happen in rare occations, it doesn't
 		 * matter since when the job_list is populated things
 		 * will be in sync.
 		 */
 		debug2("No job list yet");
+		unlock_slurmctld(job_write_lock);
 		goto handle_parts;
 	}
 
@@ -2860,7 +2899,7 @@ static void _become_slurm_user(void)
 		    (setgroups(0, NULL) != 0)) {
 			fatal("Failed to drop supplementary groups, "
 			      "setgroups: %m");
-		} else if ((slurmctld_conf.slurm_user_id != getuid()) &&
+		} else if ((slurmctld_conf.slurm_user_id != 0) &&
 			   initgroups(slurmctld_conf.slurm_user_name,
 				      slurm_user_gid)) {
 			fatal("Failed to set supplementary groups, "
@@ -2940,7 +2979,7 @@ static int _ping_backup_controller(void)
 	slurm_msg_t req;
 	/* Locks: Read configuration */
 	slurmctld_lock_t config_read_lock = {
-		READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
+		READ_LOCK, NO_LOCK, NO_LOCK, NO_LOCK, NO_LOCK };
 
 	lock_slurmctld(config_read_lock);
 	if (!slurmctld_conf.backup_addr) {
@@ -3008,3 +3047,57 @@ static void  _set_work_dir(void)
 			info("chdir to /var/tmp");
 	}
 }
+
+/*
+ * _purge_files_thread - separate thread to remove job batch/environ files
+ * from the state directory. Runs async from purge_old_jobs to avoid
+ * holding locks while the files are removed, which can cause performance
+ * problems under high throughput conditions.
+ *
+ * Uses the purge_cond to wakeup on demand, then works through the global
+ * purge_files_list of job_ids and removes their files.
+ */
+static void *_purge_files_thread(void *no_data)
+{
+	int *job_id;
+
+	/*
+	 * Use the purge_files_list as a queue. _delete_job_details()
+	 * in job_mgr.c always enqueues (at the end), while
+	 *_purge_files_thread consumes off the front.
+	 *
+	 * There is a potential race condition if the job numbers have
+	 * wrapped between _purge_thread removing the state files and
+	 * get_next_job_id trying to re-assign it. This is mitigated
+	 * the the call to _dup_job_file_test() in job_mgr.c ensuring
+	 * there is no existing directory for an id before assigning it.
+	 */
+
+	/*
+	 * pthread_cond_wait requires a lock to release and reclaim.
+	 * the List structure is already handling locking for itself,
+	 * so this lock isn't actually useful, and the thread calling
+	 * pthread_cond_signal isn't required to have the lock. So
+	 * lock it once and hold it until slurmctld shuts down.
+	 */
+	slurm_mutex_lock(&purge_thread_lock);
+	while (!slurmctld_config.shutdown_time) {
+		slurm_cond_wait(&purge_thread_cond, &purge_thread_lock);
+		debug2("%s: starting, %d jobs to purge", __func__,
+		       list_count(purge_files_list));
+
+		/*
+		 * Use list_dequeue here (instead of list_flush) as it will not
+		 * hold up the list lock when we try to enqueue jobs that need
+		 * to be freed.
+		 */
+		while ((job_id = list_dequeue(purge_files_list))) {
+			debug2("%s: purging files from job %d",
+			       __func__, *job_id);
+			delete_job_desc_files(*job_id);
+			xfree(job_id);
+		}
+	}
+	slurm_mutex_unlock(&purge_thread_lock);
+	return NULL;
+}
