@@ -7,7 +7,7 @@
  *  Written by Martin Perry <martin.perry@bull.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com>.
+ *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -36,12 +36,11 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \****************************************************************************/
 
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #define _GNU_SOURCE
 #include <ctype.h>
+#include <limits.h>
 #include <sched.h>
 #include <stdlib.h>
 #include <sys/types.h>
@@ -57,10 +56,6 @@
 #include "src/slurmd/slurmd/slurmd.h"
 #include "src/slurmd/slurmstepd/slurmstepd_job.h"
 
-#ifndef PATH_MAX
-#define PATH_MAX 256
-#endif
-
 static xcgroup_t system_cpuset_cg = {NULL, NULL, NULL, 0, 0, 0, 0};
 static xcgroup_t system_memory_cg = {NULL, NULL, NULL, 0, 0, 0, 0};
 
@@ -78,10 +73,12 @@ static slurm_cgroup_conf_t slurm_cgroup_conf;
 
 static bool constrain_ram_space;
 static bool constrain_swap_space;
+static bool constrain_kmem_space;
 
 static float allowed_ram_space;   /* Allowed RAM in percent       */
 static float allowed_swap_space;  /* Allowed Swap percent         */
 
+static uint64_t max_kmem;       /* Upper bound for kmem.limit_in_bytes  */
 static uint64_t max_ram;        /* Upper bound for memory.limit_in_bytes  */
 static uint64_t max_swap;       /* Upper bound for swap                   */
 static uint64_t totalram;       /* Total real memory available on node    */
@@ -203,6 +200,7 @@ extern int init_system_memory_cgroup(void)
 		return SLURM_ERROR;
 	}
 
+	constrain_kmem_space = slurm_cgroup_conf.constrain_kmem_space;
 	constrain_ram_space = slurm_cgroup_conf.constrain_ram_space;
 	constrain_swap_space = slurm_cgroup_conf.constrain_swap_space;
 
@@ -223,23 +221,33 @@ extern int init_system_memory_cgroup(void)
 	if ((totalram = (uint64_t) conf->real_memory_size) == 0)
 		error ("system cgroup: Unable to get RealMemory size");
 
+	max_kmem = _percent_in_bytes(totalram, slurm_cgroup_conf.max_kmem_percent);
 	max_ram = _percent_in_bytes(totalram, slurm_cgroup_conf.max_ram_percent);
 	max_swap = _percent_in_bytes(totalram, slurm_cgroup_conf.max_swap_percent);
 	max_swap += max_ram;
 	min_ram_space = slurm_cgroup_conf.min_ram_space * 1024 * 1024;
 
 	debug ("system cgroup: memory: total:%luM allowed:%.4g%%(%s), "
-	       "swap:%.4g%%(%s), max:%.4g%%(%luM) max+swap:%.4g%%(%luM) min:%uM",
+	       "swap:%.4g%%(%s), max:%.4g%%(%luM) "
+	       "max+swap:%.4g%%(%luM) min:%luM "
+	       "kmem:%.4g%%(%luM %s) min:%luM",
 	       (unsigned long) totalram,
 	       allowed_ram_space,
 	       constrain_ram_space?"enforced":"permissive",
+
 	       allowed_swap_space,
 	       constrain_swap_space?"enforced":"permissive",
 	       slurm_cgroup_conf.max_ram_percent,
 	       (unsigned long) (max_ram/(1024*1024)),
+
 	       slurm_cgroup_conf.max_swap_percent,
 	       (unsigned long) (max_swap/(1024*1024)),
-	       (unsigned) slurm_cgroup_conf.min_ram_space);
+	       (unsigned long) slurm_cgroup_conf.min_ram_space,
+
+	       slurm_cgroup_conf.max_kmem_percent,
+	       (unsigned long)(max_kmem/(1024*1024)),
+	       constrain_kmem_space?"enforced":"permissive",
+	       (unsigned long) slurm_cgroup_conf.min_kmem_space);
 
         /*
          *  Warning: OOM Killer must be disabled for slurmstepd
@@ -430,9 +438,9 @@ extern int set_system_cgroup_cpus(char *phys_cpu_str)
 	return SLURM_SUCCESS;
 }
 
-extern int set_system_cgroup_mem_limit(uint32_t mem_spec_limit)
+extern int set_system_cgroup_mem_limit(uint64_t mem_spec_limit)
 {
-    uint64_t mem_spec_bytes = (uint64_t)mem_spec_limit * 1024 * 1024;
+	uint64_t mem_spec_bytes = mem_spec_limit * 1024 * 1024;
 	xcgroup_set_uint64_param(&system_memory_cg, "memory.limit_in_bytes",
 				 mem_spec_bytes);
 	return SLURM_SUCCESS;
@@ -478,14 +486,14 @@ extern bool check_memspec_cgroup_job_confinement(void)
 extern bool check_corespec_cgroup_job_confinement(void)
 {
 	char *task_plugin_type = NULL;
-	bool status = FALSE;
+	bool status = false;
 
 	if (read_slurm_cgroup_conf(&slurm_cgroup_conf))
-		return FALSE;
+		return false;
 	task_plugin_type = slurm_get_task_plugin();
 	if (slurm_cgroup_conf.constrain_cores &&
 	    strstr(task_plugin_type, "cgroup"))
-		status = TRUE;
+		status = true;
 	xfree(task_plugin_type);
 	free_slurm_cgroup_conf(&slurm_cgroup_conf);
 	return status;
