@@ -5,7 +5,7 @@
  *  Written by Matthieu Hautreux <matthieu.hautreux@cea.fr>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -34,27 +34,17 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#if HAVE_CONFIG_H
-#   include "config.h"
-#endif
-
-#if HAVE_STDINT_H
-#  include <stdint.h>
-#endif
-#if HAVE_INTTYPES_H
-#  include <inttypes.h>
-#endif
-
-#include <sys/file.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
+#include <dirent.h>
 #include <fcntl.h>
+#include <inttypes.h>
+#include <limits.h>
 #include <stdlib.h>
 #include <string.h>
-#include <strings.h>
-#include <dirent.h>
+#include <sys/file.h>
 #include <sys/mount.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "slurm/slurm.h"
 #include "slurm/slurm_errno.h"
@@ -65,10 +55,6 @@
 
 #include "xcgroup.h"
 
-#ifndef PATH_MAX
-#define PATH_MAX 256
-#endif
-
 /* internal functions */
 size_t _file_getsize(int fd);
 int _file_read_uint32s(char* file_path, uint32_t** pvalues, int* pnb);
@@ -719,8 +705,8 @@ int xcgroup_get_uint32_param(xcgroup_t* cg, char* param, uint32_t* value)
 {
 	int fstatus = XCGROUP_ERROR;
 	char file_path[PATH_MAX];
-	char* cpath = cg->path;
-	uint32_t* values;
+	char *cpath = cg->path;
+	uint32_t *values = NULL;
 	int vnb;
 
 	if (snprintf(file_path, PATH_MAX, "%s/%s", cpath, param) >= PATH_MAX) {
@@ -736,9 +722,9 @@ int xcgroup_get_uint32_param(xcgroup_t* cg, char* param, uint32_t* value)
 				__func__, param, cpath);
 		} else {
 			*value = values[0];
-			xfree(values);
 			fstatus = XCGROUP_SUCCESS;
 		}
+		xfree(values);
 	}
 	return fstatus;
 }
@@ -770,8 +756,8 @@ int xcgroup_get_uint64_param(xcgroup_t* cg, char* param, uint64_t* value)
 {
 	int fstatus = XCGROUP_ERROR;
 	char file_path[PATH_MAX];
-	char* cpath = cg->path;
-	uint64_t* values;
+	char *cpath = cg->path;
+	uint64_t *values = NULL;
 	int vnb;
 
 	if (snprintf(file_path, PATH_MAX, "%s/%s", cpath, param) >= PATH_MAX) {
@@ -788,9 +774,9 @@ int xcgroup_get_uint64_param(xcgroup_t* cg, char* param, uint64_t* value)
 				__func__, param, cpath);
 		} else {
 			*value = values[0];
-			xfree(values);
 			fstatus = XCGROUP_SUCCESS;
 		}
+		xfree(values);
 	}
 	return fstatus;
 }
@@ -1068,7 +1054,7 @@ int _file_read_uint32s(char* file_path, uint32_t** pvalues, int* pnb)
 	}
 
 	/* get file size */
-	fsize=_file_getsize(fd);
+	fsize =_file_getsize(fd);
 	if (fsize == -1) {
 		close(fd);
 		return XCGROUP_ERROR;
@@ -1152,7 +1138,6 @@ int _file_read_content(char* file_path, char** content, size_t *csize)
 	int fstatus;
 	int rc;
 	int fd;
-
 	size_t fsize;
 	char* buf;
 
@@ -1178,7 +1163,7 @@ int _file_read_content(char* file_path, char** content, size_t *csize)
 	}
 
 	/* read file contents */
-	buf = (char*) xmalloc((fsize+1)*sizeof(char));
+	buf = xmalloc((fsize+1)*sizeof(char));
 	buf[fsize]='\0';
 	do {
 		rc = read(fd, buf, fsize);
@@ -1189,6 +1174,8 @@ int _file_read_content(char* file_path, char** content, size_t *csize)
 		*content = buf;
 		*csize = rc;
 		fstatus = XCGROUP_SUCCESS;
+	} else {
+		xfree(buf);
 	}
 
 	/* close file */
