@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -36,6 +36,9 @@
  *  with SLURM; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
+
+#include "config.h"
+
 #include "pdebug.h"
 
 #include <fcntl.h>
@@ -59,7 +62,7 @@ pdebug_trace_process(stepd_step_rec_t *job, pid_t pid)
 	 *  ptrace(PTRACE_DETACH).
 	 */
 
-	if (job->task_flags & TASK_PARALLEL_DEBUG) {
+	if (job->flags & LAUNCH_PARALLEL_DEBUG) {
 		int status;
 		waitpid(pid, &status, WUNTRACED);
 		if (!WIFSTOPPED(status)) {
@@ -100,10 +103,6 @@ pdebug_trace_process(stepd_step_rec_t *job, pid_t pid)
 		if (_PTRACE(PT_DETACH, pid, NULL, 0)) {
 #elif defined(__sun)
 		if (_PTRACE(7, pid, NULL, 0)) {
-#elif defined(__CYGWIN__)
-		if (1) {
-			debug3("No ptrace for cygwin");
-		} else {
 #else
 		if (_PTRACE(PTRACE_DETACH, pid, NULL, 0)) {
 #endif
@@ -123,15 +122,13 @@ pdebug_stop_current(stepd_step_rec_t *job)
 	/*
 	 * Stop the task on exec for TotalView to connect
 	 */
-	if ( (job->task_flags & TASK_PARALLEL_DEBUG)
+	if ( (job->flags & LAUNCH_PARALLEL_DEBUG)
 #ifdef BSD
 	     && (_PTRACE(PT_TRACE_ME, 0, (caddr_t)0, 0) < 0) )
 #elif defined(PT_TRACE_ME)
 	     && (_PTRACE(PT_TRACE_ME, 0, NULL, 0) < 0) )
 #elif defined(__sun)
 	     && (_PTRACE(0, 0, NULL, 0) < 0))
-#elif defined(__CYGWIN__)
-	     && 0)
 #else
 	     && (_PTRACE(PTRACE_TRACEME, 0, NULL, 0) < 0) )
 #endif
@@ -149,8 +146,10 @@ static bool _pid_to_wake(pid_t pid)
 	sprintf (proc_name, "/proc/%d/stat", (int) pid);
 	if ((proc_fd = open(proc_name, O_RDONLY, 0)) == -1)
 		return false;  /* process is now gone */
-	proc_stat = xmalloc(4096);
+	proc_stat = xmalloc(4097);
 	len = read(proc_fd, proc_stat, 4096);
+	if (len >= 0)
+		proc_stat[len] = '\0';
 	close(proc_fd);
 	if (len < 14) {
 		xfree(proc_stat);
@@ -186,7 +185,7 @@ static bool _pid_to_wake(pid_t pid)
  */
 void pdebug_wake_process(stepd_step_rec_t *job, pid_t pid)
 {
-	if ((job->task_flags & TASK_PARALLEL_DEBUG) && (pid > (pid_t) 0)) {
+	if ((job->flags & LAUNCH_PARALLEL_DEBUG) && (pid > (pid_t) 0)) {
 		if (_pid_to_wake(pid)) {
 			if (kill(pid, SIGCONT) < 0)
 				error("kill(%lu): %m", (unsigned long) pid);
