@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -37,6 +37,8 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
+#include "config.h"
+
 #include <pwd.h>
 #include <stdlib.h>
 #include <string.h>
@@ -59,7 +61,6 @@
 #include "src/common/xstring.h"
 #include "src/common/slurmdb_defs.h"
 #include "src/slurmdbd/read_config.h"
-#include "src/common/slurm_strcasestr.h"
 
 /* Global variables */
 pthread_mutex_t conf_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -106,6 +107,8 @@ static void _clear_slurmdbd_conf(void)
 		slurmdbd_conf->purge_resv = 0;
 		slurmdbd_conf->purge_step = 0;
 		slurmdbd_conf->purge_suspend = 0;
+		slurmdbd_conf->purge_txn = 0;
+		slurmdbd_conf->purge_usage = 0;
 		slurmdbd_conf->slurm_user_id = NO_VAL;
 		xfree(slurmdbd_conf->slurm_user_name);
 		xfree(slurmdbd_conf->storage_backup_host);
@@ -136,6 +139,8 @@ extern int read_slurmdbd_conf(void)
 		{"ArchiveScript", S_P_STRING},
 		{"ArchiveSteps", S_P_BOOLEAN},
 		{"ArchiveSuspend", S_P_BOOLEAN},
+		{"ArchiveTXN", S_P_BOOLEAN},
+		{"ArchiveUsage", S_P_BOOLEAN},
 		{"AuthInfo", S_P_STRING},
 		{"AuthType", S_P_STRING},
 		{"CommitDelay", S_P_UINT16},
@@ -158,10 +163,14 @@ extern int read_slurmdbd_conf(void)
 		{"PurgeResvAfter", S_P_STRING},
 		{"PurgeStepAfter", S_P_STRING},
 		{"PurgeSuspendAfter", S_P_STRING},
+		{"PurgeTXNAfter", S_P_STRING},
+		{"PurgeUsageAfter", S_P_STRING},
 		{"PurgeEventMonths", S_P_UINT32},
 		{"PurgeJobMonths", S_P_UINT32},
 		{"PurgeStepMonths", S_P_UINT32},
 		{"PurgeSuspendMonths", S_P_UINT32},
+		{"PurgeTXNMonths", S_P_UINT32},
+		{"PurgeUsageMonths", S_P_UINT32},
 		{"SlurmUser", S_P_STRING},
 		{"StepPurge", S_P_UINT32},
 		{"StorageBackupHost", S_P_STRING},
@@ -194,8 +203,9 @@ extern int read_slurmdbd_conf(void)
 	if ((conf_path == NULL) || (stat(conf_path, &buf) == -1)) {
 		info("No slurmdbd.conf file (%s)", conf_path);
 	} else {
-		bool a_events = 0, a_jobs = 0, a_resv = 0,
-			a_steps = 0, a_suspend = 0;
+		bool a_events = false, a_jobs = false, a_resv = false;
+		bool a_steps = false, a_suspend = false, a_txn = false;
+		bool a_usage = false;
 		debug("Reading slurmdbd.conf file %s", conf_path);
 
 		tbl = s_p_hashtbl_create(options);
@@ -216,6 +226,8 @@ extern int read_slurmdbd_conf(void)
 			       tbl);
 		s_p_get_boolean(&a_steps, "ArchiveSteps", tbl);
 		s_p_get_boolean(&a_suspend, "ArchiveSuspend", tbl);
+		s_p_get_boolean(&a_txn, "ArchiveTXN", tbl);
+		s_p_get_boolean(&a_usage, "ArchiveUsage", tbl);
 		s_p_get_string(&slurmdbd_conf->auth_info, "AuthInfo", tbl);
 		s_p_get_string(&slurmdbd_conf->auth_type, "AuthType", tbl);
 		s_p_get_uint16(&slurmdbd_conf->commit_delay,
@@ -255,19 +267,19 @@ extern int read_slurmdbd_conf(void)
 		s_p_get_string(&slurmdbd_conf->log_file, "LogFile", tbl);
 
 		if (s_p_get_string(&temp_str, "LogTimeFormat", tbl)) {
-			if (slurm_strcasestr(temp_str, "iso8601_ms"))
+			if (xstrcasestr(temp_str, "iso8601_ms"))
 				slurmdbd_conf->log_fmt = LOG_FMT_ISO8601_MS;
-			else if (slurm_strcasestr(temp_str, "iso8601"))
+			else if (xstrcasestr(temp_str, "iso8601"))
 				slurmdbd_conf->log_fmt = LOG_FMT_ISO8601;
-			else if (slurm_strcasestr(temp_str, "rfc5424_ms"))
+			else if (xstrcasestr(temp_str, "rfc5424_ms"))
 				slurmdbd_conf->log_fmt = LOG_FMT_RFC5424_MS;
-			else if (slurm_strcasestr(temp_str, "rfc5424"))
+			else if (xstrcasestr(temp_str, "rfc5424"))
 				slurmdbd_conf->log_fmt = LOG_FMT_RFC5424;
-			else if (slurm_strcasestr(temp_str, "clock"))
+			else if (xstrcasestr(temp_str, "clock"))
 				slurmdbd_conf->log_fmt = LOG_FMT_CLOCK;
-			else if (slurm_strcasestr(temp_str, "short"))
+			else if (xstrcasestr(temp_str, "short"))
 				slurmdbd_conf->log_fmt = LOG_FMT_SHORT;
-			else if (slurm_strcasestr(temp_str, "thread_id"))
+			else if (xstrcasestr(temp_str, "thread_id"))
 				slurmdbd_conf->log_fmt = LOG_FMT_THREAD_ID;
 			xfree(temp_str);
 		} else
@@ -285,28 +297,28 @@ extern int read_slurmdbd_conf(void)
 
 		slurmdbd_conf->private_data = 0; /* default visible to all */
 		if (s_p_get_string(&temp_str, "PrivateData", tbl)) {
-			if (slurm_strcasestr(temp_str, "account"))
+			if (xstrcasestr(temp_str, "account"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_ACCOUNTS;
-			if (slurm_strcasestr(temp_str, "job"))
+			if (xstrcasestr(temp_str, "job"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_JOBS;
-			if (slurm_strcasestr(temp_str, "node"))
+			if (xstrcasestr(temp_str, "node"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_NODES;
-			if (slurm_strcasestr(temp_str, "partition"))
+			if (xstrcasestr(temp_str, "partition"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_PARTITIONS;
-			if (slurm_strcasestr(temp_str, "reservation"))
+			if (xstrcasestr(temp_str, "reservation"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_RESERVATIONS;
-			if (slurm_strcasestr(temp_str, "usage"))
+			if (xstrcasestr(temp_str, "usage"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_USAGE;
-			if (slurm_strcasestr(temp_str, "user"))
+			if (xstrcasestr(temp_str, "user"))
 				slurmdbd_conf->private_data
 					|= PRIVATE_DATA_USERS;
-			if (slurm_strcasestr(temp_str, "all"))
+			if (xstrcasestr(temp_str, "all"))
 				slurmdbd_conf->private_data = 0xffff;
 			xfree(temp_str);
 		}
@@ -355,6 +367,24 @@ extern int read_slurmdbd_conf(void)
 			}
 			xfree(temp_str);
 		}
+		if (s_p_get_string(&temp_str, "PurgeTXNAfter", tbl)) {
+			/* slurmdb_parse_purge will set SLURMDB_PURGE_FLAGS */
+ 			if ((slurmdbd_conf->purge_txn =
+			     slurmdb_parse_purge(temp_str)) == NO_VAL) {
+				fatal("Bad value \"%s\" for PurgeTXNAfter",
+				      temp_str);
+			}
+			xfree(temp_str);
+		}
+		if (s_p_get_string(&temp_str, "PurgeUsageAfter", tbl)) {
+			/* slurmdb_parse_purge will set SLURMDB_PURGE_FLAGS */
+			if ((slurmdbd_conf->purge_usage =
+			     slurmdb_parse_purge(temp_str)) == NO_VAL) {
+				fatal("Bad value \"%s\" for PurgeUsageAfter",
+				      temp_str);
+			}
+			xfree(temp_str);
+		}
 		if (s_p_get_uint32(&slurmdbd_conf->purge_event,
 				   "PurgeEventMonths", tbl)) {
 			if (!slurmdbd_conf->purge_event)
@@ -391,6 +421,24 @@ extern int read_slurmdbd_conf(void)
 					|= SLURMDB_PURGE_MONTHS;
 		}
 
+		if (s_p_get_uint32(&slurmdbd_conf->purge_txn,
+				   "PurgeTXNMonths", tbl)) {
+			if (!slurmdbd_conf->purge_txn)
+				slurmdbd_conf->purge_txn = NO_VAL;
+			else
+				slurmdbd_conf->purge_txn
+					|= SLURMDB_PURGE_MONTHS;
+		}
+
+		if (s_p_get_uint32(&slurmdbd_conf->purge_usage,
+				   "PurgeUsageMonths", tbl)) {
+			if (!slurmdbd_conf->purge_usage)
+				slurmdbd_conf->purge_usage = NO_VAL;
+			else
+				slurmdbd_conf->purge_usage
+					|= SLURMDB_PURGE_MONTHS;
+		}
+
 		s_p_get_string(&slurmdbd_conf->slurm_user_name,
 			       "SlurmUser", tbl);
 
@@ -440,6 +488,10 @@ extern int read_slurmdbd_conf(void)
 			slurmdbd_conf->purge_step |= SLURMDB_PURGE_ARCHIVE;
 		if (a_suspend && slurmdbd_conf->purge_suspend)
 			slurmdbd_conf->purge_suspend |= SLURMDB_PURGE_ARCHIVE;
+		if (a_txn && slurmdbd_conf->purge_txn)
+			slurmdbd_conf->purge_txn |= SLURMDB_PURGE_ARCHIVE;
+		if (a_usage && slurmdbd_conf->purge_usage)
+			slurmdbd_conf->purge_usage |= SLURMDB_PURGE_ARCHIVE;
 
 		s_p_hashtbl_destroy(tbl);
 	}
@@ -539,6 +591,10 @@ extern int read_slurmdbd_conf(void)
 		slurmdbd_conf->purge_step = NO_VAL;
 	if (!slurmdbd_conf->purge_suspend)
 		slurmdbd_conf->purge_suspend = NO_VAL;
+	if (!slurmdbd_conf->purge_txn)
+		slurmdbd_conf->purge_txn = NO_VAL;
+	if (!slurmdbd_conf->purge_usage)
+		slurmdbd_conf->purge_usage = NO_VAL;
 
 	slurm_mutex_unlock(&conf_mutex);
 	return SLURM_SUCCESS;
@@ -594,6 +650,14 @@ extern void log_config(void)
 			     tmp_str, sizeof(tmp_str), 1);
 	debug2("PurgeSuspendAfter = %s", tmp_str);
 
+	slurmdb_purge_string(slurmdbd_conf->purge_txn,
+			     tmp_str, sizeof(tmp_str), 1);
+	debug2("PurgeTXNAfter = %s", tmp_str);
+
+	slurmdb_purge_string(slurmdbd_conf->purge_usage,
+			     tmp_str, sizeof(tmp_str), 1);
+	debug2("PurgeUsageAfter = %s", tmp_str);
+
 	debug2("SlurmUser         = %s(%u)",
 	       slurmdbd_conf->slurm_user_name, slurmdbd_conf->slurm_user_id);
 
@@ -685,6 +749,20 @@ extern List dump_config(void)
 			slurmdbd_conf->purge_suspend) ? "Yes" : "No");
 	list_append(my_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("ArchiveTXN");
+	key_pair->value = xstrdup(
+		SLURMDB_PURGE_ARCHIVE_SET(
+			slurmdbd_conf->purge_txn) ? "Yes" : "No");
+	list_append(my_list, key_pair);
+
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("ArchiveUsage");
+	key_pair->value = xstrdup(
+		SLURMDB_PURGE_ARCHIVE_SET(
+			slurmdbd_conf->purge_usage) ? "Yes" : "No");
+	list_append(my_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("AuthInfo");
 	key_pair->value = xstrdup(slurmdbd_conf->auth_info);
@@ -818,6 +896,26 @@ extern List dump_config(void)
 		key_pair->value = xstrdup("NONE");
 	list_append(my_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("PurgeTXNAfter");
+	if (slurmdbd_conf->purge_txn != NO_VAL) {
+		key_pair->value = xmalloc(32);
+		slurmdb_purge_string(slurmdbd_conf->purge_txn,
+				     key_pair->value, 32, 1);
+	} else
+		key_pair->value = xstrdup("NONE");
+	list_append(my_list, key_pair);
+
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("PurgeUsageAfter");
+	if (slurmdbd_conf->purge_usage != NO_VAL) {
+		key_pair->value = xmalloc(32);
+		slurmdb_purge_string(slurmdbd_conf->purge_usage,
+				     key_pair->value, 32, 1);
+	} else
+		key_pair->value = xstrdup("NONE");
+	list_append(my_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("SLURMDBD_CONF");
 	key_pair->value = get_extra_conf_path("slurmdbd.conf");
