@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -40,21 +40,10 @@
 #ifndef _DBD_READ_CONFIG_H
 #define _DBD_READ_CONFIG_H
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#if HAVE_INTTYPES_H
-#  include <inttypes.h>
-#else  /* !HAVE_INTTYPES_H */
-#  if HAVE_STDINT_H
-#    include <stdint.h>
-#  endif
-#endif  /* HAVE_INTTYPES_H */
-#else   /* !HAVE_CONFIG_H */
-#include <stdint.h>
-#endif  /* HAVE_CONFIG_H */
-
+#include <inttypes.h>
 #include <time.h>
 #include <pthread.h>
+
 #include "src/common/list.h"
 
 #define DEFAULT_SLURMDBD_AUTHTYPE	"auth/none"
@@ -98,6 +87,10 @@ typedef struct slurm_dbd_conf {
 	uint32_t	purge_step;	/* purge time for step info	*/
 	uint32_t        purge_suspend;  /* purge suspend data older
 					 * than this in months or days	*/
+	uint32_t        purge_txn;      /* purge transaction data older
+					 * than this in months or days	*/
+	uint32_t        purge_usage;    /* purge usage data older
+					 * than this in months or days	*/
 	uint32_t	slurm_user_id;	/* uid of slurm_user_name	*/
 	char *		slurm_user_name;/* user that slurmcdtld runs as	*/
 	char *		storage_backup_host;/* backup host where DB is
