@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -39,21 +39,9 @@
 #ifndef __SPRIO_H__
 #define __SPRIO_H__
 
-#if HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <ctype.h>
+#include <inttypes.h>
 #include <stdio.h>
-
-#if HAVE_INTTYPES_H
-#  include <inttypes.h>
-#else  /* !HAVE_INTTYPES_H */
-#  if HAVE_STDINT_H
-#    include <stdint.h>
-#  endif
-#endif  /* HAVE_INTTYPES_H */
-
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -101,7 +89,7 @@ extern uint32_t weight_part; /* weight for Partition factor */
 extern uint32_t weight_qos; /* weight for QOS factor */
 extern char    *weight_tres; /* weight str TRES factors */
 
-extern void parse_command_line( int argc, char* argv[] );
+extern void parse_command_line( int argc, char* *argv );
 extern int  parse_format( char* format );
 
 #endif
