@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -36,6 +36,8 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
+#include "config.h"
+
 #include "sstat.h"
 
 int _do_stat(uint32_t jobid, uint32_t stepid, char *nodelist,
@@ -116,6 +118,7 @@ int _do_stat(uint32_t jobid, uint32_t stepid, char *nodelist,
 			error("problem getting step_layout for %u.%u: %s",
 			      jobid, stepid, slurm_strerror(rc));
 		}
+		slurm_job_step_pids_response_msg_free(step_stat_response);
 		return rc;
 	}
 
