@@ -5,7 +5,7 @@
  *  Written by Nathan Yee <nyee32@shedmd.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://slurm.schedmd.com/>.
+ *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -27,6 +27,7 @@
 #include "src/sview/sview.h"
 #include "src/common/parse_time.h"
 #include "src/common/proc_args.h"
+#include "src/common/strlcpy.h"
 
 #define _DEBUG 0
 
@@ -76,42 +77,42 @@ enum {
 static char *_initial_page_opts = "Name/JobID,Pool,Size,State,StateTime,UserID";
 
 static display_data_t display_data_bb[] = {
-	{G_TYPE_INT, SORTID_POS, NULL, FALSE, EDIT_NONE,
+	{G_TYPE_INT, SORTID_POS, NULL, false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_PLUGIN, "Plugin", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_PLUGIN, "Plugin", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_NAME, "Name/JobID", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_NAME, "Name/JobID", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_COLOR, NULL, TRUE, EDIT_COLOR,
+	{G_TYPE_STRING, SORTID_COLOR, NULL, true, EDIT_COLOR,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_INT, SORTID_COLOR_INX, NULL, FALSE, EDIT_NONE,
+	{G_TYPE_INT, SORTID_COLOR_INX, NULL, false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_ACCOUNT, "Account", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_ACCOUNT, "Account", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_CREATE_TIME, "CreateTime", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_CREATE_TIME, "CreateTime", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_PARTITION, "Partition", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_PARTITION, "Partition", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_POOL, "Pool", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_POOL, "Pool", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_QOS, "QOS", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_QOS, "QOS", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_SIZE, "Size", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_SIZE, "Size", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_STATE, "State", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_STATE, "State", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_INT, SORTID_UPDATED, NULL, FALSE, EDIT_NONE, refresh_bb,
+	{G_TYPE_INT, SORTID_UPDATED, NULL, false, EDIT_NONE, refresh_bb,
 	 create_model_bb, admin_edit_bb},
-	{G_TYPE_STRING, SORTID_USERID, "UserID", FALSE, EDIT_NONE,
+	{G_TYPE_STRING, SORTID_USERID, "UserID", false, EDIT_NONE,
 	 refresh_bb, create_model_bb, admin_edit_bb},
-	{G_TYPE_NONE, -1, NULL, FALSE, EDIT_NONE}
+	{G_TYPE_NONE, -1, NULL, false, EDIT_NONE}
 };
 
 /*Burst buffer options list*/
 static display_data_t options_data_bb[] = {
-	{G_TYPE_INT, SORTID_POS, NULL, FALSE, EDIT_NONE},
-	{G_TYPE_STRING, INFO_PAGE, "Full Info", TRUE, BB_PAGE},
-	{G_TYPE_NONE, -1, NULL, FALSE, EDIT_NONE}
+	{G_TYPE_INT, SORTID_POS, NULL, false, EDIT_NONE},
+	{G_TYPE_STRING, INFO_PAGE, "Full Info", true, BB_PAGE},
+	{G_TYPE_NONE, -1, NULL, false, EDIT_NONE}
 };
 
 static display_data_t *local_display_data = NULL;
@@ -202,7 +203,7 @@ static void _layout_bb_record(GtkTreeView *treeview,
 	treestore = GTK_TREE_STORE(gtk_tree_view_get_model(treeview));
 
 	if (bb_ptr->name) {
-		strncpy(bb_name_id, bb_ptr->name, sizeof(bb_name_id));
+		strlcpy(bb_name_id, bb_ptr->name, sizeof(bb_name_id));
 	} else if (bb_ptr->array_task_id == NO_VAL) {
 		convert_num_unit(bb_ptr->job_id, bb_name_id, sizeof(bb_name_id),
 				 UNIT_NONE, NO_VAL,
@@ -320,7 +321,7 @@ static void _update_bb_record(sview_bb_info_t *sview_bb_info_ptr,
 	burst_buffer_resv_t *bb_ptr = sview_bb_info_ptr->bb_ptr;
 
 	if (bb_ptr->name) {
-		strncpy(bb_name_id, bb_ptr->name, sizeof(bb_name_id));
+		strlcpy(bb_name_id, bb_ptr->name, sizeof(bb_name_id));
 	} else if (bb_ptr->array_task_id == NO_VAL) {
 		convert_num_unit(bb_ptr->job_id, bb_name_id, sizeof(bb_name_id),
 				 UNIT_NONE, NO_VAL,
@@ -477,7 +478,7 @@ static List _create_bb_info_list(burst_buffer_info_msg_t *bb_info_ptr)
 			}
 
 			if (bb_resv_ptr->name) {
-				strncpy(bb_name_id, bb_resv_ptr->name,
+				strlcpy(bb_name_id, bb_resv_ptr->name,
 					sizeof(bb_name_id));
 			} else if (bb_resv_ptr->array_task_id == NO_VAL) {
 				convert_num_unit(bb_resv_ptr->job_id,
@@ -664,13 +665,13 @@ extern void get_info_bb(GtkTable *table, display_data_t *display_data)
 	GtkTreeView *tree_view = NULL;
 	static GtkWidget *display_widget = NULL;
 	GtkTreePath *path = NULL;
-	static bool set_opts = FALSE;
+	static bool set_opts = false;
 
 	if (!set_opts) {
 		set_page_opts(BB_PAGE, display_data_bb,
 			      SORTID_CNT, _initial_page_opts);
 	}
-	set_opts = TRUE;
+	set_opts = true;
 
 	/* reset */
 	if (!table && !display_data) {
@@ -757,8 +758,8 @@ display_it:
 	view = INFO_VIEW;
 	_update_info_bb(info_list, GTK_TREE_VIEW(display_widget));
 end_it:
-	toggled = FALSE;
-	force_refresh = FALSE;
+	toggled = false;
+	force_refresh = false;
 reset_curs:
 	if (main_window && main_window->window)
 		gdk_window_set_cursor(main_window->window, NULL);
@@ -986,7 +987,7 @@ extern void popup_all_bb(GtkTreeModel *model, GtkTreeIter *iter, int id)
 	default:
 		g_print("Burst Buffer got unknown type %d\n", id);
 	}
-	if (!sview_thread_new((gpointer)popup_thr, popup_win, FALSE, &error)) {
+	if (!sview_thread_new((gpointer)popup_thr, popup_win, false, &error)) {
 		g_printerr ("Failed to create burst buffer popup thread: %s\n",
 			    error->message);
 		return;
