@@ -6,8 +6,8 @@
 # CODE-OCEC-09-009. All rights reserved.
 #
 # This file is part of SLURM, a resource management program.
-# For details, see <http://slurm.schedmd.com/>.
- # Please also read the supplied file: DISCLAIMER.
+# For details, see <https://slurm.schedmd.com/>.
+# Please also read the supplied file: DISCLAIMER.
 #
 # SLURM is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free
@@ -59,6 +59,7 @@ def main(argv=None):
                       action='callback', callback=test_parser,
                       help='comma or space separated string of tests to include')
     parser.add_option('-k', '--keep-logs', action='store_true', default=False)
+    parser.add_option('-s', '--stop-on-first-fail', action='store_true', default=False)
     (options, args) = parser.parse_args(args=argv)
 
     # Sanity check
@@ -130,6 +131,8 @@ def main(argv=None):
             failed_tests.append(test)
             os.rename(testlog_name, testlog_name+'.failed')
             sys.stdout.write('FAILED!\n')
+            if options.stop_on_first_fail:
+                break
         sys.stdout.flush()
 
     end_time = time.time()
